# -*- coding: utf-8 -*-
"""
Contains embedded image and icon resources for Skyperious. Auto-generated.

------------------------------------------------------------------------------
This file is part of Skyperious - Skype chat history tool.
Released under the MIT License.

@author      Erki Suurjaak
@created     07.02.2012
@modified    02.10.2022
------------------------------------------------------------------------------
"""
try:
    import wx
    from wx.lib.embeddedimage import PyEmbeddedImage
except ImportError:
    class PyEmbeddedImage(object):
        """Data stand-in for wx.lib.embeddedimage.PyEmbeddedImage."""
        def __init__(self, data):
            self.data = data


"""Returns the application icon bundle, for several sizes and colour depths."""
def get_appicons():
    icons = wx.IconBundle()
    [icons.AddIcon(i.Icon) for i in [
        Icon16x16_32bit, Icon16x16_8bit, Icon24x24_32bit, Icon24x24_8bit,
        Icon32x32_32bit, Icon32x32_8bit, Icon40x40_32bit, Icon40x40_8bit,
        Icon48x48_32bit, Icon48x48_8bit, Icon64x64_32bit, Icon64x64_8bit
    ]]
    return icons


"""Skyperious application 16x16 icon, 32-bit colour."""
Icon16x16_32bit = PyEmbeddedImage(
    "iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAIAAACQkWg2AAAAB3RJTUUH3QMaFiYCLwtVsAAA"
    "AAlwSFlzAAALEgAACxIB0t1+/AAAAARnQU1BAACxjwv8YQUAAAEhSURBVHjaY/z//z8DKYAF"
    "mXP07Z/WWz9vf/mHLJgkz1qpxgHnMsJtePztn9nBLy9+oltoIsB8yp6HkRHKZYJLrHj6C1M1"
    "EJz98PftL4Q4wkkvfqCofuzOK8PJhKkfIWQuxIwsUXntx5c///Fp8BZnNeRHcFc++T37wa/f"
    "//7j1MDNwjjTgFOYDeq73/8ZWm7+3PHyD04NQGAqyDLfiFOIFarn3e//See/n/3wB6cGIPAQ"
    "Y6nTYGeHCb/59T/r4o8ff//j1MDKxJgizxYjywoXOfX+73Ykh2EJOKBn6tQ5kEWOvEVogMYD"
    "MLr77v4sufKDARuQ4GBEtwEY834SLFhVy3AwRsqwodsABMrczA4izE++owS8Pj9TmSo7cpQz"
    "kpq8AZv/aJiCXJ+bAAAAAElFTkSuQmCC"
)


"""Skyperious application 16x16 icon, 8-bit colour."""
Icon16x16_8bit = PyEmbeddedImage(
    "iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAMAAAAoLQ9TAAAAB3RJTUUH3QMaFiYSMrxF1AAA"
    "AAlwSFlzAAALEgAACxIB0t1+/AAAAARnQU1BAACxjwv8YQUAAACEUExURf////3+/0DD8yS6"
    "8lPJ9Mnu+9rz/ACv8By38eP2/f7+/4zb+Ira9+H1/XLS9vT7/mPO9a7l+vr9/pDc+Aex8DbA"
    "8/f8/rLn+hK08RS18czv+8ru+xO18bLm+jG+8gWw8I7b+Knk+VzM9fP7/gGv8Ov4/uL1/Ri2"
    "8TS/88Ts+0nG9IbZ91Ok98QAAABxSURBVHjabc9HEoAwCAVQe+y9917vfz+D4iQLWeW/DAwI"
    "wl8dpwx1fXndyFO7iWC/mcwLggvJ4EYMAOPEwGspdH3IpKqp5A3XlOVUipJBGMVUkpQb48Pg"
    "gGtyANz3bVq4GLHxV8Osf8uJ0nObov5efgN2BQW1nHoFYgAAAABJRU5ErkJggg=="
)


"""Skyperious application 24x24 icon, 32-bit colour."""
Icon24x24_32bit = PyEmbeddedImage(
    "iVBORw0KGgoAAAANSUhEUgAAABgAAAAYCAYAAADgdz34AAAByklEQVRIx7WVPU8UURSGn3tn"
    "9mtYiLExa9YoBilcKwpi5A9QbmJiQ20MjY3+BaIm/AITLexs0MTEjoJGzFIQo0RYKIxRiISE"
    "uCPszuzMHBslYWfvMrPLvuWcM+c5d957zigRWQbuAHnOVy1gVYlIcwjFTyBKRIQhyjYF/Ahq"
    "hwFP6j7vf7WNBR5cy7J4K0/RVukAHw8D7q83qf+Jenb4pRGy74kRoE0vPv/mn1kc4HMjYs+T"
    "9J/o7W7Q9fntixY5fbrb/VYEWOkAocH7V1MON4o6scnGzMpY944W6h7HoQwOeHg9i2PFjXv9"
    "s83Cls9RQogRMHspQ7Vk03k5WqHw8rvPG4NHnTIOmgBf3ZB7a002GmEsXi5olmdGmDzDD2NU"
    "ATdHLZamHcqFeNqPZsTd2jGbboT0A/ivyaLmWSVPKR9P3XRDnm63OOgxB4nuW7VkMz+eZaTD"
    "kEBgaTdg5SAYDOBYiscTOebKmVjMDYTFHW8wAEDBgkcTua6xT7/DdKsiEqjWjnA7lqhpwCyl"
    "0gG0gjFL8W6vneh01ct2f4OmEhSvjGrmx7P97CLNVae3RXNXMryYcpi+YKef5POS/vf3H5Y8"
    "DawOCeIBH/4CGECesxwDp8sAAAAASUVORK5CYII="
)


"""Skyperious application 24x24 icon, 8-bit colour."""
Icon24x24_8bit = PyEmbeddedImage(
    "iVBORw0KGgoAAAANSUhEUgAAABgAAAAYCAMAAADXqc3KAAAAB3RJTUUH3gQUEBkMQIv3tAAA"
    "AAlwSFlzAAALEgAACxIB0t1+/AAAAARnQU1BAACxjwv8YQUAAAMAUExURQAAAACt9wC19wi1"
    "9xi19xi99yG99ym99zG99zHG9znG90LG90rG90rO91rO92PO93vW/4Te/6Xn/63n/8bv/87v"
    "/873/9b3/973/+////f/////////////////////////////////////////////////////"
    "////////////////////////////////////////////////////////////////////////"
    "////////////////////////////////////////////////////////////////////////"
    "////////////////////////////////////////////////////////////////////////"
    "////////////////////////////////////////////////////////////////////////"
    "////////////////////////////////////////////////////////////////////////"
    "////////////////////////////////////////////////////////////////////////"
    "////////////////////////////////////////////////////////////////////////"
    "////////////////////////////////////////////////////////////////////////"
    "////////////////////////////////////////////////////////////////////////"
    "////////////////////////////////////////////////////////////////////////"
    "////////////////////////////////////////////////////////////////////////"
    "////////////////////////////////////////////////////////////////////////"
    "/zk5v24AAAABdFJOUwBA5thmAAAAjklEQVR42o2SWQ6AIAxEIRAxalwQUy33v6dLXVKo0X7O"
    "K2lnilJRLPWib+QDYGg0VbcwENyp62pmoL10bQIDhrrrrUYBQD68pMGYAX88MT2mYKHp1mcG"
    "gfa1kIII9iAOUhC9lZzvqQy0wJiCiB25zNMFyoSBZg+jFMATom6581t3PN2puPoD/jutAN6+"
    "zwrAjS3DagoRyQAAAABJRU5ErkJggg=="
)


"""Skyperious application 32x32 icon, 32-bit colour."""
Icon32x32_32bit = PyEmbeddedImage(
    "iVBORw0KGgoAAAANSUhEUgAAACAAAAAgCAYAAABzenr0AAAB10lEQVRYw92XPUscURSGn/nY"
    "3bgfpNlliQpKIrEwEEHYxkgMGrFIEdAiP0CIhYWlPyKtYDp/gNtZbFArV7HcSAIpNqJCIMZN"
    "IOqY2XVnro2I1dzZmTsZ8NSHOc+8557z3qsJIVaAGSDP/40GUNaEEKcxFL+F0IQQghhDJ+Yw"
    "/SZ+PXeYr9lUf7d95R9O5ehL62oU+HjY4tnWhe/iAJVfbTUt+PzXYb72r2NpN1UBfKg3A/V2"
    "/eQKRygAqJy0AwHYDuz9ccIfwkbL+ze+TeYYzOrRjWE+qXkDNkW0e2A87y3Si+0LfthudAAL"
    "j5PSj0zvXtJ0IwJ4mTeZ7U545nw5CzaqvhfR6kgX/ZKttnrcYvmg1TGAbzP6brkMbJzLF9Bo"
    "homCqVYBgCcZnc3RjDRvcsfi6NJVDwAwUTBZGe7yBWE5Qj0AwPv+JHN93pNRt1wW9221Z+Bu"
    "OALGq5bUHWuvsjx/aKi/kBgarJXSPDDCG1ngJV5MaVTHsqGNLNIrmczIpG7oCOj9dMZPO5jh"
    "yIxMqoChwZtiIrAC00UzfAtme4IDLD1NqbFjU+u8+FopzVDOCA+Q0uHtI/8qvOtNUH+dY6Y7"
    "Ed0iulcvI/3mlRpXNHSgHBNEAyhfAxqnm8QqAGg4AAAAAElFTkSuQmCC"
)


"""Skyperious application 32x32 icon, 8-bit colour."""
Icon32x32_8bit = PyEmbeddedImage(
    "iVBORw0KGgoAAAANSUhEUgAAACAAAAAgCAMAAABEpIrGAAAABGdBTUEAALGPC/xhBQAAAwBQ"
    "TFRFAAAAAK/wBLDwCLLwFLXxGLfxILnyJLryLL3zPML0VMn1WMv1XMz1YM32ZM72lN35mN/5"
    "rOX6uOn7vOr7wOv7xOz8zO/80PD81PL82PP93PT94PX95Pf96Pj+9Pz++P3//v7/AAAAAAAA"
    "AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA"
    "AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA"
    "AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA"
    "AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA"
    "AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA"
    "AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA"
    "AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA"
    "AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA"
    "AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA"
    "AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA"
    "AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA"
    "AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA"
    "AAAAAAAAAAAAAAAAAAAA6f5MRgAAAQB0Uk5T////////////////////////////////////"
    "////////////////////////////////////////////////////////////////////////"
    "////////////////////////////////////////////////////////////////////////"
    "////////////////////////////////////////////////////////////////////////"
    "////////////////////////////////////////////////////////////////////////"
    "////////////////AFP3ByUAAAAJcEhZcwAACxEAAAsRAX9kX5EAAAAHdElNRQfdAxoWMzY5"
    "CkcRAAAAGnRFWHRTb2Z0d2FyZQBQYWludC5ORVQgdjMuNS4xMDD0cqEAAADDSURBVDhPrZNb"
    "FoIwDAWJ4AsRUVQQFbr/TeLxQG4TwuOH/tEMN20GgtbNrjaYrzu3KlAeCeuNzr5F5stEmQUK"
    "WafYAokCQgtECqAHEzgD11+DwQDgBLzagwBijvjoCAB3Bg6NIvwcEHGeAOodZ1wkIWRVuGgu"
    "CGkzH1GhdUPHvh6R9d9KOSOdAByMF2bU3cY37DOSCcA9eyBaAsgAW63bJuACHWjPcNMJpWnR"
    "bCRxHZkDbBKdKi9Duhh8bN3jCsDS7/8DqHNjgvHE59IAAAAASUVORK5CYII="
)


"""Skyperious application 40x40 icon, 32-bit colour."""
Icon40x40_32bit = PyEmbeddedImage(
    "iVBORw0KGgoAAAANSUhEUgAAACgAAAAoCAYAAACM/rhtAAADQ0lEQVRYw82Xy4sUVxSHv1tV"
    "3dPdZdOO+MLIaHQ2OjIyQVQUTYKIRjEB0YUb3agbEfMPhARcBIKb+MCVIChudBGIBNQYZdw4"
    "YlAURQzJhPGJM8o8tPpRj5PFGHAT61R3peyzPvfe795zzu+eg4hMEZH1IjIgIr58ePPfsqwH"
    "MCKyDvgFyNNe1gA2GRHpB9bQnnbNiMgoUEmyKhC4Px5yZzxkqCq8agi1UIhi1u2el+eTqXaS"
    "o8YcQL3Cj+DoYJ0f/2ww5EVIwueY4pikgLaj9Rz3ha03PC4PB03H69cXAfQkW2NpnATYc7va"
    "EhzAvYmQ5/UofcDfhgPOPvFbL8sI+kfC9AGPDzYS59t/WdIoWJrC6H8ZpKYbV0YCogS3jS2S"
    "sWBSRjRmgHzMlR9Xhb+9iAWulQ5gJKhuXLINl1aXWFK2MSbeN7UXLDuT+jURvJ+yaENfxaaY"
    "4PBUcrBoG5ZW4sPxsiF8+6Ce+l+nSoTtc3KqzQ79UefYX/XsAXd15ZnZER86Ab6+W+PcUz9b"
    "wErO8ENPAU12BQK7fq9yLSVpsrSOO7vy7J2vaxm9UNg64HFvPMwO0ABHeot8NVvXX4w0hC3X"
    "PR5Vo2wAAXIWnF5WYtU0Xcs06EV8ed1j1JdsAP/t6X5a4bK4rFt6eyxk2w2PaijZAALM6DCc"
    "X+nyUUEnypeHA3bfqtIMo9Xs03/sWvy80qUzp4M889jnuwe17AAB+qbanF1eoqjs4r9/WOfi"
    "iyA7QIB1MxxO9JXQfMGhwP471UT52DIgwI65OQ4t0Qn5w9cRpx/52QICHFjYwf6FOiE/OdTI"
    "HtAABxcVKCh2vDka8kYZ5viGFagrNhNg4FWIRpMbETyrCd2uaR1wzBe6L05Qi+IBa6GohytR"
    "OsYCduYMvRWbqyPpDU55C+YoRV6Vg1/MckjTVnTauE4bA+5b0JFuFfeUbeaV0in4zbMctilH"
    "CDWgZWDjzNZf8fPpDqeW6X6dxDq4qckwG6DbtTjcW+DCKn1z8W4Vq/ryT6c77Jmff+8Qb942"
    "ta5tmJY3dBUtllYsFpVtmhyXQyMiV4DPaE+7akRkLXABKLQZXA3YYCZVXdYCB4E+jXj/zxYA"
    "t4BvjDH9/wA7fq9ps4i3KAAAAABJRU5ErkJggg=="
)


"""Skyperious application 40x40 icon, 8-bit colour."""
Icon40x40_8bit = PyEmbeddedImage(
    "iVBORw0KGgoAAAANSUhEUgAAACgAAAAoCAMAAAC7IEhfAAAAB3RJTUUH3wQcFAAJogD5tQAA"
    "AAlwSFlzAAALEgAACxIB0t1+/AAAAARnQU1BAACxjwv8YQUAAAAwUExURf////7//+39/2PO"
    "93TW94je/6fn/8zv/wCt9ya995fe/0rI9znG99z3/7nr/2vW94Q4YkwAAAABdFJOUwBA5thm"
    "AAAA1ElEQVR42o3V2xKFIAgFUMUbVtb//23nWpg7Yr81s8aGAHPOeUOcs7m3tLmX7B9LTnEL"
    "v5RbmCrLxBtIM/epN/DqmAnCdXCcIRwP5ABhHWFFkBik6bDQP/DVJ3zozII/9Ain88hJhSTK"
    "zhqUR3LRoA+a7KZHNKc2DdIiJCmwK2jWoG9CBg36Ypjwb+RYrhr0+WHMziTYS7TX2wEXHYrR"
    "1KGop40QrgKCaAvxqxNwsJgCYEYQLLacCwHD4PC6yt59+tevmLz2wpGY8nUX7Fez+bK3/j52"
    "YpAULg8lhSQAAAAASUVORK5CYII="
)


"""Skyperious application 48x48 icon, 32-bit colour."""
Icon48x48_32bit = PyEmbeddedImage(
    "iVBORw0KGgoAAAANSUhEUgAAADAAAAAwCAYAAABXAvmHAAADhklEQVRo3tWaTWhUVxTHf/fN"
    "m+RlMpGkJWaMQdPWj1kkXdhU48dGYjFiCl24KRIQrDsFQzsURLAb3VRRaBddCC2IxJ1CWrQU"
    "rULUCAalRvwgWrURoyQm1cnkTebNXBeTgBthzpt3nclZv3Pu+d17z73/e99VWusIUAHsA74G"
    "FgOK8jQNPAV6gUNKqUmltV4AnAfamF92HeiwgMQ8TJ7ZnBNKa30PWMH8tPs20FBMhOGpHL+P"
    "Zrg2kWU4mWNsRjMyncPThcf4alGY02sifppvsP0W7KNUjp5bLmeeZYruxotjnl9XZfnx6h/3"
    "aL2QDCR5gMmMZuBl1pevGODu6xxbrqZISuaIwVEQA+y6OR148gB/vngPABfHPPrHPSPLycCE"
    "h5s1DHDyvwymzM36m0aWrJeymLRL44YB7r42C3DuuRzAlnwsrd0fWxy+WVpBbVgZiS8egUIT"
    "mbPdH1WKfGxlGKBlQUgUPHF72rgYEgF01MsAfn44Q88tt3wAdiypEDdw7EGaw8Pp8gBojlhs"
    "awyLG0kMuZwayZQeYG5lifqotu7BVDGqMziA5ojFT5864oY8DV8OpBh6lS0twFwtHIhXiv2S"
    "nuaLK1OMurq0AAA/xB12fywv6lFXs/FyMjBFaxXjfLS1yldRz50pgmAoCsBWcOKzCBs+tMW+"
    "/eMe3YOp0gIAOCE4uzYi3qUBTo1kSAy5pQUAiNqKv9ZVs6xaHu7wcJpf/p0pLQBAzFH0tVcT"
    "c+R7xJ5/pn2f9AIDAIjXWPS1V4s3Ok9D96C/s3agAABttSFOr4mIpfGjVI6D99OlBwDYVG/T"
    "+7n8pu3YgzSTGV16AIBtjWGOtsokh5uF357MlAcAwN5PKtm/UiY5pPdDRgEAvl8uA7j5v0zs"
    "2SaTn8xojggPM1KhVzCAp6Huj1dGrhXfy05sK+hcaBtPKF5jmauBrTHzAO11tjmAzoVh4wA7"
    "l4bNAcQcRfsHIWPJb6q3xdJcvIxuNlQHMUfx66oq81KiKxb8NGqOWPy9PkpTlWUeoK025Esy"
    "v+sc8d2ySm5sjIpXn7f3gYIXdq3zn3Y12Bx/XPhFla2gqcrCCeV7Ox61WF0XoqvBpiZcnBhQ"
    "Wus7QLxQAE3+v6xSPkdBgyaAOLP3Axb5hxOF0SqFpVRxjaqA4uStV2mto8A5YD3zyy4DnWp2"
    "akSBb4HtwCLK+7nNM+AkcEQplXwD8/MiJaSWlKAAAAAASUVORK5CYII="
)


"""Skyperious application 48x48 icon, 8-bit colour."""
Icon48x48_8bit = PyEmbeddedImage(
    "iVBORw0KGgoAAAANSUhEUgAAADAAAAAwCAMAAAEX2zkjAAAAB3RJTUUH3QYHESIrZgkebwAA"
    "AAlwSFlzAAAK8AAACvABQqw0mAAAAARnQU1BAACxjwv8YQUAAAC0UExURQAAAP////7+/v3+"
    "/v/+/2TO9QCv8ASw8CC58ii88kjG9HDS9qbj+fL6/Ri38Qyz8XTT9+/6/svv/Nfy/X/X9+P2"
    "/TjB80TE9Of3/sPs+5/h+WDN9lTJ9fv+/3zW9/P7/o/c+Kvl+giy8Lvq+3jV9yS68pfe+Sy9"
    "8/f8/zzC9FjL9WzR9tPx/N/1/b/r+6fj+ovb+HDS9xC08TC+82TO9rfo+0DD9IfZ+Mft/FDI"
    "9dv0/TS/88xqrdsAAAABdFJOUwBA5thmAAABrUlEQVR42pWUDVuCQAzHOayJViBqpSZh9iaa"
    "ZvZqff/vFdxxsHE3wT2Pwu63P9ttB44jMkv/AUBe3qS3AHkRt4CYikxAsuxfMRUJ3fQy1J74"
    "9UBHZPLSybwXoR3Rr4Z1lNNKfydlWJ5cOkslKTVftjx5UEkKp/DUo1PHK/MwVct7H5XTqtZG"
    "TIMAtP0QAMgswPKoqSKvZg79sNgAYkRSkHLvFAkNkI4caLtouWOiKJZ7ZES2ljjMcr1g9teW"
    "OfZ0H+NqDy3lEvCBwCcGbQTeMdjJpYU5jyE7KDBIDiYKBOYEV8XJrw4qUWRpjvZRkSdztAE5"
    "Dri7CsxNQI4dBqEJptzZHXEAz+OSAF8vByHZh+vmbnEj+FPCvoSc4Lh4I/V6D1XbHRAMArDY"
    "NyvYgNXmC07wbBfAAyfAQduwXI84QYIEqyZdWpNCtg3auiZdam8azGFIkvijWoGIyNmFJKoT"
    "CBHT7vZqBenAfbKVca1AiHv8AeIHh22GFbMGAhHjbtkFkfWsohfayDDh4m+4kq7s8dfspvu2"
    "cG/AttV1T3H/vU737PyiftKHzTnyO+M4/8CIIdP02kirAAAAAElFTkSuQmCC"
)


"""Skyperious application 64x64 icon, 32-bit colour."""
Icon64x64_32bit = PyEmbeddedImage(
    "iVBORw0KGgoAAAANSUhEUgAAAEAAAABACAYAAACqaXHeAAAEkklEQVR42uWbTWhcVRTHf/fl"
    "zfdES5vqpESa1jSd2thKSTVK0IKIlVRMIYsKZiG0JAuLdhG06M6FQpG2VGhBQRdCUhQUorTi"
    "xkXVWEy1NZRYkzpqsGNJQ9pmvt+86yIT3erc+96dcc5mYGDO3PN75577v+feJ6iYlDIGvAjs"
    "AzqBEP8vKwBXgDHguBAiAyAqwW8EzgKbaAz7GdgthLgqpJQR4AKQpLFsGthhAUMNGDyVmIcs"
    "YIDGtQEb6NDt1ZFw7obDd4tlLt4sM5eTpLIueVeSzsuq/b7SGeKN+8I6h9phAwFd3tJ5yVsz"
    "Bd7/rch8UWp/XF/OO7pdBmxdnj74vcTBSzkWS9KzfJ1YKLNYkqwKCG0+LR1ODl/OMziZ9TR4"
    "r7JAGcC7vxZ580rBt6r1+fUaAjCTcTl4Kedr2a6pDBiZypMv+6xebruksq55AKmsy6fpkpHF"
    "W2cWVA1gbK6EI43Er7UOVA3gqwUHU1YTGTB1yzUGIJ2X/HCzbL4GmDRdWWCbCmB4Q5BXO0O0"
    "Rap7BrrqT9UA4rZgSWEUR7sihJsUBi4M14D2qJqIND2FlAF0r2pS+uNDUzljy6gWAI+vVSsf"
    "Z/90GJnK1y+A/labuOJEPDZb4NhsoT4BxG3B/vVB5QGMTOX56I9S/QEAeHlTSKmSryxnz1/I"
    "ce6GU38AEmHB61vUe3RLjmTvt1mmb7v1BQDgpXtD7GpR11PzRcnTExmlpqkRALaA0e4oHTH1"
    "7tpMxmXv+YySwPIdwMpUGO+JkQiry7OJhTKDk/5pBEuXo2SzxYc7o8pLI8An10q+tdosnc56"
    "19iMdke16PRTv/jTbLV0O9yTsDn5QESLr8OX84zNleoLAMD+9UEtyyPA4GTWU41geeX4tc0h"
    "hjeoK0VHwlPfeKcRLC/T68S2CAPr1I8elxzJE197oxE8BWALeG9HhN416kJpLresEXQvj54C"
    "WNk0ffxQlGSz+l9NLJQ59GOuvgAAtAQFZx7WI5Tevlqsjbb4f7X2qMUXj8S0CKUD3+e0Hcn5"
    "BgCg644mxnvUhdJMxuVUqlB/AAB2tdiM7owq+zk+W9RSEH0HADCwLsDR+9WEUirraqkFRgCs"
    "9BH2talphM/SdQwA4MhWtSzQIZGNAlC97KTjcMUYgFTWZXBSTdTouIpXlUZdciRrz9zy/XpM"
    "zWyG4ragd7VtfPDVnixrmQLPtAaMA0jGDQLYfbf5DHhMQzu+agAdMUvLDk9lq/3cPQFzAAD6"
    "DU6D/taA8h0FZQB9hqZB3BYc6dLTc1QC0LPa1npz+9/aye0RLU9fGYAtltvgfs77E9siWua+"
    "NiX45F3+1IG2iMV4T4wXNgb1QlV1sCdhYws8O8tLNlsMtQcZble/i6AdgCsld9rLtUBlZ5YI"
    "C8KWoCUoSIQF7VGLrc1NPNrSxJa4hRDe1RkhpbwGJKr5saw8de3jq/iVFb8eltnrFsuvk1ZH"
    "T3gQ/ErE4u8PL23aAk7TuHZaSCmDwHlge4MFfxF40BJCFIG+yheNFHyfEKIo/iloMgQcAJ4F"
    "NqPxhcoasRLwEzAKvCOEKAD8BZSvdec9HacnAAAAAElFTkSuQmCC"
)


"""Skyperious application 64x64 icon, 8-bit colour."""
Icon64x64_8bit = PyEmbeddedImage(
    "iVBORw0KGgoAAAANSUhEUgAAAEAAAABACAYAAACqaXHeAAAELElEQVR42u2bTWhcVRTH//fl"
    "ztebFwlpqpOS0qkJJdoYRRKcSCCBUhRaMYEsXDS7ihUMpItAS5cuFII0kkWyEHQhJGChQpQo"
    "WVSkStoatHUIQSZk2oZ2lDSkaWbmzdd7LmowRgSdc96785yc3Wzu3Pu755z7v+eeJ7DLbNu2"
    "8T82IYT4y+9qWfg/gRDVuPidEDRUuYlq3f1tk04MWrSBqw+K+GGjhJsPS1jN2khmLJiWjZRZ"
    "Pu9zRwJ479lg5QJImTY+SOTwyZ081vL8jvXNWrFyPeDTuwUM3cpio+BcRM2vl7BRsFHnE2xj"
    "siTB84smBhcyji7eKS8gA/jodh7v/5JzLWl9/VsFAUikLQzdyrqatSvKA0biJsySu8fW0iML"
    "yYylHkAyY+GLVEHJ2c3pBWUDmF4toKhIQnHmgbIBfLdehCqrCA+Ib1rKAKRMGz89LKnPASqN"
    "ywukqgWcOezHhSMBNIXK2wOu/FM2AEMKbBFmcbEthGANYeJCcQ6I6jQRqTqEyAA66mpIf3w2"
    "nlV2jLIAOLaflj6++rWIkbjpXQB9jRIGMRDHlnMYW855E4AhBU4f8pMnMBI3celeQRkAUk0w"
    "Zdo4PLdJvhAZUmC2S0f3PukdDwCASFDg3WfoNbqtoo3+axksPbK8BQAAhpsD6G2g79xa3sZr"
    "82lS0VQJACmAqQ4dLWF6dS2RttB/PU0SWK4D2A6FmVgYkSBdns2vlzC44J5GYHsZaq3V8Fmn"
    "Tj4aAeDz+wXXSm2sT2Pd+ySmOnQWnT654k6xlf1t8GREYuKFEMtY5xdNTK8WvAUAAE4f8rMc"
    "jwAwuJDB1QfOVZ8cfRx9+2YWkyt58jiGFLjRY6C1VvOGB2zbeHsIAwd8LELp+PfOaARHAUgB"
    "fPxiiEXirmYfawTu49HxBglDClx+SWdx3/n1Es7+nPVODthpyYyFrm+3WNz4SneYRX674gHb"
    "FtU1zL0cZhFKb/6YZXuSc7VHqO2JGszE6EIpkbYwmcx5DwAA9DZITHXq5HE+XM6zJEQlXWID"
    "B3y4+FyQnFM4HkeUtckNNwfwRhNNI3yZ8jAAABg9SvMCDomsFAC12YnjcUUZgGTGwuACTdRw"
    "tOKVpSa2ijb2z2663h5TMddhQwp010vlky/3ZZklBF5v9CkH0GooBPDqU+o9oIfhPlA2gJaw"
    "5kiB4r9ctU8d9KkDAAB9CsOgr9FH7lEgAzihKAwMKTDaxlNzJAGI1UvWzu1/axPPh1h2nwxA"
    "isdlcDfjfrw9xBL7bErwlSfdyQNNIQ0zsTDeedrPC5U6wMmIhBRw7C2vtVbDW1E/zkQDpK4y"
    "xwDU+QRi9ZJ0M4sEBYKaQINfIBIUiOoajtbWoLdBOn7Ukouilm1DANj1QSabOT0+2QMEHDoF"
    "/tgWpxb+5/yx9+VoVdvex9N/C70q+3z+d89KdMwNVWkXAAAAAElFTkSuQmCC"
)


"""Skyperious application 256x256 icon, 32-bit colour."""
Icon256x256_32bit = PyEmbeddedImage(
    "iVBORw0KGgoAAAANSUhEUgAAAQAAAAEACAYAAABccqhmAAAZV0lEQVR42u2deZQd1X3nP7eq"
    "3tL7ou6WWmoktfYFMCiMDdgBE2ODD2Qy8TiDl4mPZ0yMnQF7sGMjsDEOJMAQx0u8zsSxPY6J"
    "HRhP7CEZj8fGC4RJQjAI0NpaWq3Wrm713v3qvaq688d7KJJodQu0dt3v55x3pNPdp8/pW/X7"
    "1O/e+t3fNZwi1toGYE3lcxGwDOgAaoE6IEAI8WqJgBFgFNgNdAEvAs8Czxpjhk7ll5tXGfRV"
    "wGXAvwPeCrRUgt3T9RLijJNUpNAH/Ah4BHjGGDNxRgVgrc0BrwVuBd4EzNK1EOKc0w88DnwJ"
    "eNoYE552AVhr5wF3Au8D8hpzIc47CsBfAA8YY/acFgFYaz3gncCDlbm9EOL8ZjewFviuMSZ5"
    "1QKw1uaBu4APA/UaVyFmDMPAF4D7jTGFVywAa20dcAfwcSCj8RRixlECHgL+izFmZLIf8E4Q"
    "/DngYxUBKPiFmJlkKjH8sUpMn5wAgNsrT369wxdiZhNUYvn2k5oCWGvfCvwlesUnRJroB37X"
    "GPOjEwrAWtsIPAWs0ngJkTo2Aq83xgy+bApgrQ0or/Yr+IVIJ6uAD1di/dgMwFq7CnhCqb8Q"
    "qZ8KXGWM2XgkA7DW+sDNCn4hUs8s4OZKzB+ZAnQCN2pshHCCGysxf0QAVwGLNC5COMGiSswf"
    "EcBNgK9xEcIJ/ErM41lr24GVGhMhnGKltbbdAy4EGjUeQjhFI3ChV1kMqNZ4COEU1UCnByzV"
    "/F8IJ9cBlgZAq8bi/CW2liiBkoXYQmQtiYVSUm4MF9vyz0XWYiv/P/rraaU5Y2jLeRije+QU"
    "aA0oN/MU5zjIxyIYLFlGIstoZBmLYSy2DBQth0uW/rD8vcMly0QM/UVLIS5/zQIDJUup0vsl"
    "TCyjUVkEacQDbunM8qcX5qnyZYBToC5A/f3OOiORpWc8YfdEwr6CZV+YcKBg2Vuw9BUTDoXl"
    "QB8oWgqJxut4EmDHWHn8ltZq9noK5LXf/ywQJpbtYwnrhmKeH4rZPpawv2A5VLT0hZahyKY+"
    "ZT/d7BhL2DluWVqrsTgVJIAz9ZSysGkk5rH9JR4/FNMznjAcWYZKeqqfDnonErrHY2Lr42sh"
    "QAI411gLo7FlXyHhJwcjvtNb4sXhmDCBSE/3004hgXVDCQMlS0tWApAAzmHgHyomdI0mPLKn"
    "xN/sK7F7QhF/Nlg3GNMXWlqyGgsJ4BwE/lBkeao/4m/3l3hsf8SeggL/bLJxJGZ/aFleazGa"
    "BkgAZy/4Lf80EPPt3hI/ORjRPZ5oEe8cMBTBi8MxVzb7aBYgAZyduWds+UZPkT/bUWTneEKo"
    "Bb1zylP9Me+dD1kdSysBnMl0P7KW9cMJf9wV8uMDJUZjjcv5wJP9EROxpS5QCiABnKF0fziC"
    "H+4rcX9XyJZRPfLPJ/YWLBtHEtpySgFeDRq1aThcgs9tD7ljQ0HBf57y+KFIgyABnH72FRLu"
    "3VzgM1tD9oda5Ttf+ZkEIAGcieD/w80hf95TZEzz/fOaLaMJeyaUnUkAp2nOv3ci4dObQ77d"
    "W2RCwX/eMxFbnuxXFiABnIbg31Ow3LM55Bs9Cv6ZQjGBX/bHR/ohCAngVTEaw5d2hDy8u6j6"
    "/RlEZOGFoZjBki6aBHAKfKe3yFe79eSfiRwILetHdOEkgFfJL/siHtoaMqyp5IzkcLHcb0FI"
    "AK9w3l9e8f+jLQV6xpVCzlSGSrBhOKaU6BpKAK9o3m95oCvkyf4Y3Tozl4Ty68BtY3odKAGc"
    "JFFi+fGB8nZebeqZ+fSMJ2yXACSAk6V3wvKd3iLdSv1Twb6CZdtYQqT3gRLAdISx5f8cLKmO"
    "PEUUknIfxsGiBCABTENf0fKVHUVt600ZG4YTDmjfhgQwFdbCt3YVWT+i+WLaeGE4ZnchwWoa"
    "IAGciANhwte6i7r6KWQkgheH1KlJApiCb/cW2ac0MbX840DMuKZ2EsBk7C8k/M3eSE080yyA"
    "wxGj2swhAUzGTw9FeleccvYVrLo3SQAvZyyy/OhARL9eE6WaBPjpQb3elQCOY91QzIbhGD0b"
    "3Mj0Yr0JkABeIraWZwdjuscV/i6wZTRmr05qkgBe4nDR8vxwrO2+jhAm8P8O62JLABV2T5QP"
    "9hCOrANY+MUhvQuUACj3+uudSNgwrBvCGQEATw9EjOl1oAQwHsPzQ7Hq/h3jULF8iKtwXABj"
    "cXn+L9xiuGR5Vm3CJIDxGBWGOMhIVO4WXFDZp7sCsBZGIst2CcDJdYCe8YQenRrkcgZg2TmW"
    "oHvATXZPJHRJ/m5PATZo37+z9E5Y1g/Hqgp0dgoASgEdpmRh80hCn7Z/u5sB9Kr812k2jyYq"
    "C3ZZAIe0+89pukYT9hQSHR7q6hTgQEEZgMsMlSwbh2MKOjXIzQxA8e82FvjHgYRhnR7spgDU"
    "Jlo8PRAxGFl1Cz6OQEPgHi1ZQ2e1x5y8oTljqA0MuZQ/CjwD1b7RxZcA3GV+leFft2d4Y0vA"
    "BVWG1qxHY8ZQHUDWgDEKEAlApA4DXDXLZ+2yHK9t8mnKGAW7cEcAGVMuCHGVX2v0uX9Vntc1"
    "+/gKfHH01MiFP7It5+5NXxvA2+YGXDkrUPALNwVQG7h74zdnDL/RopmecFQABpjtcAZQExhW"
    "1Pm604W7GUB73tlT0AkM1AVK/YXDAlhQ5W4AJBaKKoEVLk8BFte6mwFMxLBNZyEKlzOA5bU+"
    "ruYAAyXLU/1qjClczQCMoT1vaMm6qYDhyPKLvojDRWUBwtEMoNo3LK9zcxoQW/iHwxE/74u1"
    "H164KgBYVefuOkDvhOV7u0vsHE+0G064J4DawHBJQ4CrCkiAH+wr8a1dRUYiJAHhlgCynmFJ"
    "jaHV4YKgyMKXu4s8tr+Ewl84JQCAeXnP6WkAQH/Rcu+WUOflCQcFUOWxSiWxdI0m3LWxwHqd"
    "lShcEkBdABfVl/fCu87f98fcs6nATrVLlwCc+UON4bImjyU1EkBk4X/tj7h7U4Ge8YREi4IS"
    "gAusrPNZVe+j1nBlCTy6p8Rnt4UcCNUsUwJwgGrfcE1LoGlAhTCBb+4q8uXuIuNaEpAAXODa"
    "1oCOKgngJUYi+PKOkL/oKaJNgxJA6mnPe7ylzd2ioMkYLMGfbA35691FDYYEkPI/2MD7F+ao"
    "VpesY9hdsHxqc8j/3FuipFRAAkgzi2s83tae0dU/jm1jCfdtKfCzvkhNRCSAdPO+BVnqlQW8"
    "jHVDCQ92hfxqMCbWmwEJIK1cWO9x/WwZYDKe6Iu5b0vIznEJQAJIKQ0Zw7s6sszK6o3A8STA"
    "Tw5G3LGhwHAkCUgAKcQ3hsubfP5Ne4AU8HIiC4/tL/Gx9QVGIqtmIhJA+pid9/iduRmW1uil"
    "4GQUE3i4t8i9mwsMlmQACSCFXNEccMOcgCo5YFLGYvj2rhL/bWcoCUgA6aM+Y3jP/KyzPQNP"
    "hoNFy5e7izyyp8hELAlIACnjonqP9y/IktdonJDeCcsDXSE/ORhpMCSAdOGbchZwTasahkzF"
    "znHLh16cYP1QrN2DEkC6qAkMn7uoyuljxE6GnnHLO58Z57mhRIVCEkC66Kz2uGNZjkZVCU/J"
    "xpGEOzZMsGFEzUQkgBSR9Qy/3Z7hd+ZmyGpkTkgCPNEfc/+WkB3jqhGQAFJEW87wwc4cVzRp"
    "PWAqikm5UOihrpA+HTsmAaRmQIzhonqPjy7Nsaha6wFTMR7Dw7uLPLS1qKmABJAeAs9ww+yA"
    "tcvyzh4q+kok8NltIX+6LVSNgASQrkzgfQuyfGBhlirNBqZdE3igq8jDvSXGtXlIAkiPBOCj"
    "S3O8u0OLgtMxULI82FXgsf0lCsoEJIC00BDA2mU5/u3cjNqJT8OOccsDW0N+0ReprZgEkA6M"
    "MSys9rhzaY43t6qByFRY4MWhhLs3FVg/rKPIJYCU4BvD6nqPB1bnuWqWr0GbZj3gV4MJv7du"
    "gp0TiWoEJIC0rAcYLmnweXB1ntc0aNimywR+NRhz6/MFeidUIyABpIgrmgP+eFWe+dozMC0/"
    "PRRx35YCu3QIqQSQJq5vC7hnRZ65eUlgKooJPLKnxJd2hBwoSAISQGow3DQvw8eX5nTO4DQM"
    "R/CNnhL/vbfEsDoKSQCpCH8D1T68d36W2xdnadDLgSnpL1ke7Ap5ZI9qBCSA1EjA0JAxfGhx"
    "jls6s9RJAlMyULJ8ZP0EP9hXIlKNgASQFhoyho8syfHOjiyqGJ6akQjWbizweF+kZiISQHqY"
    "nfP45LIcN85RGjAdu8Ytn9oU8vf9sWoEJID0cEG1x70r87xJfQWnxALPDcbc3xXy3FCsAZEA"
    "0sPqeo8/XJHnXzVqWKeiZOHnhyLu7yqwfUwNRiWAlOAbw5XNAQ+urmJNg0qGp5PA9/dGfHJj"
    "yO4JCUACSAnGwNUtAXctz7GkVsM7HX+9p8RDW0MGipKABJCaTAB+qz3gE8tyNGc1HtOtCXy9"
    "p8hXukNG1ExEAkgLgTHc1JHh7uV5chrlKSkk8MUdRb7ZU1ShkASQHnKe4T/Mz/KxJTlUMTw1"
    "B0PLZ7eHfH9vSTUCEkB6qA/gw4uzfGhxlmq9IZxyKtAzbvnExgI/3KeOQhJASjDG0JLzuG1R"
    "jnfMy6jB6DT0TFg+uanAL/v0elACSBELqj3+YGmOt7YFBJoOTMmmkYS1Gwu8OKwtxBJAilhZ"
    "5/PpFXlep1OHpuVXgzF3byqwbVTVghJAiriw3ufzF+dZUqOhn44fH4y4b0vIPjUTkQDSsyYA"
    "lzb4fPWSKpbUGDQbODFhAt/bU+LeLSEHQnUZlgBSgm8MV88qNxhdVCMFTEUxgW/1FPn89iID"
    "JSsJSADpIOMZrm8rtxXrUG/BKSkk8JUdIX/eU0RdxSSA1FATGG6al+U/L85Rr1YCUzIcwZ9s"
    "LfJXvSUNhgSQHhoyhpsXZrltkTYNTEd/0fJHXSH/+4AkIAGkTAJrl+V5d4fOH5yOHWMJd28s"
    "8FR/RKL1AAkgLdQGhs9cmOftczPaPDQFFnh2KOGezeVCIUlAAkgNs3Men1qe4y1tAVllAlPy"
    "RF/M57aF7CnozYAEkBKMgRV1Hncty3FFs6/pwBSULPyPvSW+1l1EdUISQHouiDFc1ujz6ZV5"
    "Vqij0JSMxfC17iI/2KdFQQkgRQSe4Q3NPl+8uIpGNRKYksOl8hbiDcPaPSgBpEwC17QGfHNN"
    "FW05SWAqdo5bbnuhQK+ai0oAaeO6toB7ludoV7XgCbHA0wMRf7ZDzUUlgJRR5Rve0ZHhP3Vm"
    "adWrgSnXAx7dU+LvDpQI1U1IAkgTzVmPmxdkefcFGWrVSuCE9E5YvtpdZMtIomPHJIB00Zbz"
    "WLssxw1zMjqEdMqpQMzXe4pqMS4BpAtjoC3r8Y01VVzbFujCnYDIwle6i/zt/pKyAAkgfRKo"
    "9g3/9ZIqrmqRBE5EbOHeLSG7J1QhJAGkkI4qwwOrclzZrPMHT8TW0YQv7AgJddCIBJA2fGNY"
    "0+hz1/IcFzfoEk5GAnx/b4mf90UaDAkgfWQ9wzUtAXcuy7GgSq8HJ6N3wvKtXSUOhpoKSAAp"
    "JO8b3tae4d6VedpUIzDpWsDjhyJ+uE/HjUkAKSXwDO+Zn+Wu5TntG5iEvqLl0T0RW0dVGyAB"
    "pJhbFmb5/c4sDZLAy3jqcMTPDkWqEJQA0kvOg1sXZfndCzI6hPQ4xmN4eHeJg6FVFiABpBNj"
    "DLNzhtsX5/jt9oyOIz+OZwZifnywRLleUEgAabyYxrCw2nDfqnJbMXUU+heKFr60o4gqhCWA"
    "1Eugs9rnCxfn+fVZmgsczQvDCX93QHUBEoADLK7x+fxFVVxUr0t8NN/sKVJQdaAE4AIX13vc"
    "vyrPSvUWPMKzgzHPDenIcQnAAYwxXNsacOdyVQu+RF/R8oN9mgZIAI6Q9w1vn5vho0tyqhak"
    "fNDoPw9E9I6rPFgCcIQq3/CBziwfX5ajRRJgy2jCk/3KAiQAh8h4hg8uzPIfF2Sdv+gHQ8vz"
    "w7EWAyUAt6gODH+wJMsbHH89GFnYMJyoYYgE4B6tOY+7l+edP2ugazTROQISgJtc3uzzvgVZ"
    "p8egezyhezxxfpuwBOAgNT68Y16Gy5vdnQpEFp4bjBly/FhBCcBBjDEsrfW4cXZA3uE7YMNI"
    "zHCkDEA4SJVvuLI5YHGNu7dA12jCqAQgXGVFnUdntbu3wP7Q0l+0Tp8qLAE4TGvO0ORwYVBs"
    "YdtYgssvAyUAxy++63WBW0cTXO4UJgE4zKHQMlByew68a0ICEI6yYzxhj+PVcHsnNAUQDhIm"
    "ln8aiNk25rYA9ofW6S6BEoCDJNaybijmL3cVGXZ8U9xI5Han4EDh4A7WQslanh9KuPX5AuuG"
    "tBlmsOR2BiABpDrgLWFSboIxXLIcDC3/91CJz2wNGShpfKB8ZgASQHp5YSjm6QF3r3J/KeFg"
    "wdI1lrBuMGZvwaLnvnBGAFvHYn5v3YSutBCTkPpFwKtnBeS01CmEmwJoyhquaNIBGWJy2rLG"
    "6WpIz4U/8DfbM7rTxaTkfSSAtPP6WT61SgLEJMzNexgjAaQWYwzz8h6vaZABxMtp0RQg/dQH"
    "xun2V+LEdFQZPGUA6aYmgMsaA7J6GyCOY1G173Q9vOfGH2lYWmu4WCfliqOnh8Dqek8ZQPrX"
    "AaAj77G6TtMA8S80Zgxzqzw8h1cBnXkkzsoaVtf7VCkJEBWW1XrUBW73RHImHALPsKrOY64M"
    "ICqsrvOod3w7nFPRsKLO54IqnY4ryvP/Sxp9GjLKAJyhs9pwYb1PRg5wnvlVHstrdS84JQDP"
    "GC5v8mmUAZxnVZ1HZ7XBGGUATvHaJp/mrATgMlmvnP5foPUg9wTQWe2xrNZDCnCX9pzhskaf"
    "vK+7wDkBBJ7hjS2B08UfrrO4xuMKlYa7KQCAG+cEWgh0lFof3tyWYXZON4CzAlhW67O0VvM/"
    "F+mo8nj73MDp6j/nBQBwXZsaIrvIb7VnWKLmEBLAW9oCtAbkFo0ZuHlBVgMhAZSrAjurNQ1w"
    "ifdckGVRjawvAQB1geH1Wgl2hkXVhvcvzOr1rwRQpsaHa1o1DXCBKh9uX5JjcY3nfOWfBFAh"
    "4xmW1Xp05HVDpP0Gv7Y14Pq2QIU/EsCxtOc9LmnUNCDNLKw2vHd+loU1Wu+RAI5jds5wSYOv"
    "M9JTPM17+7wM17YGBEr9JYDjyXuGFbUeraoKSyWva/K5fXGOepV9SgCTYQxcWO+zXFWBqWNp"
    "jcfXL61Sya8EMDWd1R6LazwNRIroyBseWp2ns8bXqr8EMM08MTC8psFXmpgS5uUNa5fluG62"
    "Sr0lgJPktU0+rWoSMuNpyRp+vzPLuzqyVOmVnwRwslxU7zNH9QAzmoYAPtiZ5QOdObV8kwBe"
    "4TTAN/z6LDWInKm0Zg33rcrzieU5mjIGTfslgFeEMXD97Aw5jcbMum7A4mqPh1bnuW1Rjpyn"
    "4H+laKWkwqUNPi05j9HxRIMxA8gYuLLZ5yNLcrxVC34SwKlSGxjeMMtnpwRw3lMXwNvaM9y6"
    "KMtrGnwyavCoKcDp4Hp1CTrvmZMzPLAqz/2r86xpVPArAziNXNUSUBvAaKSxON/m+tU+vLkt"
    "4MFVeTprPLIKfAngdNMQGN7UEvDD/TLA+RL4s7KGSxt8bl6Q5cY5AdWBAl8COEPk/HIWIAGc"
    "e2Zlyx2bbpiT4cbZgU51lgDOPFkDaxp8mjIwUNJ4nG08oKPKcHVLwG+0BlzTErBAfRslgLOW"
    "chrD3KryCcJP9scakLOEb+DKJp8b2wOuaA5YUuPRljP4eqkvAZxtWrMev9YgAZzJp7xvytOt"
    "lbU+188OuGF2wKIaj7rAkPPQDj4J4NzRlDVc1uRTH8CwlgJObUrllbvyVPuGmsDQkjVc2ujz"
    "xpaAy5t85uY9ndF4HgjAahiOZVGNx5Iaj2eHVBQ03dM855WLqGqD8r91lU9DxtCRN3TWeCys"
    "8lhc67Go2iOnXXrnnQDGNQzHCaDaY0mtn2oB5DyO2TLrUT4rwTPgmfKTOzCGKh/yvqHah5xn"
    "qAvKT/SXAr0mgMaMOfJpyhias+WnvWrzZ4YARjQMx9KSM9yxNMdN8zLpvfCmnKK/hKEc6Iay"
    "ALIe+MaQNZDxKh9jyPuQ9Qx5r/yvUviZL4C9GoZj8Y1hTaPPGrUMF+nmWQ/YBuittxBuUQK2"
    "ecB2YEzjIYRTjAHbPWA9cFjjIYRTHAbWe8aYQeAZjYcQTvGMMWbwpXXg7wGhxkQIJwgrMX+k"
    "Icg/A5s0LkI4waZKzB8RwB7gEVQVKETasZVY3wPl+o/yV629APgl0KkxEiK1dANXG2N6j84A"
    "AHYD92h8hEg191RinWMygEoWkAMeA649/ntCiBmf+v8U+E1jzJEF/2ParVS+cXslTRBCpCv1"
    "v/3o4H+ZACoS2ADcCQxozIRIBQPAnZXYZkoBVHgUuA0Y1dgJMaMZrcTyo5N9c1IBGGNeelVw"
    "izIBIWb0k/8W4JFKTJ+cACoSKAHfrfyCblQjIMRMwVZi9hbgu5VYnjzOT+q3WXsx8EXgKo2t"
    "EOc9TwC3GWNemO4HT6rpeuUXXQe8F9ilbECI8/Kpv6sSo9edTPCfdAZwVCZggAuAfw+8C1iO"
    "OgsLcS6JgC3AXwHfAXpPNN8/ZQEcJQIPmA9cAbwDuBRoAmpQAZEQZ/pJP0Z5ge85yrv6/gHY"
    "ZYx5xV1sT0uwWmvbKxJYVvl0VGSQ1/US4pQpVIJ+N9BV+TxnjNl3qr/4/wPcwM3my1EgggAA"
    "AABJRU5ErkJggg=="
)


"""Skyperious application 256x256 icon, 8-bit colour."""
Icon256x256_8bit = PyEmbeddedImage(
    "iVBORw0KGgoAAAANSUhEUgAAAQAAAAEACAYAAABccqhmAAAUEElEQVR42u2de2xcVX7Hv/c1"
    "dx5+jmPHdsiLiRM7jzWbpDwURBciLaB2W5JFYltQtVG7bFsQS1sQdLNaHEFQ2IAoUhC7EtqN"
    "VBChQpvtthWsulnQ7gaalg2EBBzHGfJwYjtxPPFrHnfm3nv6x8QhTmzP4CTO+JzvR0IkCBFz"
    "Z87n/H6/87u/o+EKIoQQuMpMwx9BCABA07RS/bmu2A9mlvqCJ4RMvu4uRwgmFz4hcghhKiIw"
    "ufAJUVcEOhc/IXKnCJcVAXDhEyJvNKBz8ROibjSgc/EToq4EdD4eQtRF5+5PiLpRgM7FT4i6"
    "EmAKQAhTAO7+hKgYBehc/ISoKwGmAIQwBSCEKCsAhv+EqJkGMAIghCkAIURFzJnwQzJDIaX0"
    "vSvVUWFTigCY/xOibh3A5GMofVLeF7/OeHlfp72x/07GH+vxrC/3M6kJaKizNX45VEgBVFnk"
    "Z7MCQ65AyhMYyAmkPWDQFTiZ9nHGEUj7wGBOIOMLDOcERrz87wEgkRVwzkkg4wNJT+7n9dDC"
    "AJ5bFkTY4HeHApiBi/1YysextI+ejECf46MrLXDKyf9+MCeQyAoMukL6hTxVDo946Mn4iEVY"
    "x6YAZsiC3zvoYd+Ah6PnFn5vxsdATmDQBVxWYr6cAJI+jqYoAAqghGkf9vEfvTm82+ficNI/"
    "H9JzV798eh2BeNLH2lo+CwqghHb6noyPXX0ufno8h0+HPDg+d/erQdID9g/5SGQFogEWAymA"
    "a8hpR6Az6WPHiRx+2ZtDV5orfjr4eNDDKYcCoACuEYmswPsJD7867WJndw7dDhf+dAugO+Oj"
    "pZx1AApgmtmd8LDjRA7vnMrhWFowzL9GaQDrABTAtOf5r3VlsbXTQa/Dgt615td9Lh6YG2A/"
    "AAVw9dk35GNzRwZvn3K58EuE9/s9jLgCYYN1gKnA5KnIXf/1EzncuyeJt7q5+EuJbkdg/xA/"
    "EArgKpHICmz73METBzKIp5jolyK/OuXyITAFuPKcdgSe7nCw/XiWu34J88FZfjiMAK7C4v9B"
    "e4aLfwZwcNjDSfZeUABXipPp/OJ/40SOi38GkPGB9/qZBlAAV2jxb+rIYPtxLv6ZguMD/5Pg"
    "h0UBXCYpD3gp7uCNEzk29swgXJHvCkxk+aFRAJfBa11ZvHKUOf9MpDfjo33E54OgAKbG7oSH"
    "rZ0OF/8MZSAn8Cn7ASiAqXDaEXjmIM/5ZzL9OeDDAQqAAphC3v90h4NdZ/jlmem0D/toH2Ya"
    "QAF8Cd45lX+jj0U/OeoA8SQFQAEUSTzpY8fJHEN/WQTgCHw2zEiOAigy9N/V5+Jt9pFLQ9LL"
    "DwvlcSAFUJCzWYFtn/PIT8Y6wClOZqIACvH6iSwOsGAkHR8PejiW5udKAUzCaUfg5SNZfvqS"
    "pgGfDHpjrlMjFMAYth/PoifDMFFWPhzwzt+hSCiAS3b/n/e4PPaTmPf7vUsuTyXjo9xAkP/u"
    "cxEf4bdDZrodgYMjHuaErs7XWwh5dg+lIoCUlx8f1Z/jIpEdjgmjAC7ho0EPHw9y91eB35yh"
    "ACiAi/h0yMORFI+IVKBjxOeYMArgCxJZgQ8HPDb+KILjA3vOMgqgAM7RlRH4ZIi7vyq4AniX"
    "b3hSAOcFkPI5MEIxPki4bAgqgCnTkcZEpDzgs2GG/6rRlxX4IOFibS2vv1A6AhhxBafFKEgi"
    "K/AHfu4UwLArcJAv/ihH0gMODPlMA1QXQNYHj/8U5UjKR0+Gn73SAognfeb/itKb4ZxA5QXA"
    "MVHqcizNMWHKC6CLHWHK4op8HeA0pwSpK4DDfPtPaQ4lffRQAOoKgB2hahMf8dDFIrC6AmAV"
    "WG36c/k6EI8DFRWAx/WvPB8OeBjhGCg1BdDN/E953u/3MEwBXAKbpBWkxgJiZQaqTaDW1lFp"
    "aQgpsBUEdY0fPgWgLnNDGv6s3sLtswzMD+uosjRUWxqChoawwedDARBpWRM1sHGJjRurDEQD"
    "3AmJQgIwNSg9BvzGagNblgWxJsptnoxFiSJgncI7XsQA1jeYXPxEXQGEFP7uRwMaB2IQtQVQ"
    "H1T2DlRUmhpayrn7E4UF0BBUu+jFCj9RWgALQrrSHzJbYInSAlhUpq4A0p7AMb4IQ1QWwLIK"
    "dWPggZzA7/r5OiRRWAD1toYaS80PeNAFft3nIpFlHzxRVABBXUOzopVwVwB7znp4j5dlElUF"
    "EDKAlnJ16wBdaYEdJ3OIJ1kLIAoKIBrQsLpK7bOwX/S4+MmRLE8EiHoCAIBYREejrW4/gCuA"
    "nx3PYmdPjt96op4AGoM6VlSo3Q/QnwPa2jPYnWAYQBQTwPywjkVlbImLpwSe/DTDyzKIWgII"
    "G8CKCl3Z48AL2XPWw1MHMywKEigVE6+qMhBjFABX5IuCmw46OMlLUygAVWgpN7A4osPkQBy4"
    "AthxMoctnQ5vzaEA1EkDbq81UcnX489LYPvxLJ7vdHg8SAGowddrTcwP6/zkz5H0gFeOZvFa"
    "V5YPgwKQnzkhDXfMYghwsQQ2H3Lw+gn2CFAACvDdhQFEWAscQ1daoK09g593UwIUgOTEIjrW"
    "NfA88GLiKYFnDzl45zRfHKIAGAUoyd5BH5s7HHYLUgBy01Km4+7ZrAWMx+6Eh2fYKEQByEw0"
    "oOGv5gbYGTgBu854+OfPMjwepADk5cZqA+saaYDxGO0WfHR/mhKgAOSkztawvtFCLMzWwIkk"
    "8MaJHNraMxwpRgHIyW01JtY1WCwITkDSy88RePVYlhKgAOQjbAD3zwtgSRm7AyeiPwe8fCSL"
    "t7pzTAcoAPlordDx4AIeC05GV1pga6eD3/SxR4ACkJAH5gZwK2/QnZR4SuChT9IcJkIByJkK"
    "bGsNYW6IBcFCkcB9/5fCviFKgAKQjFhEx8bFNlOBAhwY9vHkgTQlQAHIxz0NFv7iOotDQwqw"
    "64yHzR3sFqQAJKPO1vDQ9TZuqmYYMBmuAN4+5eK5TofHgxSAXLRW6HiiyWaDUAGSXr5RaMsh"
    "hw+DApCLP6038f0lQb4rUIQEno9n8SOOFaMAZGPDPAsb5rE/oBi2djp48yQbhSgAyXhysc2i"
    "YBH054BnOzLY2UMJUAASEQ1oeKLJxrfmUAKFiKcEXjzs4Lf97BakACQiFtHxT0021s5iLlCI"
    "vYM+2g467BGYIWi+7/MMp0j2Dfl4eF+a47KKYGWljjf/KIxYhHsMIwBJaK3QsWVZECsr+diK"
    "iQQe3pfm1WMUgFysiRp4ZmmQ7wwUwa4zHjZ1ZCgBCkAu7qoz0dYcRKNNCUzG6EShl+K8f5AC"
    "kIz75lj4YbPNRqECjE4U2n48y+NBCkAewkZ+hsDjTXx7sBD9OTYKUQCSSuDh6238HacJFSWB"
    "Rz5JY2cPrx6jACSTwGNN7BYsNh1oa8/w6jEKQC7qbA1PLQningbeNFSIeEqg7SCvHqMAJGNO"
    "SMPGJUHcWctcoBB7B/JXj7FbkAKQitYKHT9oDuJGDhOZFFdwohAFIClrogY2t9jsFixCAm91"
    "u9h00GGjEAUgF2trTXx/MScKFcNrJ3LYwrFiFIBsrG+00NbCiULFsP3c1WPsEaAApGJdg4XN"
    "S4M8HixA0ss3Cr3WRQlQABIx2i346PUBSqAAo92CbBSaXjgPYBpIZAW2HHLwytEsktzhJmVu"
    "SMOLy4NY38jciRGAJEQDGr4Xy3cLsmV4crrS+UahXbyElAKQiTkhDf8Qs3H3bJPpQAEODPvY"
    "2M6xYhSAZLSU69i4JMhbh4rgf896ePJAmo1CFIBctFbo+JcVQfYIFMGuMx42HeQwEQpAMlZV"
    "GfjxDSFKoACuAHaczOHpDkqAApCMtbUmnlvGSKAYCWw/nsXz7BakAGTjrtkWHm+yOWC0AEkP"
    "eOVovluQUADSMNoo9NBCThQqRgJbOx387DgbhSgAySQwOlaMTM7o/YOcKHTlYCdgiZDygL/9"
    "OI0dJ3Nw+YlMyspKHS99JYQ1UYZNjAAkigSeX54fK8ZGocnZO+hzohAFIB91toZNzUGsnWVQ"
    "AgXYdcbDC50cJkIBSEZLuY5nlua7BSmBiXEFsLMnf+sQXyGmAKRiVZWBtmYbzWX8eCZj9NYh"
    "vkI8dVgELOUwt8/FPXtSfIW4ALGwhl/eHEFLOYXJCEAi1taaeGN1mJeQFiCeEvjH/byKnAKQ"
    "kDtqTfyw2aYECvD7hIeX4mwXpgAkI2wA9zZaeCQW4IDRAvWAN7tzePu0y6IgBSAX0YCGb88L"
    "YMM8tgxPRlda4MdHsujkDAEKQDbqbA2PNXGiUCH2nPXw6lFOF6YAJJXA9pVhrJ3FMGAiXAH8"
    "5CiPBikAiWsCr341zD74AhJoa8/wVIACkJM5IQ1blgUpgUmIpwS7BCkAeVkTNbBxCS8hnYyd"
    "PTn8tp+vDlMAknJbTf4SUk4UGp9jaYGfHstyniAFIG89YH2jhWeX8hLSiWoB7/a5+AULghSA"
    "zNx/Xf4SUkrgUvpzwM7uHNqH2RtAAUjMA3PzjUKUwKX8PuHhd/3sEKQAJE8HHmuy8a3r2C14"
    "MUkP+NeuHM7yPQEKQGbqbA2PxgJY12CxW/Ai9pz18F+nWAugACQnFtHxVLPNsWIX4Qpg2+e8"
    "V4ACUEQC21pDvIT0Ig4M+/jPXvYFUAAKSWA5p+SM4eXP2R1IAShCa4WOZ5cGKYEL+GzEx0eD"
    "NAAFoAh31Jp4gt2C50lkBf69m8VACkARwgawrsHCxsU2ewSQPxLcP+TxTUEKQC0JPLgggMeb"
    "KAEA2D/k4z2+JEQBqMbD19vYMI+XkJ7OCuwb8FgMpADUiwSeXGwrP0fAFfk0oCfD9wMoAMWI"
    "BjS0ccw4Did9HE1RABSAgtwSNfGX16ldDDiWFjjOQiAFoGoqcP+8AG5UuFPQFcDeAU/5i0Qo"
    "AEVpiuhY32Aq/ebg4REPacULgRSAwlHAqioDC8PqfgX2D/kYchkBEEVZUWFgTlDdYuDprEAi"
    "RwEQRamzNdTa6n4FXAEcGvEpAEJUpX3IowCIoiGwI9DnqL0D9jpC6Y5AU9OmNwcUgmevpUJn"
    "0kef4sdgR1JMAYiCpDxgd7+LDsVz4N4MBUBUzH2HPfzbyRySip+Dsw+AKMcfBjw89EkGewfZ"
    "Cz+oeB+AyeUgf6if8QTSHtDr+NjV52Jrp4N+DsUBAOUjIOkFsG/Ix94BdT/lPsfHGUdg/5CH"
    "z0Z8dPEFGKKSAOIjHv76ozQ/aUJUrAF8bZbJCzIIUVUA0YDGCzLIhKg+I1GJU4Bv1LPWScYn"
    "rHh4qIQA1taavDGXjEtDUKcAZKfe1nFDJQ1ALqVa8eBQCQFUBzTcwjoAGYdFZQbCBgUgd55n"
    "AK1VvC6bXIrqV6YpkwA1l+lYWcUogIxlablBAahheh2LI3z1gXxBjQXMDbMIqAR1toblFTpP"
    "A8h5YmUGyhT/Piilv6XlBuptFgJInq9U6Ki2WANQhpZyHYuYBpBzrK4yEA1QAOqEfBEdi8p4"
    "GkDy1f8YNwP1BoLcHDVQyc5g5VlapmPBNSwAappWEn+pJ4BqA1UWQwCVMbX8pSiqtwErGQHE"
    "IqwDqE5DUMPNUbU7AJUVAADcXssZAaqH/7fWMA9UVgDfbLRgMwhQkoiR3wDqeBysrgBiEV3p"
    "W3FVpt7W8M1Giw9CZQEAwF11DAFVZF2DxeM/CgC4czbrACqG/99dGOCDoACA5jID80M0gEp8"
    "e16Auz8FkCdkALdEmQaoQiys4e+5+1MAo0QDGo8DFQr9H2+yMZ+FXwrgQhaX6WgI0gCyc2vU"
    "wNpak40/FMBY6m3eGaBC6P+dBcz9KYBxaAjqWM0xYVKH/usaLNw1m+f+FMA4hA1gTkhHI7vC"
    "pA39H2uyGfpTABOzstLAQoaHUob+21pDbPmlACZnflhHS7nO0wCJmBvS8OKKEPN+CqC4NGB1"
    "FYeEyEKjrWHjYht31PIDpQCKZFkFh4TIQI0FPBIL4N5Gi3k/BVA8X600UM/pMDOaiAFsmBfA"
    "38wPKD/okwKYQhpwSzWHhc7knf+F5UG0tQS5+CmAqfHnHBIyI4mFNfxoeQgPLggw7KcALjMN"
    "4JHRjMHUgDVRAy+uCGHDPDb6TPk58hFckAZETcRTOT6MGZDvr2uw8L1YAKvYyckI4Epx52z6"
    "sNRptDW8sDyI55cHufgZAVxZvlZjImIASY/PohR3/btnm9jUHERLOfctCuAqUB3QcPdsE291"
    "u3wYJUKNlW/U+s6CAO6azfN9CuAqs7rKoABKaOGva7TwJ7MtzOH4NgrgahM2gFVVBmosoJ+1"
    "wGvC3JCGP64xcXutia/Xmlz4FMD0siCso7ncwO4ECwHT9iXUgJuqDXyj3sSaGhNNEZ1v8VEA"
    "16gOYGm4pZoCuNoL3tbz72DcFjVw33UWFoZ1BA2NOT4FcG2JBjS0Vhk8DbhCC73SBGxdQ8gA"
    "6oM6bqg0cPssAzdVM7ynAEo4DVhSpmPvoM+HUYCIAQR1oMrSEDI0VFoaygyg3NKwIKRjUZmO"
    "xqCOWETH/LDOHZ4CKH2aIjquj8gtgNHd+ULCpobRd2lChoaAnv972blFW25pqLK0/I6uA7Ps"
    "/O8tXUNtQEN1QEOZqWGWlf91qS92TWMEogkhxHT+gdP8x02ZfUM+4iPy5gABXYN5UT9N+QWv"
    "Q46+HW3qeSkEdCCoa7D0vDxkyNcpAAqAqPzlpwCgnVuUSqxKyodQAGP+/zU2VROiMBQAIRQA"
    "IURZAWishhCiXP7PCIAQRgBjjUAIUWP3ZwRACCOA8c1ACJF792cEQIjqQhjvHwq2zE0JPrYZ"
    "txsqvftPGAEwFSBE/sU/aQpACRAi9+IvWAOgBAiRd/EXFAAlQIi8i78oAVAChMi5+IEvMRJs"
    "9D/IEwJCZv7C/9ICoAgIkWfhT1kAFAEhM3/hX7YAJvoBKARCSnfBX8z/A/eNjTMdI58pAAAA"
    "AElFTkSuQmCC"
)


"""Default avatar image for contacts without one."""
AvatarDefault = PyEmbeddedImage(
    "iVBORw0KGgoAAAANSUhEUgAAACAAAAAgCAYAAABzenr0AAAABHNCSVQICAgIfAhkiAAAAAlw"
    "SFlzAAALEgAACxIB0t1+/AAAABV0RVh0Q3JlYXRpb24gVGltZQA2LzIwLzA4DqTMIgAAABx0"
    "RVh0U29mdHdhcmUAQWRvYmUgRmlyZXdvcmtzIENTNAay06AAAAF/SURBVFiFzZfbioNADIZ/"
    "t0IKgoKlhfoMQt//MYT2oiBYKFgYITCCFwMD7ZVlD27nZNf9wStj8mmSSYz6vr9jQX0sGfxf"
    "AMQ+D0kp0ff9V0dxjO12izh2cxm51MDtdkPbtlBKTd4nIhRF4QRiBaC1xuVygRDCyikRoSxL"
    "EJHR1qoGqqqyDg4ASikcj8dfv5QTgJTSytEUxPV6DQPQWuN8PjsHHyWEgJTSH6DrOmitvQEA"
    "gJn9AUKDA/jRrk4Ac2gYhmUBkiTxB3A91Xx8vAQw0dtotVr5A5jyZ6OgFDRNEwxgOozengLT"
    "PHgJkKZpMEBQCjabTTBAlmX+AGmaBqWBiJDn+Usbq33gdDoZh8p3JUmCw+FgtLM6CU1vMSXb"
    "+nkbwG63mw+AiJxqwcXeehi5zIX1em1tayzCYRgghHBeTrIsw36/9+sCpRTatgUze+2Dn2Va"
    "1Z8ASikwM4QQswyhKeV5/rxGmKiu63vXdc59PhdMXNf1nwYexcxg5uV/Th+5hK9m92rw1QAA"
    "AABJRU5ErkJggg=="
)


"""Default large avatar image for contacts."""
AvatarDefaultLarge = PyEmbeddedImage(
    "iVBORw0KGgoAAAANSUhEUgAAAGAAAABgCAYAAADimHc4AAAABHNCSVQICAgIfAhkiAAAAAlw"
    "SFlzAAALEgAACxIB0t1+/AAAABV0RVh0Q3JlYXRpb24gVGltZQA2LzIwLzA4DqTMIgAAABx0"
    "RVh0U29mdHdhcmUAQWRvYmUgRmlyZXdvcmtzIENTNAay06AAAAQ2SURBVHic7Z3NauM8FIbf"
    "TgQqCGpQiMEFQ70L9P6voFeQRaALQwMODSggsMFQgUO/xYeHgWlnPI2PjuTqge4aydZjSUc/"
    "lm+6rntHgo0f3Bfw3UkCmEkCmEkCmEkCmEkCmEkCmEkCmEkCmBHcFzAF5xze3t4AAJfLBX3f"
    "//X/siyDlBJaawgR7m0Ge2Vt2+J4PKJt2y/9vus6AIAQAmVZoiiKOS9vNm5CmwtyzqGu6y8X"
    "/GdorVFVFaSUs6Z7LUEIGIYB1lp0XQdjDGleSikURRFM08QuoO977Pd7DMPgPe88z/Hw8MAq"
    "gjUK4ix8ADDGYL/fwznHkj/AKGAYBjw/P7MV/kjf99jtdp9GVtSwNEHGGBwOB/bC/xUhBB4f"
    "H6GU8pqvVwFUEc5cKKWw3W69RkreBIxVPQaqqvI2bvDWB1wuF19ZXU3TNN7ySnNBHzAMA/l4"
    "ZMSbgNfXV19ZzYKvWuBFwMvLC6y1PrKaDeecFwnkAqy1OJ1O1NmQ0DQNecRGKmAYBtR1TZkF"
    "OcfjkTR9UgFN0wQ12PoKbduSjpLJBAzDgPP5TJW8VygjIjIB1tron/4RygCCTADnDOPcUN5L"
    "EjARqn4gCZjIuMY8N2kqYiJU44EkYCKpBjBDFdElAROhWrgnE3B3d0eVNAtU95NqwES01iTp"
    "JgETybKMJF0yASHsOpsTqoV6MgG+t3fEShLADJmA1Wq1KAlRDsSWJCC6PgCgu2jf5Hkep4Cl"
    "LMhQ7pJLS5IToKzJaUlyArvdLr7JuFj3An2Ec47sfsgEcL3wQEV0nfBSIqCR29tbknTTSHgi"
    "0U1HU03fckD5MJEJoJq+5SBKAVLKxTRDUQoA/h/CL4FoBSylH6Bc3yafjIs9HKVuRsnXhKni"
    "Z19Q7+4gFxD79pT1ek2aPrmAmPsBKWX8NUApFe2YoCxL8jy87AvabrdRhaRCCFRV5eWavR7W"
    "wX0+0BR8H9jhdWecUir4PoFy/fcjvG9NDH1c4Hv6JO0N/QUhhPew2buAkCfoOJpH7wJCDkk5"
    "Dnf1LmC1WgXZEXNNn7P0ASEK4LomFgHr9Tq49weo53w+g0VAaM0QR/QzwhaGhjQe4HwY2ASE"
    "FA1xPgxpIAbeh4FNQOwLNXPBenh3KIyfPeGATcDhcODK+jfqukZd1yxH7HhfDzDGwFob7HlC"
    "WmsUReGtXyAX0LYtrLVBF/pHSClRliX5p05IBIwFvoS3ZIQQP2sFxVzRbAL6vsfpdFpEoX9G"
    "lmXYbDazrhVfJSCGNp0CIQQ2mw3u7++vHsT9swDnHKy1MMYs7jWkr3DtZ7EmCRi/83U+n4P9"
    "/EgIaK1//k2V8UcB45Me29HzITBVxm8CvkNn6ps/ybjpuu7dOQdjDIwx36oz5UAphTzPobWG"
    "lBI3T09P76kz5UEphR+p8Pno+z6tB3CTBDCTBDCTBDCTBDDzH7726OxO0Z6SAAAAAElFTkSu"
    "QmCC"
)


"""Small icon for clear list button on start page."""
ButtonClear = PyEmbeddedImage(
    "iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAYAAAAf8/9hAAAAGXRFWHRTb2Z0d2FyZQBBZG9i"
    "ZSBJbWFnZVJlYWR5ccllPAAAAgdJREFUeNqkk8tu00AUho9nfKnDJU5j5NoJkTB20+JU3ZR1"
    "F+xaKhZIkRCSAYkdL9CqEgtW9B14BVa8AiyQQCELJCRUFUgXMZAKqOPY8WWYsZISaFohdaTP"
    "njnz/2c84zMcIQTO0rg3L7iT5oqUZ6P+Q8rPaSJ0SvKmbt2zdcu1Wf8kEcoygH+hu7qMhdKa"
    "Vru5qNXWF7GgrLHYNO3UBBTXsN0GCT+JJPwsGtbdBov9VwK60rJ0rrZaKjfM7Z2vsL3zDZTy"
    "NVMqVFfZ3LEEKX1MwMYPKtYdJ/I/oiAIgDHs7yH9yi2HzY00Rx6UpTTTCJLBjQuKsyLLRSON"
    "f4Hv+zlp7EOhoBjnL1orTDPp4dP06EBlDnGucXXdiYMvMExDaLVa4Hke7D9ahozsAj9bd9Le"
    "rksy8pLqB/lfiBMABv2c2+W560sIRUpv0AGvvwftdhu63S6kQghEjADESJGK1SWmHfsQK0SK"
    "CpzYVKuN+d7hW4izHgg4gu/ekxwRD3Mw50NR1+YJ4CbzMC9K6BboNu6rlfpCnH2QeeSDhMMc"
    "VXucMx4zZCmRS3OXFpiHeVGSgIUFaUOrzJgC/IAZutKYcZuMMfSqYiKe32BePgjIlllXbREf"
    "YkLYif65XMHBZv7uHzz/u34xYKM2a79/523xwQCi16/2OzTcOV7pT0+/iRxE3Fmv828BBgCY"
    "syym9ECFNgAAAABJRU5ErkJggg=="
)


"""Small icon for compare databases button on start and merger page."""
ButtonCompare = PyEmbeddedImage(
    "iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAYAAAAf8/9hAAAAGXRFWHRTb2Z0d2FyZQBBZG9i"
    "ZSBJbWFnZVJlYWR5ccllPAAAAu9JREFUeNqcU99LFFEUPndmdmZd3fXHqmlrta6SYZnmSNhv"
    "I4l8UEjIeuihJx+iQAj6E6K3giDaoAjaHjPYCipLkyIoEiuTLNx2Ze2Huq7uOrPj3pm50xld"
    "o8fqwjf3cufc75z7ne+StpszAITA2rAYA9M0QVMUEBwO4Hh+ZV+UJAwjQVy+MAwjZOg6GJSC"
    "AH85dDzAcZyMSzm3FbI/NsEZsKxqnNOIKOIVYjIXJFuW1Y3zdss0yxlWdrStSr73fLoPz6yQ"
    "CFhOzbH2ykBaNfUfieXA5ymlBeOeYYCfJ+xUfcBTvs7rKnSKvJMA4RMJCh2tFXJ4eKoPCRKC"
    "fRdUgLN0kLwuUdrXUOx5+nr6nNvF+/e3+Cp0Cg6TWqCDhRpYQKkB2awAeja7UqKAQkT6B2KC"
    "31dQUFmS741OLZUay1rD7p3+AlUxeV4A9jWe+B6NLybVDNW7DtXL/Y8/jqCgl3mH4xFpvDhm"
    "67AJ73q4tNjZrKSWOrfWVRZLoiSazLDejce/zCczg4TjgtihG3ZW+7BDkkKCKAIJnB9elYsQ"
    "nhlG2Ocr2lvsr/QsaRQy8Zn03JzykhOELowwEccRNYgLa93h0smkiGhWFhauiHl8jVpd7R6l"
    "EqgapTMLasbj9XzDuF7GTLtTrYgyrPYg1TRQUyngHdu6r3rceWfL6jY2ppua/FHm5Eo43Uy8"
    "GVO1zVsmeH+V4CRmCVUysqEtswM9e2ojoxGbhDLGYiT/xO23Had75AdpEXRsbZmp6XRg8CeH"
    "P6Uj7fOzxClw2Ca3A8CDasVUgB1FAPE79ydXfKCjHSeymEJNZlk0tph6/2mWUXrL5XbHMg+f"
    "HPLW1Rbq630uw10gLnMCx5BMYwA010bCdwWDWE4TrucQH1Dhu7wgjCABoEdqUflduG/fv9DW"
    "bEPvydr49dAkxoVR3CHCdV5D01m/PY9+BySAHAGYhrH6yDAGrXwp18YwPrQh9ME/PKbVkiOI"
    "cUwwtLZP/sz+P+OXAAMAj/dc2TUqu0UAAAAASUVORK5CYII="
)


"""Small icon for delete database button on start page."""
ButtonDelete = PyEmbeddedImage(
    "iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAYAAAAf8/9hAAAAGXRFWHRTb2Z0d2FyZQBBZG9i"
    "ZSBJbWFnZVJlYWR5ccllPAAAAhFJREFUeNpi/P//PwMlgImBQsACY6xiZPQAUi1Q7vF/DAy5"
    "v4GMH1BFbBBam5GBIRjINALibWH//8+CGwBU3BJRUmL84/v3/zdPn5a8fuqUJdBzJjB5ILuT"
    "gY3N7fevX++AhvQChbaDxBlhYbCAkTENyErTNjeXVNTWlvr57dvvM/v23Xn96lUsPx9fjqiU"
    "lN2DGzeuAzVnszIwPATSDFFAvXAD5jMyMvxiYDAGOj0cyHUyd3RU4hEQ4L937dozdg4OhhsX"
    "L54DOjcdqPkFK8hmHAaA/fwXaBBQwUw9Q0N1BiYm9tvXrt36/v27DiPEK2AgDjUAHgaPENEi"
    "ChSsVZKSkv7x8SPbradPbwjy8vJ/+/Pn0pffv/VAlvwB4lfo0fgDEpAgyRoFUVFTMWZmsWtP"
    "n97++PPnxPtv3pxlZ2XlAspt+4crHYAMAJqeLsHL663GxCT15NOnF29//lwIdPJcoMagR9++"
    "beVhYZEHstt+Q9SiGgD0t/xPBoZUaw4O+e+/fn098/HjeSB/zieg3D+Iy/Kf/PmzFmiREVCz"
    "I4YBQMW5hlxckjx//7Js/fTpPpBfD1T0HqYQakgd0IAzQDmPH9BEiGyAgw07u+SlX7/ePv/7"
    "dwdQ49nvQPHvEDm4IUCX1gD5r4De0ENJSNHApPwfkpTfMgPDAhhlD5BSIQNa4CkCxSSW/f9/"
    "nHHAcyNAgAEAxF3igbzwV7kAAAAASUVORK5CYII="
)


"""Large icon for detect databases button on start page."""
ButtonDetect = PyEmbeddedImage(
    "iVBORw0KGgoAAAANSUhEUgAAACAAAAAgCAYAAABzenr0AAAABHNCSVQICAgIfAhkiAAACIpJ"
    "REFUWIXFl1uMXVUZx/9rrX09++xz2WfmzJnTubXTQlung7SFUrBALQba1JAQ28gDD5qIShQj"
    "gYRoTKiXB0M06oMooQ8KMVpsDJeAJERagXZgqGmBTmnPFDr3mXPm3M8++76WD05rQWmnSOJK"
    "/tkrO2uv77f+37fXyiJCCPw/G/0kH934wFH90wIgl3Ng89ePyQ4p3Uw5v16T2faIi2tDzi1G"
    "SEOi0nE3ig4Jwt9IxOzDR36+x/lUAdZ+7dlhDTiYiem5NZmknjdN1mkaiKsKOInQ9DwU7TY/"
    "U6w6pxZqdZ+TL53av/vo/wywffshqbSy/AMG+tD2gV5ttWWRZquI6ZkCyovTWChOwTSSuOaa"
    "LRgcXIvOzg6UWzYeO/SOa/v+bxxDf7jwq53eJwIge59mQzGMZGP6Z27t7dcJt3Fk5BmcPnsC"
    "WiIdhIgIYYxRQqKo3UJgt6Xurj58494H0NPTjT+9dtJ7bXxmQlONa9/67e725QCkj75Yp3rf"
    "SyvG+h29ffrU9HGMjL4ET1PCZE/PGRLWT7KgPsl4s8iZaQVJs19YPesqjj306C/3sbt234M7"
    "r9+iUiH6Dxcmfwbgm1fkwOov7x9SKHvzi4NX64FTxN9Gno1gxjzmTP+xK+YdTyQMp79/lbR1"
    "69a+RDxuekHARkZG5l4+MtbZ8LWv8rar777tbnrd5hvw0+cOObW2t7Nw4CuHlwWwffs+aT6b"
    "P7mxK79mRUwlR956Hg3iOWk+8ZPebHIuk820EolE+/bbb1+1bt3QDstK3yEEwkajMX7o0KG/"
    "Pv7E7+am7MQPY1w279l7PxxO8MTrIwuaog2e+P099scBXNgHJjqsrRpDd18iRSamxlAn3EtK"
    "tSdX92anBgb7SytXDhTXDl61oOvaO5qqfgAQj1KqJpPJgeHhIXP3HTv87iR+3Qjq0dGRV5BQ"
    "dVxtWWazVd91KQcu1ADxg+uycUvlPMBUaQIKsd9f2UmP5nvzlb6+nkou11W3rFxTVY3J0uLi"
    "BytU6SSl8g1hEAhG2JgWU6cHu2OVui+Pnp74x5YNG24iPcm0fmpu6kYAT18WQCbi1qSiKK1m"
    "BT5Cz9TpsWw228hnu+sr8/3VfDZb9SQpopRGlDb9QqF9UHKcvzBZpnOlUlylciaX6+jsqNWO"
    "TjfbGxuNhpLUdEIF33YpBy6kIAiDzaakIgxDRAKwDPqeZaXtjlymmcnn61KShpIkhYrSDB1H"
    "CbOMBVI6HQSKG6W64nY+l2t0dHS0cmn5ParIrF4vQ2MqgtBbTwjIJQHI3r0siNwulckgRAcj"
    "XMml2IRpmm6HaTkJxkJNU6JuRQmNuhSqqhq0VDVwXTdyXSVSFClSTNMxzbjblZLnqaSg3iyB"
    "hwAVggzs2td1SQBx4EDEBC+23DYI1RCTk2Ez1LOyrIdyXA4aUSQqlUhEqRTv3qSHo6OjQblc"
    "jhKJRBSPe5zzSKTTim8oRtAM1AQlTMQNC23XQRA44twLjyxcNgUkio5V2w0QwWBoXaTmymuB"
    "ELhoQ11Y+Nc8e/bsEZs2bRLA1IcmC+CjVOerFEZDSUpisVkFFfyUuMSBcwHA951XKnYtiKIQ"
    "cS0v8dC8KQgCqRXYMmOMWBYjqqrS6ekEGx8fl8+dOyfJskGllkopZcRedOQo4lKl4d6gKXFZ"
    "cIrF+qIIQ+/Vjwv+IQAOPlpqFN0gcpGKr4ZBV6x9c6x5s+M4WhAEzC35TFUdptm25Pu+7Hme"
    "bNuB1FYUylyZNoKW/urxueGmE+zIJVeyiBPMVOfaIQ+OLAtgznaOOpFbnK7NCCGqMPVh6rq9"
    "33/nzHSuUSolfFVlvh9JxSiSoyiSdd2XfN+QwjCUSpVKbHx8PjN2rvrjrNEta8oKFOtFlFpF"
    "J4y0Fy8F8KGzoGfb/dcQyo5u7d2sp4yNgKihFp52jVTp4bs/v+6lrt5MkzEacq4LA4DneXS+"
    "uWgcePHk1rGJ8qMamJUz1iscMRyZeBXy4siJ02+//tllAwBA7y3ffcRU4w9t7N4U09XVELDh"
    "8smoGUy/ocf85wa6Eye2bcidGzld7i7MlDdUavYtjuPvyqiWakp5COg4vfgeujM1LLz7Andd"
    "f/+JscK9ywYge/eynoWe0aQWv+pqa41hqHlIchx+NCtC0vSbfpXaQZMJEUQKFb4CTTNYmjGS"
    "QhgKFKpnYPuL2DVYRl9vHvufOhjJkvzgibHCL5YFAABDQ/uUqlX7ESX41prUoN4Z7yKMqiCg"
    "ICREyJsghENEFIIwgBNU3CoKtbNIGxy9Zh0xZwrZTArplIU/HHw+1FXtzrdPn31hWQDnW/5z"
    "395MqfTnmKxbaTUViysGM+QYFKYi4D5s30YraPO617CbXlUiC0ea64c3WpIiS7w1j7ioI5tJ"
    "Q1IUPP/S330K6drCxMTYsgEAYM2u+9VWC7dRsC2MkFs5xDCEiAkCjxL6Lhf8sOB4IxDNl5XC"
    "M/eB0gcHhq5X4olMwq9OIq1xZDvSaDs+Ro693bS9xqqZmcbisgH+W+vfdl968rXHagDIkuiS"
    "SDaT2SlJeKJzxYBv5fpyXmUSHQkd2Y405hcqODsxM1Vv+2tnZ2cdIYS4YgBCyPmgbEnykpTz"
    "/YRhrIkZ6uNxM0m7egZ6/GYJnekEujrSOPP+JKq11uhY4YObAfhXdDNaCk6XAqkAYgDiABIA"
    "UgAsAB0N27Yr5fp3GvVaeaIwtsiJjLliGbPFMlb25+F63saUad4BQF02wEUrpxetXFkC0S6S"
    "DsDwowjFxerjbds5Ozs92Q5DzhdKFcwXK5AkKgjFFgDqslPwEYCPC65e9FSX3MmY8dgX4rHY"
    "TlmibQGQIIjc+VL5JgCzV1QDH4GQ8O/8q0tA5yUtuUSXxhNVVZPJeOwuLsRc2HafrLnuLIDg"
    "kxYh8J9/ALuof36MuEgcQLQkDkAIIcQ/AcljIy+SCczdAAAAAElFTkSuQmCC"
)


"""Small icon for export button on start page."""
ButtonExport = PyEmbeddedImage(
    "iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAYAAAAf8/9hAAAAGXRFWHRTb2Z0d2FyZQBBZG9i"
    "ZSBJbWFnZVJlYWR5ccllPAAAAiJJREFUeNqMk8trE1EUxr87GfOYR9KKLUQwCUi6jdK9CkUI"
    "WoluIm5dBQTXroKIZOPWTSGb/A26cCW4EFQU0UUXaRERNTXpJM1k8pyZO56bR5shEnvgm3uZ"
    "Offc+/3uGeZ5HkTk8/lbNMRxuqiRXoiJPHszHA7j5XJ5p9vtot/vw3FcNBoWzTnC4Qh0XUc0"
    "GkUsFkWhcPdBIBCAr4AIx3HQbrdhGMa4QL3ewWDIoao6HNeBFJCgqBHfUaSlB2WAMOgxPhEm"
    "On0BSp8s9KaL3bHmY97Cp1Kp9DKTyWxzztHr9aZWHGIQhqZp5D+GarX6inI//qvAZrFY3J6H"
    "WD800R2MEAwFoekqYgTx+s072YeF++IGPvwX4p/DNrqjESIEzuYr+L63i57VQbPZ9ETOQoFF"
    "iCfeOXNhHrWQvZelaywIdpdJn5dC5NwBtwfoHTXxs1qFbdswDgzsG/vP6fM1YZvNOjGXy20m"
    "EonH8xBt18bq2iqSF5OIX4hD0RXfBulz6UfyyW58AeKPXwdotBrY2/2GL++/YtgfYOv2FtbP"
    "r2NjbaPIGHtzbMGyLG8GsVarkX6j2TZgOX2cOasieSmNEQGdLn5KS16T3h2fgKjKS5uJpK5o"
    "KD8rI5VKtTqdzlvfLVABRZblcbMEg8GxhUAoAmVgQgoxqFoEV25cHfdCpVJhItdXwDRNgyA+"
    "cV1q1wlYJkQhHpAkSYyemNOfaIhRxF8BBgAPDR3S0EHTJwAAAABJRU5ErkJggg=="
)


"""Large icon for import folder button on start page."""
ButtonFolder = PyEmbeddedImage(
    "iVBORw0KGgoAAAANSUhEUgAAACAAAAAgCAYAAABzenr0AAAAGXRFWHRTb2Z0d2FyZQBBZG9i"
    "ZSBJbWFnZVJlYWR5ccllPAAAAp5JREFUeNrsl01oE0EYht9NNj8btMWIhHopEhAKRgURBC+2"
    "0uLFU/HkwYMIUhEUBIMpPWlBFHtS9CB4F48iNl5r8dTSnmKjCFYpHpL2EJP9m/Wb2Z+YH2M2"
    "0c1BlwzfZjOz3zPv+81kV7IsC4M8QhjwIb+bl8SJJPkfzMdIdsxQmP5N9xck9jrXm4vuCi//"
    "gUkcpptNp6fuzqGDnR/yWcFKba1Bgb6TA+cOnrk3m8hch2oYqOm6iCpFzTRx5XMKlYqGV5OY"
    "K+azruVr7QAuUjvgJzuf8NjZhdyuQ9dgULJOx8kvM1iaxOzGolDiOLWnwsa3tz3/7xy78OwW"
    "v6vlmCQiYyI2XGuKJs3WoFmL7y4Z6ma7xkRkWfQvvM7O09ecUMDpe4nDFFdXfekfVxQMJ5OI"
    "UZSj0Y6QDUAWpAYL6EL6xNXnNy3T8AVQrVTxaWUF+0dHoSQSnlLSL6KrDAVv+cvMvhZihg6m"
    "qr4AomEJY+OnsJ5/g72pFPaNjLTY1g6GcoZsq+oAksUHMdP3MjB2ysicnsD75WVsbW52NYbZ"
    "Flwmlscy5RUKWCYBmKyntahvl5E+eqT7DWxi/MbSw/MPfi7CEJ8960EBb1bV7133DcfiXh14"
    "NcABrD4AfO0ffLItAH1Y4BuA8tQBmFuE/Vng6y9Y5LL3gsFb4Kge7nUZ9gbAQHnDTTVAVIHV"
    "gNlSA6GgFaBP8zJk4ofAANopwIIEcBXQnSLcLpWga2ogAJFoFbpbhDVNXFOGhoegqdVAAKIx"
    "BZRXEQBVGyC2UypD04NRIBqpgfLGBMDCS2BmCvFkcg891xmBAMhhmR5aEX+0SOfFLQwXvmLj"
    "yf1cJMgXko/fUKDcu/l+HOeqcBucRzTpL+fmZa86zZT++XfD/wA/BBgA+029gcH4w1sAAAAA"
    "SUVORK5CYII="
)


"""Large icon for home on start page."""
ButtonHome = PyEmbeddedImage(
    "iVBORw0KGgoAAAANSUhEUgAAACAAAAAgCAYAAABzenr0AAAAGXRFWHRTb2Z0d2FyZQBBZG9i"
    "ZSBJbWFnZVJlYWR5ccllPAAAAyBpVFh0WE1MOmNvbS5hZG9iZS54bXAAAAAAADw/eHBhY2tl"
    "dCBiZWdpbj0i77u/IiBpZD0iVzVNME1wQ2VoaUh6cmVTek5UY3prYzlkIj8+IDx4OnhtcG1l"
    "dGEgeG1sbnM6eD0iYWRvYmU6bnM6bWV0YS8iIHg6eG1wdGs9IkFkb2JlIFhNUCBDb3JlIDUu"
    "MC1jMDYwIDYxLjEzNDc3NywgMjAxMC8wMi8xMi0xNzozMjowMCAgICAgICAgIj4gPHJkZjpS"
    "REYgeG1sbnM6cmRmPSJodHRwOi8vd3d3LnczLm9yZy8xOTk5LzAyLzIyLXJkZi1zeW50YXgt"
    "bnMjIj4gPHJkZjpEZXNjcmlwdGlvbiByZGY6YWJvdXQ9IiIgeG1sbnM6eG1wPSJodHRwOi8v"
    "bnMuYWRvYmUuY29tL3hhcC8xLjAvIiB4bWxuczp4bXBNTT0iaHR0cDovL25zLmFkb2JlLmNv"
    "bS94YXAvMS4wL21tLyIgeG1sbnM6c3RSZWY9Imh0dHA6Ly9ucy5hZG9iZS5jb20veGFwLzEu"
    "MC9zVHlwZS9SZXNvdXJjZVJlZiMiIHhtcDpDcmVhdG9yVG9vbD0iQWRvYmUgUGhvdG9zaG9w"
    "IENTNSBXaW5kb3dzIiB4bXBNTTpJbnN0YW5jZUlEPSJ4bXAuaWlkOkNDMzdGODExN0VENTEx"
    "RTBBRjEwRENFMzEyMUUzMjQ1IiB4bXBNTTpEb2N1bWVudElEPSJ4bXAuZGlkOkNDMzdGODEy"
    "N0VENTExRTBBRjEwRENFMzEyMUUzMjQ1Ij4gPHhtcE1NOkRlcml2ZWRGcm9tIHN0UmVmOmlu"
    "c3RhbmNlSUQ9InhtcC5paWQ6Q0MzN0Y4MEY3RUQ1MTFFMEFGMTBEQ0UzMTIxRTMyNDUiIHN0"
    "UmVmOmRvY3VtZW50SUQ9InhtcC5kaWQ6Q0MzN0Y4MTA3RUQ1MTFFMEFGMTBEQ0UzMTIxRTMy"
    "NDUiLz4gPC9yZGY6RGVzY3JpcHRpb24+IDwvcmRmOlJERj4gPC94OnhtcG1ldGE+IDw/eHBh"
    "Y2tldCBlbmQ9InIiPz41BSmtAAAC8UlEQVR42sRWy27TQBSdaztpmlSUBRSxAdEFQt0VuuiK"
    "BV/Rv2CFBHs2iA3/gMRXVKyQQDzElsemYkNRRUlsJ37NzOXO2E5sj50QhIaotxOPPT5n7j3n"
    "ZgAR2f/8eAcPj9V4jWKfYmQJd0rxkeKbV0zsv7h/+Gh3Z7RnA/3kbPr56Nmbx5pAUYKtGzvD"
    "W9/H8VsbBK5fHh4Q7pYuQTlJPCSzpAeNVWqgyADQf0FhhYHGQoRqBkCxkmiJQJ4BqGaAJlGx"
    "skRAY7FaBiQiZ5ZKUGDVMgBSMk41kFYIENZcA2UqiJWwpQHZUQJKgB0bKiyjBLkL/rwEXGKW"
    "ZDKZJSLiQqYZXQsh6Y9JoFc7wBzXcVzPBa/nOv3hhrs56LkD12E9hdUsgSIgCH5pCihvIoh5"
    "EEY8jDIRrzANbUYKGlOK2XnIJkDMNonExVH/qkFA7V5UOlQNWCIfz9KJP8sC0S5ULFPauIaG"
    "/dg04XGUCN9oRLkGpNEw/Cjzx9PMJ2BRPttCAFZcNzWApg3zTjhnkHGZnfnJecJlUuwJ9BJs"
    "gShf1zWyeodRbjNtSNsvbTBLRfQzSMfFrqEG1Pa9et011voAyrkNF41IE2BhzMMxpZ2mEUCx"
    "bG5hWRpYxzNo2LBNhMKPs+lkxkOdbr0SOsq6rgygQUALsk4g5Zj6JTgUK7pcBh33oEUTzTWQ"
    "u8FwQUy+Zqp/LB4sZafPKWBuUL1nDkn3Ya45c/OYP5S/BpGZLtD+LncO9bxBu6mgMg+them4"
    "L6sZWJyIEGGFf//diQjRJKA7ADhWCMiKCMl7anSQ5T8gls6E1AukxvKEEDmRXLFOV2NrqzGu"
    "aYJKi2eEqw3gca5OR8zVvRbqYqmMuFxj9R8k6O4WWGiAEa5by4D2yF9oABduXWMRLDLw6/gJ"
    "2773IHj35dS5c/PKJRsa+PD1h0saCCYvn2rq26PbR3uD3buHzO1dsHImE5mfnLx+Fb5//kkR"
    "GFD0KTYoejaOhBRJcVLivwUYACZZJwaDak8bAAAAAElFTkSuQmCC"
)


"""Button for databases in database list."""
ButtonListDatabase = PyEmbeddedImage(
    "iVBORw0KGgoAAAANSUhEUgAAACAAAAAgCAYAAABzenr0AAAAB3RJTUUH3QgQDRcfgk6jPwAA"
    "AAlwSFlzAAALEgAACxIB0t1+/AAAAARnQU1BAACxjwv8YQUAAAM/SURBVHjazZc9bxMxGMcf"
    "596TFCI69ysUUWBASLAwVZ27d0JCSCULCztzlnyJrCA2vkGL1H6BDt060ObIvV9sHjv2ne96"
    "1zRqInD0yHdNes/ffz/+2UcYY/Avm6nfHB4eqssXGHtrzvUL44RfTCaTZgGqzefzvdFo9LXf"
    "72/Xv+OORVEOQZBCGGb4W4BOh2AYYBgGmKYFlmViWHhtiojj8PdwePSFEHJypwOVL0xz++rq"
    "CpOEmCyAJElEcj5jcZyC7ydCCGNEJLVtGxzHAc/zoNv1RO+6LoYDW1tbT9rydB7uLNM+oEX1"
    "fv0CCA9MIvsiKimXS3iAA+zWvfgQBk2fDQhQEvQUcrTCCbppB6QIomacNoybFv1mBBBWiiDK"
    "DboIwqQ45cS6BZDCA9Dnv17/y2qgjQOn4/H4++7u7kEURZCmKShk53kuuKDYwBsHEAePYsFi"
    "/Zdxfn7+AyQF7yvg+XA4PEAicioCpVRCaBFRnKGABMIohXxOgXASCgoqIRjYW7YlIPXqzbv9"
    "j++PvjWJaCUhH7Xv++0knEUQopCcUTDMjkimRi9IiL3nIg0dQcLN1ACDOnzqc0+LWL8AKQLq"
    "y46ohBSqgF67gGr1i8SkiQObcIBoIyI1MXpSuT9sBsVqE2rYCxWESjGrc2A1N3QKkttYhjum"
    "4P8F0fHx8QFPkGWZCJ5YjFOAKIU/QQRBHENGM+FAB1lgWsYCQg4XgoGC+P3T1y/3P3/4tBqI"
    "1EgbQYTXPv59FieQAwowCDpgiMSua4vjmJe5Akbu3AUTHWprD9yOy3NAWXjNW/KqNbCSiFKK"
    "3BFru+K9BfBNR/btnumtqH7VV1kA2irgz8Rj+d0C+HxLAf3licvkhECVA1CektQ9rqbeUgHT"
    "6VQJsFedgjqQFhtVKQyfbS8VcHZ2Bjs7O7za3fsLgCKZvjMyUhVzfX3tcAGXl5ftAvhyu7i4"
    "gMFg4KFiH1/NHnG49Hq9KgeSFPoBLs84hISmIhnBJy04YEogcQ7wQ4kNwTTyb25uuhgFvIrZ"
    "1N+OUeEAu8e4jt9i/0ydhFRxNlQBkf8H0l6mrpXdmu2nWGM/sZ/hM/02Adx6FWt4bas0bmGE"
    "kWLOwoa/OzOLOIBt5xoAAAAASUVORK5CYII="
)


"""Small icon for login button on online page."""
ButtonLogin = PyEmbeddedImage(
    "iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAYAAAAf8/9hAAAAGXRFWHRTb2Z0d2FyZQBBZG9i"
    "ZSBJbWFnZVJlYWR5ccllPAAAAzFJREFUeNpMU21IU1EYfrZ75+Y2a+l06piWkjNXVCBFqMj6"
    "ggSVMiHE9UFRFFZC9iOKqN8VFkjRn6CC9kNjSkQ/CrLvNClT/NoctqBys7m5TXZvu9t6zy3K"
    "A899ue85z/O+5304isbGRigUCiiVSjkScglrAJgIy/BnRQj+dDo9QZgjIJVKgUUe/5easKm4"
    "uLiqubm5paSkZJ0kSfIGz/Pwer2j3d3dD3w+3xtKDRJEtseVl5ezqoy8s76+vtXhcJwZmoLJ"
    "9TyMO48iePQqBo9vEXyGztSyt3Y7dcq53W5G9hGSnNVqZa1UNzQ0tNrt9v0Xbvkx+V0LTVYB"
    "8vNNMBqNEFI6fCLOiw9BHNhtXc9xnEQic0xEmUwmTUVFRTXbtm11nL/pB6c1wWAwYGbmB64c"
    "1+HqCR3C4bicS6mMuHg7iNraWofZbK5hXCZga2ras+/xywCEdBYNB5idDYLyGBiZk2dw/7IZ"
    "gcC8vBcRM/FsIIS6ul37GJcJFFosFtuwOw69XiuT4/E4BEHAsUsf0f/+K+VmceN0JgYHPyIS"
    "ieCzR0RBQYGNcXn6GKLRGMZnJKwsSaGvcw38fj9isRhZmwWVKgFRTMtOvL5XhbqTY3Q2TUUE"
    "1qWBJ6tYF5CkJCIxAdPT03/8JYJKpZLjUkhpgiSTwbhMIMpxPMosNNLwLzSd+4ml61q7GZW2"
    "bJlcdegTVGqtfBZQMoEoq/7d45meXFuqRjQShj7bgoysQvDaXFw/u/ofufrImJxPJuKwrcog"
    "l75MMi4TGHE6na4dm43IyYxBEhaoip7uz2FjmUYm1xz1QLN8JZJiFGZDHPbKFejrc7kYl8vL"
    "y4uFQvMqQJHZfthe8eyVG7OBMHWQDefLDNx7mkQqTfYFPMjXBdHZYUNvb8/DgYG3LprVMPf3"
    "YXybmBhTks/KC6caypdrRCwGZzA6/AEL/klsKBLQZM9Fx8EKOJ13e3t6HrjI6iehUEhSyNMA"
    "NGq1Oluv19ut1opNbW1nd1VWbildOsyhoXferq4rT6amxgfJ4n5RFIOUFpgARzAQcgh6ss5A"
    "9y6lR5O79DlTl3M0dW8ikQjT/yKB2RX+LcAAp/aU9ivfuRgAAAAASUVORK5CYII="
)


"""Small icon for left merge button on merger page."""
ButtonMergeLeft = PyEmbeddedImage(
    "iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAYAAAAf8/9hAAAAGXRFWHRTb2Z0d2FyZQBBZG9i"
    "ZSBJbWFnZVJlYWR5ccllPAAAAe1JREFUeNrEUz1MFEEUfm92uOO4cJgYz3AEjQnRhgC6ibEx"
    "VthRWRAIdnYmxl4LayoaCwqojlgRQgeFsbDlLnEbAW1MOLyD3N3esjc3+zO7vlkXc4UkJBS8"
    "5Mubef/z3huM4xiuQgyuSPzZeiM5IOIqMTOV76owfHduJBwHwiAAZhjJ3ev1wBMCfM8DTobn"
    "dpPzz0sPEZBtfflthHG8TLKOVgRkiOz/xTKtTFFrd3zPcRSM5HEokHLGp0ytej3JdGEPXNsG"
    "X0qNb0f1M8d1A7h7O1ckp9ey273Zb0wNXyUs9cuM4cdLSQVErY4jZ0eL+VvHDXsol2U3mm0x"
    "TQ4n5GmHvu/R+QM9+QlxQdxSSgHXUaMoMiU1hRBV91nNKxTuBAN8rHS/ONuuNaddW4gwUEo3"
    "svRowjyu/nybjr+MY2929169fGpaXQY1hSDCGI7OFESkZwiQH0AY5JiUq2XNXgTDGbp//loh"
    "0Xuux/ErMMCKMqDnoWhSuRHi8V8HQXD1OQ3QzdJUOAUmv2QPqHmVzY+bl966wcUFk298qviI"
    "K9D6sYPZqRdw2XVmD+b2kqecHqyo/e2yanwH7llJdioKMoSsTkLIpVzLjH8jK9w7BGlXVWXN"
    "ous4oYl91RlpoH4YF/wXRZB6y/Haf+MfAQYAtE0LahFUAvsAAAAASUVORK5CYII="
)


"""Small icon for left merge multi button on merger page."""
ButtonMergeLeftMulti = PyEmbeddedImage(
    "iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAYAAAAf8/9hAAAB2ElEQVQ4y8WTMWgTYRTHf9/d"
    "eUlsS1PFFKpFBJEOlaq3KRK6utqloou4CeLkokMXwTplcQiiLhGngqMdHIJjm6IxCK0FUWIa"
    "CdV4vV6+u+/uPockpShYnfrg8f7vPfjx4L0H+20CIP/0WxFwejUDSHp6sXx99O7fAAZApNTk"
    "5ekjZ2emc04cqVN9bRJfulCsD+8JUEHw9cfPMHDdGENHyfd2qFw3ZnhAHFRSntkTEEr5rt7c"
    "cj1PcWjQtL40XO15iuOjmVwYBDdP3397GGBqvlacmq9d/RPQ6bx8/6HZkGEQ6SjMrK63jE4Y"
    "JI1mO3sslzofRdHjibmlfCilE0p5e2JuaQciTtwpF4UQDsDY+MhkNJK1FUIcQGuFEHqjtea1"
    "fT9ScQwwdu6k01hZr2itC58e5kvi6K3F5RvXLjrVbYOPAdS3YhINhoBEw5AtSFsC6OabnYQh"
    "W8DrNxXgnhX4Pp+VSTWxiSwYzEKsu55o8DV4urvXRMN2CpQFA74PgBVKWVl4tPBPR2MA6Suz"
    "jvX8RSUUouCWZl+J/7m69MyzZYCktVoIyw9KAFavZwE2kALSQKYXbcDsA9RGbQ3ZXokrT6rA"
    "OLApdk1n9kC73eyv+jeLAQn4+/6M/AJo6ded0dcRQQAAAABJRU5ErkJggg=="
)


"""Large icon for new database on start page."""
ButtonNew = PyEmbeddedImage(
    "iVBORw0KGgoAAAANSUhEUgAAACAAAAAgCAYAAABzenr0AAADgElEQVRYw8WXu2/kRBjAf2PP"
    "eO3NLjlIA0gUFBQ0KQIUNIcQFOiUChSJ5pBOcEJB6EIkRAMH4iHqNFEUnQR/QOhANHTUgFAE"
    "0qWioAsSsU38tmco1vuM97LLncVan0a2x/M95zffwv/8E00Pt7a2ngU2HrCuX46Ojn6afSib"
    "ZlZVtbG3t/dlr9dbm31njCFJSqIoJ44LqgosS2BZNrZtI6VCKYlSCiklUkrSNP57d/fGh8Bi"
    "BgBIKddOT0+J45goisiyDGMMxkCa5oRhRpKUGCOQUuE4Dp1OB8/z6HY9PM/DdV1ct0O/339k"
    "nh7r/iNrJi4mZPr+wRsgAGEw9TiSKZWXm2Ddj+eNkRCGpquVFJipFEx4LAyg245AbYQYZlw3"
    "+K1HYzsGCDM2QjBhiB6kYioSbRThRNiH+Z+t/8tqYB4Hft7f3/9ufX19M0kS8jzHmMEiZVkS"
    "RdGIDQC2baPUmAWD/T+W4+Pj75sgdC8Dntnd3d2sqoqqqtBa1xAaSJIWRFFGnOSUlUZYAsu2"
    "kXJoiMJRCuUopFQ8f/Xla+++fePbpUiY5zlhGM4n4XlCnBaURmNLC+Wokffdrofnuniuh9vp"
    "0O/326kBwyx8ZnOvR9LSLphFscaIoUI9A+hWSDhBP6EbKNhWBIS5EIXGsNfng2mNA2J2r9f3"
    "Yngm6BENl+XActGYpKC4iGXukYJWQPT53ffxa68fFoJbj328PIh2dnY2syyjKAqKoqAsy3FL"
    "lub8EyVEaUqhCxBgSQupbBxH4d81sD1Y6OzAcH37zWsfvPPeciAaetoIoiwjjGPO04ySAmyB"
    "UjZOx8F1nYa18raO43EfMC48M3dWO0WI4aMf38I385U8/elTsMYBNzlYhSq4M9bbaIDW2l6G"
    "hL4xcGui2KuJOdvTTVFwiH1pBJIk6S3aC4z8zoC/akXDHiSvjdG1PLpgCoIgcJZJwRUh8A9n"
    "UvBKPf4w/XgVquAyA87OztxlquCzFw6Rjo3TUXQ6Dte/eR2eBP4YvP/tk9957aVXvzg5Obkd"
    "LBIB3/e9IAjCXq/3kOM4rKysTHMgy+lFMVEak+kcIwxCUnPg4pJRkIS+73cX2QVXgNUwDI83"
    "Nja+GnZCWut5VSAAhBAIMahIIQS8wQ4wiALw4nNXvwZ+BR4HzoFw3r9jd0L+MyNWb/JnUH+/"
    "Cjq4wxNACSR1aWbDuf8CgMlR7Y0Q0vUAAAAASUVORK5CYII="
)


"""Button for open file on main page."""
ButtonOpen = PyEmbeddedImage(
    "iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAYAAAAf8/9hAAAAGXRFWHRTb2Z0d2FyZQBBZG9i"
    "ZSBJbWFnZVJlYWR5ccllPAAAAZFJREFUeNqkUz0vBFEUPe9jyQqKJWyi4gdoKEgU/oNKKxKl"
    "UrI0CqKXqERHIxLxA0QnolkEWWJCLLtLJozdnZk1M++5M1Z8hGRkb3Jzz8u957x778xjWms0"
    "YvJwif2a4Az9FMZ+SW0pjeOPeyX5BHnvzyoqwsCMmrMcB0+2jUmjA6ZpY/WolVN6kHwtrGP7"
    "C1gYmt7OIAigtYJWXz14j2GujhljyK5PLRJ3NuogUBAhWb3WvhHVF3KE61GIBCJOSOZ1ge83"
    "/02OOmE8Ekg2UfuhiE8H5Xswc3uolR+BUIw29O6KzhTVJ+acIyEwQuR54l9LEpWuVYJPRenh"
    "8Vifrmd0Yqj6YHSfbWaWpU9jVcw7iJYU3Ici4vwXjMZ4zB3kXR+noYB8ujfQ1TcAnxYZx0RT"
    "MwpXJ0Xbxbn0FGTFekGaJWILBJ5bLtwYJcGRl75PO0mm4Ll2tPk4Zt7nCpaDS4JaEmhvbeuE"
    "oLkgeIz5GW6Ni+eqi2OC1L6Dq52Nld3/PCB6J1kvwF4k2Ohr5GjQ3gQYAE2uCzTGoVQ4AAAA"
    "AElFTkSuQmCC"
)


"""Large icon for open database button on start page."""
ButtonOpenA = PyEmbeddedImage(
    "iVBORw0KGgoAAAANSUhEUgAAACAAAAAgCAYAAABzenr0AAAABHNCSVQICAgIfAhkiAAABYtJ"
    "REFUWIW9l79vHMcVxz8zuzxapC0QIhgVdqEICgJRBCI1AgkQTApGQf4BFWkSpHD+gFTsCClR"
    "FTXpwi6KCgEs9AdEQIQAOUixCkeFITswFYuM7ACEdBF5vNudN++5mNnj8RdMWkgesRiSM3zf"
    "z/u+t7tHeIu4devWr27fvv3Lt8lRfNs/vHHjxtylS5f+cObMmZ9cvny5/eDBgxdvA3KiWF5e"
    "vnDnzp31EIKFEOzu3bsvb968+b3/i/jS0tLUysrKP7vdromIiYh1u11bWVl5vrS0NHXSfCdq"
    "wfLy8tjZs2cfXr9+/eLIyIiLMRJjBODChQsT6+vrP7169eofHz58GI6b0wE8evRoXlV/670f"
    "GWw4t2dVVff06dPpa9euvTcxMeHMbG8i5+h0Onr//v2/ttvtxdXV1XgcgBLAzH5z5cqVBVdt"
    "ETfXDz3454+eMTc7y/j4OFVVHXpmbGzMLy4uzsYY/7S6uvqzYwMAI9576s8/ov7kLwcOPdl6"
    "l6npBc5MTtLr9Q7sNy4BTE5OvjM7O3v93r17C9PT0y+G97335IJ3gF/PzMz8oxzeaM0s0ppZ"
    "3JP88ePHfPrxx8yfnmBjY4OJiQlardag900URUFd13Q6HcbGxorNzc33X7169f7c3NwBYFVl"
    "bW3td8CP/TdZdP78eRYWFvDeMzo6Srvdpq5rqqrac4UQaLfbjI6O4r1nfn6ec+fOHZozz49A"
    "bsGwhftjamqKqandu+vZs2fUdY2IHKjq1KlTXLx48Ztqwszw3m8NAE4SZnYkwP4746hQVWKM"
    "nT0AR032/hCRIwFE5Fh56roGeA1QPl/+0Ttf7XRGvnzx+bEAqLuEbucAgJUlVF2+/GI3z1F+"
    "aFR0+7/9Jx9+OOI++/3P/92a+uA7OF/ifJoH53Deg/OAA2egBiihFgrfWB4hGphhUYlBKApA"
    "DNUIUTERiBGNioWIRcFihGrnTej3OmU5Nt5693SrtLANRYErCpwvcIWBh935NEzzFW2Q2CQl"
    "1VBjTrAQsBiSWAhY0LwKFgStBa0EC3I6+NGtMgbpoQENOzgrwAooylS98+Dy68IMU8UkQIwQ"
    "AiqCSRYVST83YhKzqGJ1A5IAElxEnfVKpO7jy1SqczjnkvM+tcEXDnMOokAUzCJmgpmACqYB"
    "U8GiQMzVxwzWQIhgomgIWG6LSSCK9kvVsAMGmvqZvmJyIzqid2mcVLHGcgloSKJN9SaNIyG7"
    "0JxNANq4UgtWC1oFJMSt0kL4Svs7P7C6j3mPKzzOO8z7PTNgqmA66HkDspu8sT9ky5NIEgxo"
    "nWHqZH8MhvblZaka10J3G+oernDgPc57nDPwLrc/TToaE8ig4rArKiFZHIZ6L3nyQ+Oephao"
    "oVEhFM9Li3wi3W187CXRwuc7OF8WwRTUUq81g8ScNKbvB3dEIzx0ERXE0hrTGoOhwT4tw6vX"
    "n1Vxq9tyO+NmIT8D3NBQAjiMxgVLjmiqplmb6pBDACS3buh3UdiJpv8qw/bmFxVj3WI0jmN1"
    "bkEDkMR3H235odOAxGZNVVq0vRBxGECzOwkk1n6byEZZVdXLgkLMwFTy7ZfF978lbQhCSdXr"
    "EEzMotGOhpDUThELvAkbDuDJLy6tnX7Pf9dinTQbB/YZsAtAEt7jRBbOLlju936IJl6/cc9/"
    "+PfN8yWAVKEfPKCShJs5dEMAth8iu9BADDkxEG9aI8r+N3VdWx/y67iupNcXwaHg8pMvV+8G"
    "NlhiGHJhdyCHADSLa556O/ytGMSqAUCvjnUZ+xhDvR90YciCJtmwCxkAZQAxrHiYuBlUZruf"
    "iP7zJvxtpxj5vqmhhhucSh6nBcNiTqmkvQxizSOj8VlBm3P7woNizm0Hezxc3gjwAdDiW3xM"
    "O2EIUAMbwLH/g/qfxdfI9P0zcP/UhwAAAABJRU5ErkJggg=="
)


"""Small icon for remove by type button on start page."""
ButtonRemoveType = PyEmbeddedImage(
    "iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAYAAAAf8/9hAAAB6ElEQVQ4y42TvWtTURjGf+fk"
    "kubzXslQ7JJBcBMj1dFNhYJ1EA0iOHUKCP4JERyyuStksWvGKpTOTmKsdJIsarRqk9wbEvOd"
    "8+HQpEmo1rzwwuFwnofn/fEewaSy2ewdYI3l6mepVNoBcKY3w+FwrVgsvux2u/T7fZTS1Osd"
    "+n1DJBIlmUziui6e55LLPXg81TnztkopWq0Wvu+jlKZW+81gaIjHkyitkCFJLB5diCLPDCrA"
    "AlaY4+a4lzfAToR2ItZY9MKL+RHKhULhdSaT2TTG0Ov1JqMoIpEIiUQCz/OoVCq7wPu/GVzN"
    "5/Ob8xBrjTbdwYjwSphEMo7nuty6fXfjSW5rB3j3X4hHjRbd0YhoPMrYnANpcMKSIAjskhBn"
    "sxuhTxikUimxlIExanZGY4TBoBcSnAlxrMcEjeAEou95vKlUdlOpVPmUgTHmFMTq4S8+16tc"
    "2HvL8GAfLFyXcuPil+/rD+GbhfKJQafTsYsQFUGrCUBwsM/9K5dnWTOXVoHVV9vbswS+7zv/"
    "WiaTWefFxw8AhKSk+vWwm2gefXLmE/i+H3McB8/zCIfDKKUJrUSJDdrIrXucTzzCnezCzWs3"
    "nv5o8nyBQbvd9tPp9DOtNdbayU9ACCEQQiClRAhhhRCEQiF/qvsD5gYPZnfJMf4AAAAASUVO"
    "RK5CYII="
)


"""Small icon for save as button on start page."""
ButtonSaveAs = PyEmbeddedImage(
    "iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAYAAAAf8/9hAAAAGXRFWHRTb2Z0d2FyZQBBZG9i"
    "ZSBJbWFnZVJlYWR5ccllPAAAAf1JREFUeNqMUktoE1EUPfOzEzDalQ2FBjV+tuIim5ZOFxYX"
    "igqK4LJ0U0GquLLgQnEnUmvppl20SLrSTV1IF65KYxeCCSglgi0IGmokaLQxDm/ezPPdl86Q"
    "SavtgTtv7pt7DufeuZoQAsPmExA27/7Abqj0jEzLY7nzeWH+00APzK37ERkZGR93E+CN2lnj"
    "p7joHejIynRUCQiI43dyw7dPXEvK9zgeLH5BqeJGeVqGc/kYZic3r4ogeLMlEOiMMXDZju/7"
    "MYG361WcuXQKH37JFnnzbqUK9A9luxae5m+FDvQgCMAk2fO8mMDhTg0vcstRrmka6v19yD9a"
    "+OYetCdCBwbnXAm4bQJjF47E8isPV8BzL9Fd+PoO++15JRAI3yDrTLpoF2hH5lAHTlpJlErv"
    "1yhvCkgHJPB7g2Ffl/1fgXvnT6OyWMOq5EQCYQtrzz5jL0gkEorT4qDZQrFYBC3WTqDhhXAc"
    "R3FaWzDJgWEY6B3NbPsTlmXh9eQ60uk0yuUyqJY4rQ5McmCaJup1F0vjq4qYvX40skzfCLZt"
    "q10hTiTgg1u6rquiRoMhlUqpYnpXMxJGTIB2hjiU6/TwhDv1eGzmVXXje40xoYophGhGeNcq"
    "wMSfpAxoNLRz+k154Q7Kjby/ZM7ldxqiw4f6YkOFVpDHDe1fU98r/gowAMaC+CTtivcaAAAA"
    "AElFTkSuQmCC"
)


"""Small icon for scan button on merge page."""
ButtonScanDiff = PyEmbeddedImage(
    "iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAYAAAAf8/9hAAAABHNCSVQICAgIfAhkiAAAAzJJ"
    "REFUOI2V091rW2UcB/Dv85y3vJ6kWdIloTZpHRjaxq6FqRXXiyzaCo7pbhRRfLnYjS8l/gNe"
    "Kd45UEGrU2RDigwdtjAJdVPHwItRjGtr2mXdurV1WdpmJk1yznOe8xwvZoMvF+L36nf14Qff"
    "3484joPdDBw7q0uE5BSJZLlwBgFApqRg2c6s7Tjvzk8+XsM/QnaBvpe+yqiUTI0k48HBRERJ"
    "7PVD12UYnKG4UeUff7dUZVw8s/jpU+f+BaSe/yLjVZTpowMpz53tW8ifn+Hl9ZLErRZi9/SK"
    "N159UXp4JI1X3vu+ubbVOFw8+WwbIfuePqHLlJaOpPoiv8zP2UuLl0CUej4eshdTqZ7AxUur"
    "3dVNdujR7Bh54bkj9LUP8xXLFvuWp16uAQAFN3K9Pl9g8/ZtXLu6jA7P1bcOPRA89dnkO9oH"
    "x99+4vz0+6EHh/3HL1z4yZmbW8ZYOhGEbeZ2N6BUsGzU41Xni79ySW3k0/3J0siBAyucGx8B"
    "+Nblcl07ODK0oXpE/vTMD3Yy1KEQ28zuArJlNgddRIFgQnI5t4o9Pfs3h9PpNUUx6+vrC7nG"
    "lq3v7Pze75G2u5o1c1wlGiyzNdgGhGWAWQySrIFC4z6f1/DsUU0h/IYQgBaoKz6f11AVjRPH"
    "jVq9BcGNdgsUghW2aluQNc1m6OpnjCmsyqVAgCmBwN2ZMaa0nFi/2++3VzfKgG0W2gC3zNm1"
    "6oYZDumy133f2OWl7eTC9SvRcll4y2XhXbh+JXp5qZJ0q/eO93Yn5OLNks0tY7ZdY+zg67pE"
    "aGkodn+kaYBbJghRyl93x+U8ANxYtx6zzOBRv18j4VCA/Fg85zg3zh67ubrySfuQ4qMTGYXK"
    "3wxE+ryUathpCk4cWYLjQFBmd+humVIbhd9+xuEhDTOnP281mq0nN8qb+fYpx0cnMpTQqU53"
    "WN/jCWk+1QdCKJpWE5VGxS7X10hUq4jRgU450uHF5IlTOyZjGfLXZ4qPTugEJCcRmhW4+0wU"
    "pGA7YtZZObNNeOPNaFdCeuSh4aAqQUx9eebO34D/SnxveBzAyVAo2Ix1hrsXiiX8L+BPZD+A"
    "aQBdAFb/ADonfMWfJE59AAAAAElFTkSuQmCC"
)


"""Small icon for stop button on online page."""
ButtonStop = PyEmbeddedImage(
    "iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAYAAAAf8/9hAAAAGXRFWHRTb2Z0d2FyZQBBZG9i"
    "ZSBJbWFnZVJlYWR5ccllPAAAAT1JREFUeNrEUztSwzAQfUIGjBNomAwFPRWdSwpKzpAWCg7A"
    "OThACug5AxUFJSUFVFAwJGRgxrHxR5Il1nZw0GCHzKRAM/qs9PbpaXfFjDFYpq1gyeYUw+Hl"
    "CIyxAS39BXzuSPXpzfHOjCBXqpj8/tGuL6X9pJ8vdByGq+uX3wpklpVGHOcIAtV6dbfLa6xF"
    "INK0NNJUYTIR9aGUElkmoJSE1hq9XqfGWgRZkpSGEJpIJKIoQhiG5JzBzpKosTZBHJdGlKR4"
    "eh1C0M1VjrgFTvQM26jg+VNg6Li06zYHga/NVzDiHsad1dYginU+X8Gb4+HDba9MQdyyScF3"
    "agzn2PQAbaYd1Wym9SBZhdXjB9rplz6siDJVIecHZxfY3tv/sw7fH+/z2/MT8lMWAa23qG8s"
    "UMqF3MAi+Nff+CXAADjrrYLxZ/nIAAAAAElFTkSuQmCC"
)


"""Clock image icon for new days in exported chat HTML."""
ExportClock = PyEmbeddedImage(
    "iVBORw0KGgoAAAANSUhEUgAAAAsAAAALCAYAAACprHcmAAAA4klEQVQY032RsW3DMBRE7wsB"
    "q7BiZQ/ABZgBnFHUaCeyYcU5tMDPANxBashUbM6NFdiI4Nd94O7wcSd4QNKKSMg5r2MMGGMw"
    "z/M3yR8R6XgSXmOMVFW21kiSrTWqKmOMJHn9S4wxcts2HjwEJMlt247bTiISQghwzuEM5xxC"
    "CBCRMOWcV+893uG9R855ncYYsNb+E6SUkFICAFhrMcbAhzEGvfcXw7IsL8beO4wxAICbqvId"
    "qkoAt4mk1lqx7/vpv/u+o9YKknrUdymlnPZcSiHJCwDI0zCfIvJ1sqCKyC8A3AF0iM8aPIik"
    "BAAAAABJRU5ErkJggg=="
)


"""Edited image icon for edited messages in exported chat HTML."""
ExportEdited = PyEmbeddedImage(
    "iVBORw0KGgoAAAANSUhEUgAAAAsAAAALCAYAAACprHcmAAAA20lEQVQY03WQMYuFMBCEZ4Ok"
    "EREsPe51mlYR/6x/Jr8gWliZSjhOsH1WL4TsFYcP9byBhWX3Y2CGcCOtNTvnkGXZR9u2y34X"
    "V5CZpbUW8zyj7/vvYRg+/4WNMS8hfs95nqOu669bmJnlOI6IoghCCCilwMzyFjbGvEII8N4j"
    "jmOUZUnH/wm21gIAQghomgYAQERud3/D0zTxtm0AgDRNoZSia543nCQJ8jyH9x5FUZxy/KlL"
    "a83MnCzLwswsj3NyJiJnrUXXdc91XR9E5I6zw9G+SClRVdXj2OtVP75NbogDzH5sAAAAAElF"
    "TkSuQmCC"
)


"""Removed image icon for removed messages in exported chat HTML."""
ExportRemoved = PyEmbeddedImage(
    "iVBORw0KGgoAAAANSUhEUgAAAAsAAAALCAYAAACprHcmAAAAMklEQVQY02NgoBTMnDnzPzZx"
    "RnySyCA9PZ2RiSKrcdEMDAwMJJk8SBQzEgpbWLCRHGIAnXQV/zSmlRkAAAAASUVORK5CYII="
)


"""Help image on default search page for chats page."""
HelpChats = PyEmbeddedImage(
    "iVBORw0KGgoAAAANSUhEUgAAAH0AAABHCAIAAAClA9+5AAAAKnRFWHRDcmVhdGlvbiBUaW1l"
    "AFIgMjMgYXVnIDIwMTMgMTU6NTU6NDQgKzAyMDB/0ECbAAAAB3RJTUUH5goCCSYXo6y/eQAA"
    "AAlwSFlzAAAOdAAADnQBaySz1gAAAARnQU1BAACxjwv8YQUAACbTSURBVHja7FppbFzXdX77"
    "/t7sG4fDRZSohZIlS6IsyVZkyWm9NHa8xI5ToEj+NOn2r0CaHw1QFEVRoL/aAG3RvzUQBE3j"
    "ADYK13HsxLUlRfESa6FFmZLIIYecfea9N2/feh5JiZQoyzNDW2qLHAjU4+Vdzv3uued8596L"
    "fvzBmQBFfit3U/AAIQB0//8+7p7n2Y6z8o2hmB/4G79JkiRw/F5rGgoKuN9rHW4vhmkTRKgb"
    "juMYqLkspmXjeFiIYZhl2+RyBYLAUSSAahxxm7kEQdgWRbu1rJX605dnHVszHTQV51sthSZJ"
    "1/cImjZVPZvPttuyIrcy6WzHMDDPzRSGElGx1wn+78LdBqP1AorAOF5okhnbR3eIZqtRvVQy"
    "RRbLRmmZ1z5sn39h4GlVUdl3T/uxWLB3d0dt0zTreo5hmGDgNEPd6HCpXB3IZTVVJSiaoggk"
    "8F0PJYiblsF1XIIkKpV6JpMslZaymVQqlWg2PMsxHDfAcMyCGq5bbbSTsUhHVT0fkSJR3dAN"
    "0+JIqtFo+o7d0zRTsViI++XLV3EchW2om04yQi5UtADxUlFurtTcvXu8XqlQFKl0YBgHFGZ5"
    "xrL9GI81NZRAXbAkMMNYLIaFpuhV6y2SYgfzCZxkRZ7tFfdWW0ZwRmBxikEWZUu2gh0iWmra"
    "py93nj8SQ1Dknaunfjrz6lPZx6Gy/7uPBp6L+OGcPd+zDe31/3ormUratgvmv3/vBMkyruOA"
    "CReLc41Go604uUwUJ0mAmMAwA+rZJkXzY2N5z8eX5ucbhWGBI5d787/82Fe/OPOqL1xDpz48"
    "U65WYSsahmG5AR7YLB/xfS+TSgCg4BotXXNcH8yloxkUrA+GuJ4X+J4UTajtJsUwlmUHCBqR"
    "BCzwVN1CAiSRjMOOZVmmV4UAI9u2KbBMimVADeiEQJuNyuqfUTyeSFm2xbGcCnbnukQomKrA"
    "zu90OurGDjXNKBTyzWazSwUcxx0ZLjTbnWPHH/nicC9enkKvXjonxBKfb78tAzHd1e8I5VFY"
    "8MXN4dMENiJO9OZFDa1jGlqj2eR5IRaLf3G62Z0OQTNcKj0Ahub71zkAhnUfiG4riQAJbgc1"
    "BMDNddyb9DqLannhzTd/nslkNEW9em2WZ1meZ1VFJkjacRyKoV3Tggn4nuMjOIYhNEl1dJ2h"
    "KZbjdE2H8TAksN1gZDh/54Fw/3pcvTx96cVnn+FEwfGYH//kh0NDhYW5Is3zEFUYiqqUK45p"
    "J9JJy9KDAIIQRjB0Ihb7tH6/+zPkF7Phx1gCyfHIJzWkYoS/7okb399fvjugh6wRcS5cKqZz"
    "ydHCYKMlcwzlAS8Bb+aDn/QBzUwuS2BrawOOdMvYNqBPvmNhtqPKsg801PertZrveD4WKO1O"
    "LBYtDOc7smqYLkNSlu1a4J8dT2m1ovEobJhIVOpGvVXcXdfXdEvVg3pjHhx0q1GfvnQRorRm"
    "GPcdnFRq5VpDL5VrNOX6Dr5QXBzYOvKlhw5/pjmpJkKiSJJfxf0uS1vWJY5OJFOmZepqfalo"
    "AOm0/aBeq3qOnc0OJtJpAltj9KlUUuDZjiqLUjSZHuhpLM91KpUKy0sQ4F3XW97bAQ1bxDIx"
    "inRsn6SIjizHUym9oxqKsoq77wcdHSKhk0rw0IQXpckjR8NARpAQ9PPZfSOGBTsLdi5FM8dO"
    "fnbAFBlkSERgTudqyKGU9sOTYWy8m04GmJ8kiUbHrC4t8rw0umV8bnZBiogYhheGCoZmJpOR"
    "2mIplc0xNLmxea8+CpgIzbDgHkiCIUn/RjlBkoAhEngMwwSeB8kIAGhhKnH9z5B9eASOYOEO"
    "xQ1dqzdlhsIYLoL4jqyosCsJLFA7eiqd6UYP3UV4IjTzOA1zCHDs7iG+NmcCa7VajMjHk9lW"
    "qw1h65OPp2hGqivtkUJhemqKAqYpRjfiDtzIC/rxh7DYtyl1wkLHsSEFk2zGMBq4a6Ol2ZmB"
    "4THwYsAjV5aYYVkIrZuZsOUi3rq4iqMBeS8oTa+zUJUWGBz4GcjacIIJMFi4ZZKBYRAP4GdE"
    "WvXdtmW22grH0ghGeBAMCAoSMuAl4P3X1sBxmq0mwwmID/kA/ENKpdbMjPDww6QlN1ft/e1f"
    "vv3h26/lJL+le9LIgW9840VgOGg4IoToAHh0T3N4bQbZLrSTjNt9k1vEWz6rw9H+VwuUpykS"
    "UspILAEJcE9tIfCCj/bBO6CweGgIBYKS9Foa7EIG63mQagSY57su6noAEoreRFt9+IPr2ZYN"
    "jiTszQ8sy4KEBBwKciOuvv/B+z//0T8/fyiHevNvXP7a4f37y/Uq1ABvk4gJuVx+bNto93r/"
    "dxFhUxoVsfpG7dcV3vDRh7IdrN+QALjHIuKbP3v9wIH7p6/MGoafTIiI58zPL/KiwHH89ok9"
    "o0O3D57gVOPJzDJ2PhjcjZ/AJlc+gHynKWble2WsYNk0b1QITRYnU6nU+uaq6kbDkxxnDXcC"
    "KjruzsHx80V5RxrPj4wkshng4MBnaIoSBKHXaV9R6K2bwP1AWkPC08S+OwidDNjbkWMP8xw9"
    "GUtCKgSgALfct0+rNju5TArc6ae1bTbq5XJ1dGzbLbivdNtN4UpYXlmMdTX10VHn0lQxKYmr"
    "uD+QR//TsC9XFn7xkfLH38YMXQXCC64uwCjXsQjUG9k6EZW47qdd7FDdV94oHzU4zcYPZlWm"
    "30ADU5VbzcVSA+EZBsXjMe7aJ7PtjhlPRGVFqZQi7XqDFqXDx49LzK1x1TR1WVZHt2wJFz7w"
    "1n4iN/96p8KVc9CbCgHJj6cukHggMfRqXF26cPrCO2/EM4np+ebxyT35IzedCq2cmXQ/59ev"
    "QEpm7U/qm4F+kxKaWJhYhnGPYTngawGKA6AwkdAb4CSkRwGCSpJ0gzHeiKuVpRKCkZJ4eztT"
    "FYXlBWITFG0tX02M7z8yshs2xqhphnzzZukJdJBDeaA0NEGQLOH31PDzFWLD+QzHdXVECqRz"
    "sVJTWwoXiWCeqZmOpRsES7dqTSka3bFzrHL+Y91yhgqD49tG+tRt5b9XX/npv/3rv8TQoFop"
    "jx99+Lt/8b35qjw8kg8srVRVofeeXPzfvB2eE3x9rP3caLs/tZomUdKJYdGWyD5XjiRJpb5U"
    "rhv7JveWF5dEgQ9jH4IalgUUDcfwgaFhhrr9wRnFcLt27Q6Q4I1XfgJ1gIrgKHrg6KMERWPL"
    "uyOZzK3UlCEj70VMQwdWk0smVgeeL5XNSvl3Thx9yzIsz8dI1lCL01OKb5suQsvZVB+hdTOc"
    "ncX9FONaLob0izuIGIlpFhF4DjjwSqVGk7ipG9VmE/LG/EAumhn4VNxpJhJLQoZ56rX/GEwz"
    "luI/cXjiwSN/RXJdnb3cQd755Ru1WiUTj93IV0mTYFqyGo0lyHg8Eo/s3L0DzMMyLZZlXN+b"
    "n1+IxeMC30NoBRbYt362h1VNYjzSmzWtFyAzEUFEKrWPzs9EJWb7+Njs1bk08JhsFjIcy7AN"
    "uT6zZOaHh1n6Vi8KG+PixYu7du10sKCiI7syyaHEwNnT71KxdLVUS6YTtqlnMpnZ+RJHMxTH"
    "Hzq4r0utCJJKJDOwoqu4D+YHDz327DVNRpPMc8+/EF69Qo4VBOAigfJTFAmJQ/epE40jHBke"
    "laJon9aK42ia9XWPYAmvvx5AW5ykorEYY3gkQwMhFiSxVCyyXKShtAcHBpZKJYpkNN3aiDsQ"
    "kYcefDCeiBkBl84/bFMeWpjYO3nUdoN8doCmKXAXvCCIktTRTYbuIfiNbd0KwOrt1iqf6W9u"
    "/8/kBp+ZX1g88uCXoOTPvvPt7XsejEajyUTykUceoKjNXkfLrTpsJsD9elx99dWXXnpp5fvY"
    "sWPf+uYf6KabWr6uC+90bYtieRxDfc+zHJdl6Dv3/tI5ZKaJwF6yXSRKOV8f6/aa7XMUyFyi"
    "klBvKZDB53I5rJfzRdjaKw8XSnPF7Yl4Pj5x5q13ThzfTwn85tVauRJaxX16evrff/yj8eNE"
    "Mpg4e5b+0+98672zF4FN+Sg5eWDy7JlTgwODHuIZitwy7Weefgq/Yyr5mzKiWMiQhCgm8nHZ"
    "+0pWuye4c4T34fsX3E5nx4Fd01NTtovyNG6oWlnRBBLhefHwyUfzqcjGtuAKXn755Ygkeq6X"
    "oDHcMWmKLBbnolqnUa0DeacJDKdpyzCaLRXHXDGSNHVNkoSBwhDZHa9fxZ0iyfh2Mv97QaJG"
    "ilocwdm992/vaAWO4yGf/sqTj3cMe/mhSkBSZDf9frCEXGlCeERIlHxtXnqsoNx96H2M2X9w"
    "Iny4gaFPfvUZIDPsMn83tE5bNXLZ1B3aRqORQ5OTEIErciet66ph+Y7ZVoC1B5hlMIw4d+2q"
    "IEQsw4xE2FqlLAiSLLcT2XxvuNuOU59y3voeghIf/P7XdnbUTqPVBq9iGEY8nkgk4jTbA5MJ"
    "9RaQR/KIbMEC4BdbzD3BvV4tnzp9hibEZGEQvDbwmUatzDCRitwaSGcRT/Mc5MDxE4XMrVfY"
    "EJO/fCJ8T8DvefxafJB0bfv+yeHxPZF1GezQ0MhmdFuNq+fOnTt9+vRK0fj4+IkTJzbT6ZkF"
    "ZHHdo4o069wXvwcXfZBzLL//Cs9HVqnV8uF2sO7Sff0l/sa42tH0M6dPq6py6IHD+Vx28xdm"
    "t8bV3bt3T0xMrHxv8jEBSF5EBgUvxa4/f6f77q0/Wb08WCc9PY187733BYEvFIZmZmaAWLz6"
    "yisvPP88L0qQfKkd8AFRKMQJwtB1juvFE9wSV6GXZrM5OzubzWYhIwACU6k3aIKo1VuJRMyH"
    "DYnhrUZr9769FPHZ+v/DrxDS0f5wZ71v1OZUSrHxXXED79cGSJLU6i2TJEfzqauzC5CCgOZg"
    "7rKmh+95UGzbzt0cfRMvDELxg+Wj3WKxeGjyILjZ0dHRWCwG4Fy7elWR5czAYLlax3yzYwSB"
    "B3HCevrZ5+K9nNSuyNrA0LUsy2AmgLttubXyEsvyAYK3atWm3Iac23N83+829e84mOsjPd7z"
    "rAlP+iIZjtY37gAhJ3FRMQZmn0xEdN0JkMDUdb2jKI43NDhgO+4tuDuOLbca12bnWE546qkn"
    "IWecmbnSbrcBfaDwh48eXam2d7WyA0vbq1YQMiEfBVkbeGW/8HxIUXmR37J1nCRw0zJRjMwV"
    "BmEaYjTOdJ04nK4K33QacbrPbBP10asasT3m9X3IA3OLiPxHH5yP5KSlhdoDDxwoXpvjBS7D"
    "cqZtQ3ZSK83Om/aW7Tv46+9Yg/BGyQ6NazlRhxKaorYOD8WjMSl8dnnrNc7Gks8UXVNr1SqB"
    "XL8ShCWFhQXoTdNUVRWWF/gi0C+eECzLJgkanFL3qUeKQ4YiCCwSSfZp8BEO20YHGEaR/Z6L"
    "wcbFSXrb9jHF1nbt2gGgJtOp6tIiy4lg9Klk0rE0gNU0bZ6hNra9dGma57mc7bJvvI0JgvjE"
    "o2Q2t/nIt2rsOPHbc4I1qVcXK0vzxfkSx4tLlQZQjczZD8ltY/zELqNev6Y2ZC18kDQ6NlrI"
    "5/ob4srl89VKlb7xcjMI3guQU8ucqx0E4zj2ogM+3kNYth8e8k+/DlPWP7+vLPZrra6Ptm08"
    "SrvEJu61GYqETZwZHLnFj3fT9uTJExFJctyAGMgRMQgT0S1qGiMooJ1kj89dbyvX34sFrG5a"
    "tdrsQvHK6EjA4vPvnv2N6/iQXNx/+Pj5s6cqijKQSfgIGtjG1olDEzu23KHTq60wX1W3WmS/"
    "/r3coUomMsA7ObbfCIGizXplYX7B0Y2pKzOK6iSTEuJYc8UFmmUkMXrfwUPjWwq3bQv+HTwt"
    "fOgDaVNVmMADUhqJrp4ogK+w7T61upE5XH8/89aFv/vbH/B4EM8gBw7v+qM/GXzsiQws7MqN"
    "+HDhmdC/L9Ph8KEI9tlUcn9SE8k+lQNhSW8r5UWo/nvAcTyVShGUQNDE/v0Hh4YKkIQLouBa"
    "RlM1JZ5lPv15PqBs2w6s3F9//y/ffedX2Xx22/Z9//iDv+9bmXU934y7EEHHRpiTx8Rm2+U5"
    "rCO3Z67NAsYYScejkUJhcF3brkJlgvb6jamh1E2i8z/sXGlsXNd1/mbfd84MyZkhhxT3RdQu"
    "WbIk25K8xHES26kbx4abFukSBGgbJG2B/mhRpGgNOEAToGgbwEhhFGhgJK2D1opjx7soWQsp"
    "0RJJkeI6KzkbZ9+3njMzlESJdkwpqF00FwQx5Nx3733nnvOd77vv3lcQ9Zoyd7yfgKwWXF29"
    "enXRaGsuZbKJaNDvCbh8K9Zma3gt4rDZQh6PVKM78dhjOsWtdJB86+TJk1aLORrPUUMXLkx2"
    "946srKzG1sJEFWQq3YprTmO05jIkDwTlUsXa2tpiNW9peA27d2879Gd/8UOpUJQuVlWyJpVW"
    "NzIyQg5e3zW21Xv+3R0QVhVW9SfaSblpsTYu3fJ5reuFBu9wOIZ27L7+n6GRLVze3uYYHh7+"
    "l3/+12yuIJcJ9TqFUFBJZop6NUdDW3sH6UqNRiOoliLZpEy25SzYsLveYKOf27++M+Y0aEFt"
    "N9qWZcVnpNCcHeDt0NBr+QSAUUf4JLc2t9LP9TottgYGdN1RF5+t83yfkULSqa6JpibHv3av"
    "NZWNv3XyJ08/+5zFYrnLlm/Nq78pt5Rz584rFPLluSlZm7PDmJzKBNYiEVOTpVwqkfTR6LR3"
    "xm9vzau/KbcUn8936OA9JhGKBShV3dt0wYDPvRYKJbL5bKrwW08/cZfKle1OYRWPxz/tO/2U"
    "i1Z7Y28MZc7HH/+SUCB8aBumvSvJQk5Srh65Z4/MsLXDNx9TGsfODR99SOz/YaltZhdUUd3z"
    "le8srwbz+VLG50oWINj6QthtLTc+sN2rlXI6m5NKJFKptEJ0lBh6pcyHHfjMYKlSRalc2XSX"
    "SLFQoGtolAR6fHzuM1/IbvkiNGqUSvgYtU9Gn56+qlGr//wffvTV3YNSkfC/3xv7VhlSqax+"
    "ckP8CR5CfETLjQ91uxf/6fvfVzc1m/UalaRodAz5lxcFUj6YnU3H25xdS76ASqPrc1pC4Ugw"
    "nCrnkkKxjLK8qCravne/Z348ECiYLMZUPCpTKIj4j126TDNH3Fau0+UTaQGf8hYo5ZLjDz+2"
    "1aWSX29ZnMPqCtYyaDbC4cT0FXR3YtELYQUjB29UI9UyMzMzNDQoLFeVIrFZrSSLj773Ls2Z"
    "WiFJFQXPPP3kljaG3F5qOCOW/8E3v1EqlYvFilQiUKp19pYm9t/aCRsCvq6elFKlElSK+ibr"
    "oEQqFlQz+aJcKsqkElWp1mY5RtPAK/rlokKpFIskZou1mM9XSKyLRYV87tq1haGhAfr2bvYu"
    "/1qK3oR4Cq0aiCVIpWEwoiCAWokcBYEUifV94+TvJ04cV9MtqzRLFRkK5UOf+9KxBx+qP5zg"
    "R7J3PZJ13aTf8Ezdbt+goer9gXd6rt9A7bfRtLk4Vm3c3+NwtH2axr6pNLfwz68s/JBHw1L5"
    "e88/XxHKopHwLlurQi5fN3i1uMUXcNzUcuPD/wFQ/t8vxGei0ZhIJDp27JjL5So6mjs7O+/+"
    "mCNu5+/lMiolzC6grxcEBvVXFQhrH0QiuJag1WPsIixG+ILY1o7evkadUJi3SaQiqGrQ0crz"
    "SfVTcUTTmBjH0AAmLqOvD9u6GUPnXUjHMbKD69RbDq7wasLYBXQ6EEww7Hb18rEmGk+99/pA"
    "r1xBawvMFszOUnKkgILrGroHUMigp5c7rVbw5i+xcxd0xsZD3fqD+4mLfLjC1o8mDdKJxqge"
    "ewwnX0V/L+wd2PTBJeHru+++2+aw9w8M+v1+cv+WlpZcJrkSiivEwlSOn7bLFMpwKHbo3gN3"
    "BjqNbv/2r3H8Ubz8Yzx0DLkKVvxQSRFPw+XD917A9AwOHkA2gw9mYLaxlVdiGB/le1txI1GE"
    "QYhJPw7uxOhpfOsvcXUcR44ik8fpUag0MOgweg6iJDRNeO1NXDgHqRIffojv/j3GJ3D4EPJ5"
    "pDPwu+Ew4sNrWJ3B62+jswsLC+jvg96MgBcdTnzh81hcxkAbXBEezNISsin0dOPkSbgXYG7H"
    "Sy9CbUUmBpkaNiPGp7FvCFenUDyF7/wJTp9pjGp2Egse3H+IR/XAoc3t0t/f193VVSyVZbLa"
    "SyGI6RWhVSsoZ1nUqlgiKZMp7DYJnzC9owTbsDt5iteDvbvh7MOr/wVnCx/2azfzGp6o5jta"
    "Awi0u7oRjLEzkpv0dWB2BVUhm1VVxfZBbuzYCTTpIBFBJIPZCI0Di4vI5iCXQ6/AmTEYm7C7"
    "D+41PPwIlDJ2bZUWOi1k9JnEYRFyLWe/Ew9yNJAv69S4SM7eCj59J+DYopyyWuD6VIGP7ovY"
    "0PccxfwS50ljM3daESK8gtZmKJQkiGByIpO7MSqpHKUs4kke1aaF8GT7dl699M7NiWuHh4PB"
    "YFdXV5O1YS7HJ7LtxwKOb3m+qWXb6dM3/hUOc4Sa11PmwYOIRaBtgmKdwbtcaG/HxASi0U1a"
    "HB6GVoVwEq3ri0geF1rbsLwIt3tDzT17KEOhJIZRe6PltnZcnUYgcGuzOh127Wp03ShVuNw8"
    "JaOjv/o+P2pUN+8Tufn5an2/GJWlxUX/ygrpyoH+/rvfL+ZeuhYKrj9flUpxfV/e1BTuP4pw"
    "FE1GzC/CtwShDEtz6JAgIYC1ievU73zHDiQTUGuRSaNcgVKOJRejMHGfbJrd6to19PQgnUZL"
    "CyMJ+fK+ffxtPM5GvLkkElApUKyyw7oW4bBzPshncV26U4X653rX6fUeM1kUCo3BpxJQam88"
    "lOFLNAxfVDOX5nP7xUrD6PXWdIaP25wzOnqapCIJxnK5fOTI0bGxsXB4rVAoKlVKXnYXVOOJ"
    "lEqlVKu2tjP71rz6/HdhtCEdBaFYMoNIBENOFOTwLCMRw3un0LsfH7yNowfx2juwNyNb5Mqk"
    "Qb72h7g0gelZfPkLGH0fgwMY2YNfnOT8VijB0IrZCUiKEDVj/jy/IEGqxoX3mcx5vZxCl90w"
    "a1GSwKQCsc2xK3CaMbfMEERTRYajahIZln04tA+zUzDZcPxIo8fPP4jZa4hHucf3fwnPAgwd"
    "EGZhsKOcQTiBXT0QazB6FvfuweQMDFoGw5f+jaf/6iSEcjz37AajxOPJQGiNJBL7fih0+PC9"
    "CqXK7XZHo9FKpRIKBjwev1gssDnagqGIWFCqitT3Hdl/Z47fsLvRhIE+JOMo5RAJkpKq8YEK"
    "7G3sU0olgw+BKzkOaTaCl3wZ6Rj7HSrsSsRYUimICYjKPCXEdug3MZlDEtK8GOjF4hrnOmqB"
    "Gre3I+DBkoe/iiRAGKuxsnJptcPgxhplRQWvAtIAwkFuNhNgXJ6ZYkSeHsWxe9mFqcdkDP4A"
    "2szIFhCPsQ5yaNhjJk+hfxsPJhLFjl6023FuFPY+lNJY9WBlBXNzcHmgvG1FymK1aDSqVDLu"
    "9a8++eUnabiZTIa8W6fTEcQPkxDfufOuUAaIrCUKpYpBo9wE3+vh3NmBhUVsW99Zk4wiU2Eu"
    "ODm5oeaRI+yS1zHX7ULLTYBLWERBTZBdDy+fB1Ybxs4jm721O50KUi00teOlxRxC8ZpZ/ZsM"
    "/fBh+Hwbemy14dSpW6uZap60GoG9LpSqcHs4FRP6UZhSwBHEUlM3l9v3A1er/xmNRSVigUJR"
    "EYmeFgju9rzH9f3Aom//6R/rTcZMBtEQnF2Yu4ZmO3vT+DiMBiws462foXcPpRdMTkBvYAbd"
    "6sD+A/z+QJUM3jWYDRwTCSKXEcwtIRWEqR0qOSfnXB5GI08M8ZZ3XkdVgUgYzna0NLNKMOiR"
    "B/w+jAwwGb14HpNXGHYnr3J3B2rMddGFng7GmY427N3LyoDmMBBC2I+yiCkWzcGlC2hzMua0"
    "d3Ad1wIGtjNgRuMcOho1J60LZzmpfHAWTifuPwbPEs/92XOwdTCm1UshnyuREi3kE8lULJbM"
    "5XIG05hStSYSL2Uzo0rlE9WqkgilSCS+459MJsVHl3K5Bs4EgkwMVHpotHDoMLOMN36Otm2c"
    "tda8hCVcgXyE2CQJqCYZFv2cRf0LIPjZ0YNShZnlA/fDQ0S7HctZxHyM5qEYVlexMANlEzIh"
    "JCoI+NGqx/BB+FfwwBG4zsLaDLUB428zqa9U8bOXkUijczcEReasFitzG70e6QhSJVy6yH+a"
    "Cf18UHfjmS82Rk7KrqsTIOnnxrkPEK2tt1w6g+YhPPcE16EodC+j08kMat4LkxF+D5F0loGm"
    "2x+eV6tzc3PDw0Mv/N3Y8vzlYjYtVuHxL76eLZsk4mJf38D4hfNCuVoqElB4PPXVr0i2rmMb"
    "diduQLBLYEpJxRXE0E5092EtgnCcOUYlxxU6O5GJM/kh0bSjG6//B2RyaEWYvIzeIbQ1s5UJ"
    "ypUaOFQoRFEu8tyE/NBbUEhxely6RviPhAJqGbM6IjAD3YwAqSjMdizOIJqASI5UGL45lI9D"
    "IeQQVMsxNcdyWlqBd4U9w70ECeHGGPIP8cAcTnRRgF6CXAJnK08kRUA5DYUW0+PIPsJ1nB3o"
    "7WeZJq/wUF94EVY7zozjj76xiVEEAsHDDz2oUCq9gbmRYVEur0xGC/uPnDCROqiVnt7uuwSc"
    "ht3bnQgFYLJyQnMMQCnFU7+9od6Be2qg2cT5KptgBtnRxfBNxNHrh2N9GY34tczKq30EJuTp"
    "BCDi3dBpYNKzaLrPzusBnjAzonIBxQwkEk50uSQMZhw4CEtNNMRiSCQ5r1KnNHmT0yAY7Otm"
    "rfTMs4zshGBxEv0xTvj1gdElpHsX5/DOWzj+OdhtfHk6iYVZpHJchy6ZvcpEYFsHFBL81d98"
    "nFF4D3eNIIqr9lIS7ohIKSlXCuU72AB8SykVC7lsLpfNNuw+U1v3oERKXJu4XY7i/SX078Qr"
    "r+DIfYzdAiEuT+MHP+CasiqmZtmDlj1I5vHBe5ie4LUOj4/lidUKnRI9g/AGoBajLMBqFc0G"
    "htSpq9BKcHEBx49CI+JoGNnOnIQANuGGsIrLBayuobCGQBE7BzkNqqWMcpfHIRbwgsGPXsSu"
    "/VDIcGUCUhLGecTSHII927Grk7PRWpCBPl3EGz+FqQVpao3C0cnam9LPCrkFDUmCM2/g2iKn"
    "GUItktBSBb7+Oxv83ePxSiSSH774WqFYEIkF5WL1m9/+xzrFvJuyMD/v83m7nR3r5+RFaO/m"
    "oyhnL2C4u4Yq3fC5MTTITLzVzOm0r4fhnmoSgrcC589jxwDkSs6cA0PssHqKhirjiUYFIbm8"
    "nVmQRIlMAgo10jm0t0EuREeamdyhXUwH1TrYmlnTW1vYZGl+yy03FfTytQQULQYIFejq5/ch"
    "EogO9iMWRUzAcjqe58WfqgC+FR6VUgWtkSPDbuE4IIAKR7j9ZIkT7GAHdBUYrWjS87RRUrUa"
    "kUqie5iXzKrY8KLREqfXLNGb3//671kGqyM7nPNnil7XglIpFwkF5LPxRNpkMhDRpg86neZ6"
    "lORyeY1283cYUJPZbDadTiuVKpls/f0zpCEp5Im3UY4iYUmCZewiVv3s1ASssQQ7nVrJ7kxy"
    "5rrarF/19tvs43SrdBui2v1TviKg0GnZCrEIr+FQuETXDw9TFqEgJp5noWRb5GQYirC+FUiY"
    "sJMOqghr8o3Ap4mfBxXL3BT1RVfxeuRNhVCIAMe3ypRx+/aGEqbflOeIERH4ULSpFbyCZHey"
    "AK5/S79PvQ+9ccP7nAYGaPwNHrm4tOx2LTva2m0tlmr1kx58IGWbK1adN9YxNpSL4xfI6G0O"
    "m5JmT7z+1I0g741fIJbl0XT3I+xDKMrjXlnj1xGSyTJ5tNkZCn76MqxtfGMUpAOdeP3nfERY"
    "IEZvM7zzOHcJAzsQj8AVwFNP4uJF+L0QSdFsZWlO1l+YhjeMFjvMYVydQ3sTzl9BIcvZYt8B"
    "XilcXMbhRxH3cVYPhFnK2cx47Q04bQgFGZTMRKvUSATRs5NXlWmQuRyrhGwcr77GpJO0mLK2"
    "BEYtUAC1OyAs4Mev8I00aTmNzyzC3IxqGWUx7j+8iY3EYlF7uzOXL6yshutvTvokhWbI2txC"
    "sbLptwqFitgaCWCCL8H1vJpPo6kdc+9g7z6EVnHvTngpn8zCamZe32xmZlkqMNAvLiEjw6AN"
    "E1fQYYF1G+bfxN49nJapJhF5kjx02xfP4ZFHWZESLhNNLOZh0eHdccxNs+IlfKBJItFPjOXA"
    "Xvz7TzDYw7Lzw8sM1uRh7OMarGVrnUY5hUaD/H8KR0+E5dVUjZvKxcxhiKRTNaEIl8d4sYim"
    "ubettiZBalnAX5EmCPh4NWbtfxq7sp4moih86OwzDEiXmdoFLdoEUENCYtCUkBgf/JO+EUn0"
    "F/gkPpgQglsV64JLW2gLbekibbHT6eD5sNaERb2vd6Zze+6533LunVaCJGXV4FNQ1wvGzo5g"
    "JHzuyc5Wu80o8Zcj8Lns11Ao5PVPnmQ+fk0ZsqHeaIxr+p/3PbJZeAq2lFaEXmwMLCX7VYkN"
    "jo2vl8sCQ4Z+lQOUSv2+Kw9ZtrGO1Bu2+XlUFFgpMWgUy+T8OFmP/GUpS1WKR/Dh0djAdjJM"
    "sXCITQLQc3nsVzBFS6d28Pm5LDF1P+wb3876Mp0edCWT+C+HUIRkAV2qRpnMGTEKBoGcw1av"
    "Vb43asViIeD3O04nnc4YutrteWO6spUrhC3/xUjc6R7attWolEv7dXFEYBMnynJzv+x6gmYY"
    "12aT29uFK1NT6+vrsiD6FJb4Aq8XQ5Nr9SY7p0DQYkWTiEYH88aA8DEDz81S8vVjgDUny8u3"
    "ZJrQ75mntLCIFc2jZx7jbJhJ0spD2NHOMVuyZFx5QHfu0dQ0FT9TgXnsEj1bA+LXajR3gzKb"
    "lLyKUrvXRRRYEbISP+ySIMF5PlqmpbskGTQZpYND2s6DNniCfSJZFmS7bCC1v7ynm7cpvwOi"
    "nr5OgTFaew6HvLiAfYLl+yiOihPkdih5hG2sT++gcZ0eZOX/vAjdc7qrq09s2+a4uziiItWb"
    "rWBgwm/Zs4risd1WVY47X6nq+gW332y02L0qinw5kWi1O7KqD/kiHos6vZ7r9o/IN2qoDFma"
    "qgiSqOta00FujnzbfKUa5u4etnsiCbAcpxknGgusI5E0ARZ86wOFJ8ntIvV45Y6PUjiMKjl7"
    "V0GEQqgdoIqQWkKCj3i4EQapT8UKRW2kVWkPk8QozAzMuNF34U41Hb1MJJk3dCsFxhOPxQlr"
    "Wc9DfYZjZ/JlKqpshR3MN6+DagVrS/aBY1SGi02amyHZBIEzr0gm5Ao/mlmaR9LtUNsh/zgG"
    "/M9W2i1VK2XDAAQ3Gmf/Qpfb74dtq8pS6Zw2ZpqtTuc0zgybIIjxsP0TOwE6OGPVaAcAAAAA"
    "SUVORK5CYII="
)


"""Help image on default search page for contacts page."""
HelpContacts = PyEmbeddedImage(
    "iVBORw0KGgoAAAANSUhEUgAAAH0AAABHCAIAAAClA9+5AAAAKXRFWHRDcmVhdGlvbiBUaW1l"
    "AEwgMiBhcHIgMjAyMiAxMjowMjozMyArMDIwMI317FYAAAAHdElNRQfmCgIJJBF4+XjOAAAA"
    "CXBIWXMAAArwAAAK8AFCrDSYAAAABGdBTUEAALGPC/xhBQAAHgNJREFUeNrsW3l3HMdxn5nu"
    "uWeP2RskThKACIJSSJGiJFKk7si0ZCuRFNuJEr/kH+cT5OWD5DPYeZZekucX2VFkXdHJQxQP"
    "QLxAnItjsffs3GenFguCiEyAS1siHcr1SLzZ7Zrp6l9XV/2qp5eePH+S+pPcXWFZDt9rG/6f"
    "yVKpnkwmMcY0TYdhyDAMXHSaeJYmUcDzQhRF2z+kUqvjiQvnWTHJY2KYDsshxCCMWcSxptb0"
    "I8pzXVEUqTCIqWroe+VSOZ3v2T3Ud6Ov75woshJPpn3XSmV3NKslQUnsHhroNBXnplpaHUA/"
    "c+oUoWjdcOMJhce043gejax6OZXPVWr2s08+4jgu/fEHb4dhFISBwPG2azMMYjHL8ZyptygG"
    "+Z7HYMwQIsqy5zqgCY3plPqdxR1zSk9Pzy2barVVy2jZjletVAiJdNMBL47HZNf1eYFrI8kg"
    "WCKSJIYRRZ/85D3dsH4PC2BiYZV9S8OLSMTQ3T68e0vuyOYulb+mFgRBuHWcCXwfhrZ3bA82"
    "TFuNS42WgRFiOda2PY7DmXTqtv2VyjUIbUHgkyhSZDmZjP8BOH9dVkplJZYszs+mMmkqDJV4"
    "XJHFW2r6QVCraZVqLZ1KYgQfIwQo0BB3ozAk2XwOMzfXJtisKPHQt+r1ZjweD3yPas8uITQj"
    "cBwMYXZuYWiwf0NZ4NnI9xiWs20HBgtPaq94jHlBAEfeUIMIDNCLkhCGlOdYkizDY33PFVjW"
    "DSJBwK4TQPjO59Km5ZRKqxzHY/D8qZmFcrmKEROEPo2lbCoG3dwWmkazBYhPXZ9JpVKEkNGR"
    "oW8Q92qtLmiW4zrnv7zIsmw8pRayt3YFcK+WbrmOdbVai8eElm7rWguzWNd1CLKHHjnIs2iz"
    "zaVSZXmlyBCcSiXrjRpFGM+zddvvyedGhgd13SguLm8ow8TQJAxpVClVCE1Fvq/pRiwRz+fy"
    "O3qyG2orS0uSJLf0lhxPMSSwTS2RLtimYVlGFNG+5zhBmFLT42PDlu2Uy+V9+8bBy9GrP3p9"
    "fnYuV+jxfVcShUZDE0QBLCjs2MGz2xGexcWVJ58hoiSrycQ3CPodC4mmrk2xgsSxwDOIE9Ei"
    "QzTLi0u8G4YIfJ9FhVy+o2uZ+uzcopqUaSSGnolYiSIuidgw9HhJ9l2T5eVcNt1RXl1ddUyD"
    "QkiJq2l1yzE2Gk1VTd7eTEI++ej9MCJw3Ya1UV0F5zfc0NZqQGkg2QaRDQEnnctvjzskBphb"
    "w/GPH330XsJOUVoTfMVnOBaFXk1z0gmx5USIkl3PhUBIsXgDd8+BBWGwmPYDE6IGwzoMTWiE"
    "Iy+C0YSBm1RvDnl1uaQ1mtmefGGnso0BhmF0gzvIA2tiGq12H6lMbhRxsgyP7hMEEbJwlwPe"
    "NbijpScVWfI8IJzuWnqBxc3IknQ3cYf4nclmoGNelIC3KakoLkuyrsdjMV1v0QAquhlqOEHM"
    "5NIxmaewQAKHQQKEe8zLoe8IkuKaOifHNpQLO3uy+YzrehFQEIy2MgDW2fzsDI243r5epjum"
    "18Z9dmb+4uRkRGgg/uMPHxwZ6u9ywFNXpmoaBEF3ZGR48uIEzUscoiF1vPSDE98W0bmVgL+v"
    "LJdoyI68FOMph7COxGFJ1ppNiMnFYklOiLl8rqMM/r68sJztUWEdhL6PedY3zXi+YDeNkK4F"
    "rpXM9KiJdeh1rT4zNR9X40oiI/LsVgZUy6Vao8XQeAfg3p3NbdyHdg8NPzCyeZ5Ms80seZ6D"
    "3L3NzQO7Bsfj8c6NkiQIElyHFI2iIGDw3auEwYD+wT7ol2JoWeBdP4zJkuU4oiA4jjPygBJR"
    "NwfHCdLQ6JDIIQoJNPHA2QSO8QIqIYmiEoNUsbnaLOzoS6qZMAwoAtGK2sqVB3ePZHTND6hm"
    "rZbJpLvFfXZ+4cyp02qMT+R2EbemmdANw7OkuFx+7OiRPcNbEpVGvfHWr3+TSiqxTD/tNOot"
    "i2U5igTLq/XjTz2xq7/v7uAO+Wr62jRAlusbrC0v2hGrKny1qfcU0tWVMo14xOHsDThc27oy"
    "caWnLxv4lO86nCiwDOXTHEcHxvyiJCAkxPbE1v19dXW5WTN937R98sSxo3iLILI4P7taqWPM"
    "ibLUJe70u//91pPPvECtrVb4z7J34KemaQJX3bClVi1zoiLebpV8G8BXqxWKxkDaIdQSYNqE"
    "II71bAdKxCgMaGCiynpidGxTN932vhTNAseH6AoTJogiA7QmJIFrY15UpPVawQfI9Zbtepls"
    "nsVbhhAIaIlkV3ymsrrUxq2TV4uLCxNfXAwwk0iozz59rPvxlkur5859QWEISGImk/JtY2Vl"
    "xYuwosi22Tp89OjdcXkoys+dPU9FARdLx7lwuW7vTEurejCQT5SrDYZmI4Y6fuxIR9ky9M8/"
    "/qJvsBCECAxmRQVRQYR5o1aSknm9vDgw9tDw0LrZ09PXa5WaY+n7Dx9Lq1tSmoWF4oNd4L5Z"
    "2v4+PDpGQwXr+RzHwVdATjoXtxUoVi3bFkTIYsA+PYHnbctieR74A3wPAfMugN5BHigH1XZc"
    "ghCGaYjA3xmopUPMAjEPofJqOxtFMII6MfCDED7C2AWe8wIfMQiKe2ptXxG0YMV7fgiuBB9d"
    "14EF0d5zhMSwNSbQRRCGfBeg8UIbk3V/vzo58dmZz6kghMmH+yOa/Ojll7oZ7vmzpz88fTGd"
    "VMZGhs9PXuFESUJgegBFWr3Reu0nP8km5bsCe/TLn/98pWEmk6nxB/denrxYyOeyauLa/Mrg"
    "QN/ZMyf7Bne7tp3vHTh2eH9lZfHNt96TmJDilMcOjk1enVVzveDsy+XVvnS84bMq582V9b/+"
    "m9fTCvfxB+8v18xqbTmX7/2rv3hxq/7fffe96eLyP/7D393W0qyws3PR9vdHH3+ipTUh9a9N"
    "CNSqwp2MmeiWFZM38CVNoPTxb3Kv5n4SiBDUhr9rhj954ZxmBHD94IHHdvbmu3zKV19dmp+b"
    "gVU7ODhw+aurPb351eVlKZF/8Xsjf7iJUehPfnV58vw5Xkp6RtNwvVyhN6XK5ZXFStP72c/+"
    "foNckCh44xdvgAfwiUxGpiMpjez69eXmIwf2AiGJfMqOqJdOPN9RXlmYffudT3fvGZKgFsdM"
    "vWFZzUos18eFhhFySRnRnHzowEMd5VOffUrRZLVc23/w8f7e3FamTkxMrC4Xa3VrdHzswEPj"
    "W6lt5FWq4+/PPP/9zc1015vr7ZhJ3eS1ax/bt3f/hNs+H6TztI2Hd77Z3EVHbSvDoQW+32i7"
    "obwRz9dbbl5Rt1beZlDdq/0fPnP58lytsaLVmhGsAhbLAnro8PFs4va1/ukzE66jGYbp2t4P"
    "X/0h+kbfhoC/X7wwAZVIgHi3WXXbMVDJqEoYRA3dOXHiuZtkmkS//c07QeCGWOpRBUbJErNi"
    "hmLfzvTCzLQoJUzXeebp4x3dWnnl44/ODI4O8ZiBFNpoWo6pqZkeEtghjYlv8UpyfOyB9QGe"
    "OpnKZBHmdg1uV8NPnjs7NVMMAvLKj1/pkkG3/f2pZ7/nuu7aljzMGLEsO5vL4y52aYAGAPmB"
    "v8AfEonEN/4OyveAp0CWDhiGiUICadvQNbARYTYRv7mLAn7UaEDZwrMcogmwwhAzyPU8FiNQ"
    "Bg7Ocbx0g5K7jm05HswZhtaozd+BmPswgiigGExCP5ZQ0Y0pBaJi2xZNI1nezgt1vQVIMght"
    "vzH1dX+vVcoffXIynYUSzoZSIdM72tPT1TbD5YtfTi9WU2pMkRSYucVS5dW//EGXG0PdCMsB"
    "lPzmb9TULapBmoomz08GvoPEZEIkWMnyTMhJEoxhsTgri0kscHtvuLBjGac+Pdc/MgBVE8ux"
    "WtOwLV3NFHxLswKap/14umdosLejPDN1tVLRgGSP7juwDX+fn7ruMzTm46Gt7394/zYjchyr"
    "Uq6mUsm2vz925Lhp2cBTWcSA14uyElO64n+e52uNBoWRJEpmS8PtVzYq8w0C350AYV9eWsIs"
    "DzwdhuBFkYCR6Xg8i4CeNepNGqHCjX0x8DVNt2A1t0k91LIERk38ENa5j1jBd0wg02pinY9V"
    "KuU2i/f8VDorClvS81qtQiLaDwOe41MpdWs7yTv/9atKtXr0yBH67V//xwN79jabzUKhAFUP"
    "z/PUHUoE1ocRx7J3euN9LxC8LNvL5bLUWiTUWq3VlSWIXWNjYxhC3LkvzwLcksB6nmsa99rY"
    "+0ggezh+lFzbVb4+dbXZ1PaOjXaacDaTaeltsBeXVu61nfehFHoKENngAmM2lUq192vXjiDQ"
    "fzqn171g9tYh3rZtQeDp7g6eAAEplUq42WyZhh7SjGcZkE8dJ9RNU5IEKOcQy4fh2j5SRBCD"
    "TL2lJBIcRsCXNd1IprLZ1HduP8B37bn5RXDYdgrH7M4d7dq+XC4PDAzMXp+iEQfZDtJdQk2Y"
    "uuGDGqIh4TuWybCc77q7hnfVag24hXEdB5IqIQyJQteLAHGgBFpD4wW+0WhqmmFZltbUgNhj"
    "FgMVAG4LhZLvBfcagXsjQOcbWovjWKDrYRAYukE22hjGNg0/CAWxfUQSvFWRBNtpb+4KohS4"
    "XrskuqFNf3XhNELo9zPiOyRrpTgkRigqf7cRUAb6CK3bPwMWAqyGTDpTrVVxIpna2b/7Xg/r"
    "uyLF+enp69cQvnEO+2//+Z+mFoqCjBlYP5jNqXGt0Roe2jXY3398/+HxkRE3imTE4BsHATfv"
    "InUjd6p/v8rS0lKptJrN5dZxZ1FkmHM+YbQaycmpBIfU0I+K02+ePfXWh++fOH4sJko/ffEV"
    "vPZK5c03/rW4tDrUW6g0zUOHD1+a+DKAGhExUKweefzxQi67uaczp05BhtAtV+S5WFI9fOjA"
    "vR77vZSB/n41oSwul9Zx3zdiYDluu2HohP509HA68eTBYwxG/3b6wgelS7/68JetZvj8I4/v"
    "6m2f9f7zF77PMEyrWaVZJa6Io7sHIc2yXPuNmvg7G0Nj4+Msi23bgXV013cQ/ugkjELf96jO"
    "OQ4QNrKHEknT5bXAeO7p8YMje2lChxTVG8P7cCHEtMCl5BvvS1eWl1KZnBJPVWu1ZEJh2i82"
    "26EEYQzsCGPMbAopnudB3vZcN6lKtWqNEMpxXUlo53j2Lh87+GOS9ZHbltqfSe8o7CotL/kL"
    "pU8//WxsdE9xZWlnKrH/yFMRL0Mijkvrm2XF+ZmPT56yWi1JTfla488OPVoszvpugJiAIOm1"
    "117j8U3cV4pzTctrNVp7943NT1/XWk1GSAaWdvjosZ5cV0dN7kuhF+evA5+ZvvI5lEcMxsRo"
    "mhMXMEEUzUiJWAiuO7KHMEJIol27H+SFu3rw8f6TxYXpZr3SPuTU+YwYjjDA4hkkqx6HqtMz"
    "LC2YlpLcuxcRHJJw808a3n37P/WAUVjGj8LegeGTn7ybzQ+2zGY+mRoYHoHVEHm+SyhZiR06"
    "cOD6lUucJNVrrbG9ozPXpghF3AjxTDQ6vi+j3tPT2/dU1nGfWlhdLJYFnq6Du5+59PqBvMLH"
    "UIxfe39KQ1AGzr9RmO0Z2xdSTPs8IvF5UX7q6RdamhZPjmKaoRA/snu354WcwDGIhTg/vm8c"
    "yExCiYuiuLOvNyIRjdgo8EXhjjec7ydZx/2jT87+4t/fIRCfCWVUZp4ceJnHrYwT+58vSr9d"
    "OLNnZOeDY7mevvHOCY9YQmUw63suZMhCLgf/avV6OnXr32NALef6AZF4yzBZjo/HFdNyOFbx"
    "HFsW7+TAyP0l67iLgIulC6yiG1U5mRISWdvy/uWjhZNzGkNjzbQuzVZefu5EJzCcPPXZ9LWr"
    "hu25WBjp69OqKy4hIoosn1GzO37641c2dwAFmtb+AUp8aX6x/Y5UjUFxNju3+L/tnGlzG+eR"
    "gHvuA8DgvnlTBCVaoiVLXsmuckWyvZazjuzdj1v7Z/bPbFKp2myuTXk32U1ZieVLhxVLlsX7"
    "xn3MYAYzmDs9BEXJtEhZtmSqEjWrQBA1BN7pafT7dE93D09MxOPxx1/w34js6P3Wl3cIjwbf"
    "NUw7Unzh33+3afT7tmNzYtRD1+A5nVZ9AJ4oFy/+E1y8X/rhOM4BhajjUzu1NFNH7hfVzJ46"
    "fdgnfsiyoy+5oxbyqa7SLoxNDU9Mej5hu3bQD4hxKEX6nm2afQL8h7/F3zGGf2fZUdn7v/kF"
    "Pt65jWEOQg3EolCuAkOD58JECdKP7qp8Lo8nXzNVJEnDAgx6ulqg9H4fY8tA9c/licvX9H70"
    "2GEv5+9Gfsj+r+dyX3bsvdkAywGBBVEC7pkphFEV6JkQEgCDZd8LWtopCqoVyGSDalN87jpg"
    "9AHDAMOE+31FPiyvQC4HtgMsHTwKQuAw+wZIEngOyCpEwhgJBu8QtL7jWxHguBCOwIMZU8uy"
    "fN93g3ukVFC/iJSxne8jg5El3/cO3Y7e11ZhdQOaVXjzHZgcPWx935OODJf/CKoOLAuWDaYN"
    "k+OBWrsdoEKQCMFGFaIhqDUBGfXCj2BQc4X6+eQjULvgekENn+PBdAlqDSAcyA7DiRL86SOg"
    "GMglYX4FdBlYIdjJUKM/fg+OjN3/9K7cabTasUQSXKur6oOsq2kYxZGxVOLxumq+KTt5sT2v"
    "DpAcI1KM9ZEj8U+KJDHs5Llv1X/zXPaTvXmxTz/8Y6cHDOU0O9bp2cn5xeVmW7n07juX//Df"
    "+YlSPslev7H8xj/+aG2VnZ4+7LV/Xb64eW3+zqJuWuff+vFIMb3fYWqr/P4HVymK+Jd33vzp"
    "f/zSdrxYMsyRrM+QpIOuhB4Zyn35+e3JEzOdWmt84s2JKdTJ5Wa9TdD07Jkz87duYlhz8+q1"
    "ozPHF+buDg8Pz8/NX7j4rzTD5rcLL3/1X9tdAD5wIrxyHqKPau3aa++maX6zRHLwIjrEchmG"
    "f6Cm1MOUrS3IZOCRBZ/dLjoGGOSlKhXQdRgUZuTzsF+V6V57X19drbc6ntUfm5puLC616pXj"
    "syfnFlcY8ELxJOlZrufX600pErGcREIaFSLAPxsup1qtzP3lVqKYH52YlsR913Tt2qea2mP5"
    "0Nl/eOnaZ5+bhpkqJA3FINige7TTbg4NFbbWylIi7npOPDpN0rC6vKiqptGTU8VRW1ejiWSz"
    "Wh2dHF9ZXJESiU6tOjI5S5A7n7i5EezeaO+4jeeKj172bl5MKHCcofU4hozEEom45AMxVCzY"
    "fZ3mOIENy4qSzWWpoDGXaXcgxwM8G3rHfah04gWkDsI/KMCbOTYjKz3XMTzPjyfiJE3nsmkt"
    "piGxcCyNJ0VRTDqT9CkmEc9sbgLupiwnpHjRjIq5XKZWsXFvC0ejvufHUimBJvx0qm9Q5C7X"
    "EFDeCuw9IoFlAv+o78qO3hGQQqFwPBbHLTSbjHaUruvYkRDbo6kIz/QsX4rGQiEB3VmnWRfi"
    "bYLg220TV4unQZIkx/GKLEekSHlrK5PN4VY8qNrAXwhfitxhKMIl+FQibPbNza3K8HBxY30t"
    "nckjICpdlWVpKZJ5rDbCXUmlAp/e07oHz7ATxFC11uAFkaYIXB4vBjNE0DwRCimakyTO0HsU"
    "zVAMja+PjwdOBmHRcT08hb6hB9UtNIunhf9LU3Q0LmnlcjQKu7fxC3m8tAFB2RYckN5utTqN"
    "Rotj79XPKO1mraWDZ9SaxulTpWql1la01994fWHuIyDYSqtbzEitpjp7arbZlluNOXxxdHzk"
    "xmdXhXAYF36kdKwnN22/ILdbd+8ujQ5ly/V2cWRI4umvFtZ4xrdt1/SYcy+fuPvlLcNh8Qrp"
    "mnJlfkkMxUy9+/rbb338Ibz2GnznEhvHCmaVREL7bme+7/S6enljPZl6tVatC6Jqmf1AzTyD"
    "RsNwvNFFHbTiuTx+b9Ru8tRp6CqyYXg9raXIPccxCYqtVbcYltvaqpj9Xr1a9WHItKhBI8n1"
    "61ApB+FCOAZvvg3xyMOXMTI6mt+uED6IIy2rT1LsNxudHmzo7vU0jhfo55V+30467YYdNBl0"
    "93Jko2OdmZ1cWFxuBBz5k8sf/G88EsJLnUimrn96bfLopGUTPO2g1dMU73tmLriCMzZu4pnv"
    "t6LvIb7nvv+73x5/6dWR4r6LQD/+pw/+v1ZvvfvPl/7zZ7+MZ9KZdKxRbrAiF43FOm0lX8hu"
    "LCywibjTdybvcaSm2UBYkUhsaWnx3GsXlr66OXGkdPv23UIhP3/nq/N7OHI7Tf4kOXKP6IYu"
    "CjuOTdcNxxF2cepvQ54eR+6198W5O4ZNhEOcrBjDxfTa2rrRt2ZmSouLCz3NjSXCLM0oalcU"
    "IyxNlqv1Qi7T6qhhgeKl2HD2CH3YbNPtNA2Hyqb3vXFYqVQb1S3NsM+ePX3t0xtCJCKwZFfW"
    "eEmgfKLT08eQI9e3wrGoJEk0mUOOXFla0FSLYX3T9FChjCB2W7V0YWR9Zb00PXn787+cPHsB"
    "+W7w/siRARc8LkfG4gne9q1+L5jFRZH5XN6wrEg0USwUbdvjRcGxHDEkkiSTTCWyuZxp6OFI"
    "ACepdEZWQAw/+pOeqpA0Ez4wh4FwkszkE64VcGQqwQs8w7ABpIXDPbVbHBnDrTKbTZO4x9JU"
    "swmJFHC8yAvhvmnk8nFNNzLJmByLiTxnmyZBkKXjxxyL2b0Dh0RQrTw+RyKth8MiG4/Zto08"
    "2zftkMBrXYQaM51K9nWVZkVBYHt4NQxNNaxsamh3ysm3myT3dIVlmb7tH3BAOp1aXV5hAgQg"
    "yCCjyG6XF/odWcZgUOsqaFUOsz3MiiTHxgIngwboui563WCsiuf2+pbn2DQTooMyaoQOJG9X"
    "DO0oMJeD6emAIx0bvg0Q7/wbfk/rHQNco9bqnz45haSFKj9/4by5vLbR73um2rPp8SH0LfJi"
    "u3ny5VeWFiA/DMlnph5A72m6RUrh/cvZfFBVVdncSKWTjWqDD2miwCFZZoeytVrN7NtRx26W"
    "y5yEp+Rp3eTJl/B4uW94rmtgfEJRBB8KNetVpM6tjS20zlaz6fmFzTIMOPLGDahVgGUCjnzj"
    "LWAjj1jwzr7qBznO+zMNggQkRQX5SDrgyMGfMGhEC8wlOGx71o2PhhbMRPA82/U4lrFt54BJ"
    "WQ9uyE9QBjMZ4MCJFrvHwMOK8fe88uAkisHgi50DtmdMDJ4Hjw+0SHseDCrqtgdU7DsBbu++"
    "evWjy23NDziybZ558cgOR773kyu/f58kRU3tjE9OLSwsgmezQtiy3XcvXfyf3/xaMZzxqZIA"
    "dq3RpLjIyy8e/cPlj4cycYKPSCwxt7yCMbDA05QQe+XMi32jj/H43Bw88Yzmn//v9xZBzrx4"
    "tpDet8/t4ytXlK6iadql9y794ue/wlg/GhZUWeVjIYxKDZco5pOLd+aj2RxGpZnMq8iRn135"
    "M3Kk6xmiILXajZnZlzZW5qaOTn/84bXpY6VbN25cePvfdjnyt79G3QdPeBHOPSWOhIfNwnId"
    "yyeZh5a47x6MtrC+DqPPzH2V/eQH5UjdggFHjgxlVlfXDNN+YaY0v7jEs4JpmRhS5ws5VWlt"
    "lJuSFMZdKZrMIJn5lBDmoaNonCBOl47pBpf9Rg589wrhN/UpKb22tUEJ0dT+fZ3oFq5f/cS0"
    "4dy5M1c/uS5EpLDAdFpKdjhvmlYw4F7kKuv19FCm3WhnsycGHKmqJq7dtgPXkS0WK2sL0VS+"
    "tlUdGine+eKLU2dfJ+5x5Mb6dlrGD26XPgZHxhMJwUJj7zEsg668UCj2LRM5crRoeED7hI/8"
    "jt4slc66LkkwdCQkovhecKOTCRoFQ0ii4HHGd5kk/wQkLElAHcSReMmPzZyQOy2Ek2QmxSNz"
    "EOTwuBQML+G5nmEiVmZyCZphsrmMLEMSOVLAzSiMu3G+mEUHhYBXHBnnOd6zgyTK0eMvIEfu"
    "OnJ07tUqUPQjONIJqkqNdvte/t3zg4GnsZhk2TbP0rph8iyLHNl3CAosQRAsx04mEv2eFpIi"
    "+KPrKkEy+fzYHmaKHFIjsYO6oA5yj4rc7arKdrop2DQJCk1H0Hs9G5EBzyTgQiuocHYDaMQv"
    "ZcCRJAKFF0a+DoWUdhuvk2VaDI12SfMc25Xl+JAvCDuKR44slbY50jqIIzud9s3PbyRTaVrv"
    "qVsbywFGdg2eJbWek8+n0C500y1NTTYrm522EomGLYeohTil1fJpjiE8khPHRoprzXoqdTiK"
    "3iOq3PFIJirtG79pqtyodVzfcZ2pbruuys1eiG83ZJd0aZ+iRY7yttvdRQ58tlU3YgnQNUXX"
    "ENih3W5g1NJqNTjUT5dV0Bfr0XajQZDIr3Ryu46hvAlLRlDy5ZEwNg77dXI16jWMh+Mx6a82"
    "+4BWPDhp+AAAAABJRU5ErkJggg=="
)


"""Help image on default search page for information page."""
HelpInfo = PyEmbeddedImage(
    "iVBORw0KGgoAAAANSUhEUgAAAH0AAABHCAIAAAClA9+5AAAAKnRFWHRDcmVhdGlvbiBUaW1l"
    "AFIgMjMgYXVnIDIwMTMgMTY6MDA6MjIgKzAyMDDw23fuAAAAB3RJTUUH5goCCS0qGDAqowAA"
    "AAlwSFlzAAAOdAAADnQBaySz1gAAAARnQU1BAACxjwv8YQUAAA+4SURBVHja7VxJcxxHdq7K"
    "yszaq7t6w76SBEiAmzS2QiHbM1LM2JoIWzEH++ST/SscvjjsgyN8nZsPPvkwEb744pPDdjjC"
    "4bE5pERZEilSxNoAGkvvXfuWlc4CIBICwQUkyAYkfGwUu6uzu199lfne915lFl9bXeTO8dYB"
    "2d/wxAW2pbsAADzdiNKUUp5tBUF4vDNNU34X/T6EJyY+Nn7PNrY9ZPCRR/f2sVldgnvPPv2v"
    "//inf7v13rWZtdXFP/j4k6/vfymrSsKLbrsBeM5xGj/9+JNf/eqfdQ0Pj493Gj2Aqann1xbv"
    "icUxDYI//bM/x8Lr2fJK+Me//2WEcxSgnIJXllemp6chiGLBAF6r27NCnNMh9aKomNdXqhsI"
    "ooFi8eL83Hs/erffzHM88zOsv7u25YYx22KENE3rdC0o8ISkEAphlGiqiCWl1+lJikziiAcw"
    "IVESE8TacAKGfGVwROhHT1qrVgUBUA5GcQABIGkqipgNTREJcUw4wAMBJQkzNQQ8ZKOZvTZy"
    "es4w+ks66+/7vPfXjh8aGO+nwt/9ALHv35MkycKOILDwBASQRUvKPQ6ZlD3Y/mw3i67ZGy8T"
    "TE9PHDuF2Of9b/7ul6vVtYszl8OINwu5j378QbmUkzD0vaBYMNa3Wwsr2x++dyWnSfe+vJcr"
    "5KIwlGUtDn0/DHheKA8MFs3cwe9dfPhgcXVNwsiyPcPQOr0ehuiDH39oGsoJWl+r1VzXV2Qc"
    "RhGlzNXHjk9FBCQJj4xNCN/2js8/vcNhqVwojo4O95vw7/K+svhwebXm+zEAQpISP4yKU5Mz"
    "8xcG83qna69tNm03TEnKWl6eu8w6Muv1EMI9rXakmhyfnh6fmur0bEPXmJhjIZrpIojwyVpv"
    "5AxdNzBGJIlTymygJkkQFtnLgwZdvX6TsIMKgn6z/RTvJM4MrVWXwijQc/naxnqdxLeCcHr2"
    "Ug4Jy13nZiUnSIi1RAgd/PxBgXwQGItsO1CR3qj1uqZ/+/R5P4SYSuOQJL1ZY46Ffd4LpUqj"
    "5w4ODFiOK8qqY1vm0JAtgM+bHebuoar8uxd9GCaGiF7v586xj33eEcbdThtCZBbLxfLw2NSF"
    "7TiSkUgU8Zqu3VBxDoEiysauZTs8TWVVZSni3mcFAT4dZ9utpiQr7VYbS7KuKcwRYVEEJ53c"
    "Oo7Dsg0mCpjT29se2azb6UiSGERJPtdn5X6Y96WFR51OhweiqBgXDHFr9bY04ijOOyMjH0wL"
    "/FhKuYhiPhMnVs/2fJcF2516C2PMU37ywvTTvsZ13IVHC0iUXcdutTsIwvd/7yfFnHqy1ne7"
    "3YcPFxRFdGxHVWSkaDMXpp5uVt/aDEmKReX08L6fN/3FX/2t44cD5eH11c86ze0wsSavrCQ8"
    "GZqa/8Xv/3WNXAi96GeXhnQMX/8nz/GkPlMZGIF24Lr1jfXFlZU1VU8LZSpryca9r/4F/WXw"
    "/j+MK6aVpvrr/d45HmM/r5m9PD8xMRlGBACsqqqpDwSRSAmSJdhbWRxSdqgCUV9KMN9T7Pf3"
    "am17bbPhuna73QgDZ7m9Q0VMIZodiaxOvLmzND11E+1GxUePliQJMT2uaCqXhFEqIIFj2rlU"
    "KuIDEtN3rfv3v4nilE8io1jgAaKJF0SEUvDub70DTii+LiyuYCQYhhrHhPK87zgCRLKi6Jom"
    "ik9yhUajyafJ4mK1PDxwYWqy35wf4F039HGmcjl78Zt8uVxp1Hc2N3pGUXOsZiKb84W5i4TC"
    "rF7AjYwOB77H8byIxcDncmKm0+lT3ysr6uTUhOuFAkh5AP0gko1iQtIkSXebnwzxlXK5Z3Ug"
    "FAI/4oCAsETThKPpoWZsp+04+WKB5c/9Jnwf+3H1X//z177ns0xPlnCn01IVpdpcVucnk2Rd"
    "MuYBNGlAfjY2VlTkfhv8fcCTuPrxR7/z1Lsf9tu87zOOHSpZepL9R+n+k5dAFEWPn9BnvEtp"
    "GsXxofZvCJT9WJo+692s+vTcjxMW3Ojzm7wYx9bjK6s1CIjjuIQk41MXCvmjM5G1lYX/vfN/"
    "iqKJAr+yWs3li6apbGz33v/R3MpyVckXZyeG7nzxFQ9kLu7GBJYLhUfLS6ZZlDBNgDFSEnca"
    "3eHJmXevzTzHmFu3Ptc0IWLBXciuDTP/PjkxyvTYoWZffPZpq+eVK4Wd9TXHDQZGx1ISRCGV"
    "RH55YXXu+tXV1bXKYElC4naz4XvJzRtXWq1m6MWRb9XbvUuzlz3XTuMwFcQ0u46VXp6bnxwb"
    "eR3e38b1pjAMxd3w+xg0JQnlDwpT1gPjhOBjxj3WNwmL1JSF6dTzQ0VRWIx9uugfBD4Agu/7"
    "sixFUSxiGBEmcMK94h3P82zsIoy5lJDsUkNWUI6YNUkiSSxQp0CA7HfYAwDWTSmJIw6KivTq"
    "tdUn/v2N4hDp2aEy7XF4D8D42E6PUcw+tvcci88sN0pSJgfwbss9rnd//YlVeP9L4GOr0OGS"
    "9QGinjqcV8B5KtQfHLu/d7tdwAYmG5GUimwciuKRVcDtrU3XdXkoaYoIOBqngMY+lHU2un3P"
    "03NmqWi+vvVhGPM8ZYFutyaaTRjYuxDJTDrobZr1epxSwKWqngs8R88Vuu0GxNh3g1K5tFnb"
    "YNssmgIBA94NIxHyrh+bOZ35lq7lqJLoh5GiahiCKAo5ARqa9rZ5jwI/ZMkhJWys+EFQLpWP"
    "LL4yT91sBI3WZs7IszSWeWC7282Vhny7m5IwpuBEeN/a2mo2m2Pjg41GLw4CAaPAc5nYuDQ7"
    "VzSfBHyrx9iLBBCrfhy6bTsgfrc+OjH5cHXFdtytjSrzKve//lrW8qMD5tp6jeOFlBcqpVy5"
    "PNBt1h/UmwIUrK7L0r7J6el3blx9fcvP53H0AefzOPqGc977g2P793v3Hxq6wjMlyxKJMJZU"
    "pVwsHSz+7cFqN+7cfYBRjLXiULkYhIHVbEj58tUrl07Q+gcPFnVdhEhkwToT3hwT70xw01y+"
    "YB5I6KrLS7W1TaxJJKaqrkR+6AWuWRxsbtfmr1/bqm0laaoocrfTpTwTAYkABLNQxJLY3N7m"
    "AJ8rFIjvVde3r797Y3NliWJZQjhwLQGiwsDQ2PDA2+B9YnwUISYeQJLE7BAzKX5UXV6U1as3"
    "5nRZTCggcWgwaExNnEAsPYjx8ZE4DniARIyYjomiiKepFyUYfee4RFkemx5XtBwW+J7tVi6Z"
    "tdp2ZpGC2Yliqmx8eMjpdUzTjFhXYuoIAFVVEGZKjEuiQDfyLNeaUXRNEtk5QJIqIhjpchzF"
    "Of0Vhc15XO0DzuNq33Bs3j2PeVIuq4uQ9IWNfd/v9wGeUhzbvzfqddvxMOTCOK0MDg+UC0c2"
    "W3hw78GjpZ7l/fyPPimbr5vdff9w7t/7gLdUj3xz6Fk2032qrvPZ3DFX09Qjp4i3mg0Bifzu"
    "ZWS2dV2HEI7JGaZVuk5QKuQdq5fyAhNFTKTZtjc4WOF2r/BACJv1OgWwXMqGtetmPpZJnYNf"
    "znayPXuNPceiQlaSeqHlZ5v3VrPTs7o5XWr1fAWmhcHJocoRUrXX7WEEvnqwHFhto1ThScxB"
    "cWdj49LVq9vry3bPBlJ+0BTtkAlQgePxnd/c9uNE05RufWt0+mLgR4HTSZK0UCp1bR8kPott"
    "eqHSbu7oiqQZattKYr89Oj4TB20O5X/yu7/9QsuP7WdarWZCqKaqh077IXSajerGtsCnmq73"
    "bIfnhWvX58/F0x5eRUcCnoeAi18oZnieDWqzkGepVbFY4LlTst7ytODYfoYl0C/VrFhij8cv"
    "x0b7faCnDGfbv3/zzRLHkUq55AV+mtDhsVHhqGFVXV5oWWE5r0Up19hctUJhbnZi6dHC+PhU"
    "q9uNgnj+6qW7d7/UcoaE2BcIcRJRgN65ee3NjdHX5X3vGs8bJfc5GB4e8gMXAMC0BHr2XOVC"
    "eQDCTkw4hITZK1cbbRthfGV+noVHkzMEhJvN1rUb133PpzQlUcAj3XG8N3pUx+a9Wq1GEUGQ"
    "+mFaLOR2NmuiZpA4AtmS3NzQ4H5x7u7tW4trO3/yx784qamQR0LXFfZgT3IvaJYtg3r88qAD"
    "/A5eyoOeDI7N+8jISFZw3V2DkJLENJmwpb7vK4rCH7ikefXGOzNz8XksfRaOzft3rmLD/YUe"
    "hxabcdmsChGfxHyHY4EkzHNks1+etdrt9OCsx9XldqsxPFput52UENe2RUWCSJq5OK0fqIzf"
    "/vV/t+0QgbA8PG0110pjc1vL96dmZn7zP7cnxia++PLz2blrnebORz//w7z2ltb8HTtviqKE"
    "5+nemtW9xavcoUGwi3az2e72pi9Mn/hasu8BXqU+U6/Xg8Bl4Z51KMfqYVmVZWVyYuxQs2Zj"
    "B8q5c9KfhWPz/pJLzWeuzPf70E41zrZ/r+80NF0mKRAAFwUBQJCnlOl0RRbjOJFlac8B2pbl"
    "B55nuzwUDU1udXssPcIY2T4BJIQIyaoah1GSpmyA+p4LBAQFngVpWdWQQF0vZGpY0XSr0+Gy"
    "taawUW+ZRVNStKGB8g+Rd9vqub4rMu2EReb8YkIYQZ4fMTkjIGV4sLTH+9LCYkJCJCph0Fpy"
    "g2LeiAjLScMwTnmOx1AwyxXX7nXaTQGJLANjZwXwiMni2voGxEwcIUkUvShxOx3AU0EUBYit"
    "bPLBq6/aOXZcXVla0vP5OIqyCc2SxI6TCYkwjCCCGGNC0kKxgBHa3liDSr5UOC3rdE8VXiWu"
    "5gtFylE2SBVZSWnKOgWjnul3mq00Q4/XQSiaBuVTdB+G04bj1yPN/Ms0M/KFl2n2g8XZ9u93"
    "736lGYoiilEU7t1sEUCB/eMBN1AZwt9Wyj67dTvmSRTEUUKmpsZq1fV6s1spl0QMvSBMIsJS"
    "XVXTXM8bGBpOs9vbOa2eb6gs3uoxSe12E0m58fHBy5dnT8rys8373NxMGAa79xUiLFMg6e4d"
    "uVIqy+LBKunFK7MCzzU73Xy+kERe4ea7cRLzaRzGBLCTRAmTMoosRWHAzpuhj8aEsgyFRS6B"
    "5b6yys6YHycnu/b1bPMuSSy0v7gKlMtl9UrN2KtavtRNFsz8wRLnyd+X4fySZ39whvs7cwue"
    "az+/jWU74xNTL/d9J4M0JVa3feRbCSGSrGm7a3TOMO+ua9/7/E692SBU4JJkaHTQ6vV274mK"
    "PKcrQEnVdZomb5l3Fmlq68tcGn169yGliSRLGAKA9UvTI67nj03OnnneGUQJl0qlMCIpiWma"
    "lUVVzdje2jZy+SRJNVWxbatPpoHR0UEui9ppEIaqfviC2BnmPaVAM4eennpZKD+p3Blm5S1b"
    "xTJ2HmVGDY0dTnRUQzPN/WlVZ5j34i76bcVhSJI0N/fiWuy5nukPznnvD8557w/Oee8Pznnv"
    "DzI9s1ld6rcZPzj8P2EkW6DVWMWkAAAAAElFTkSuQmCC"
)


"""Help image on default search page for online page."""
HelpOnline = PyEmbeddedImage(
    "iVBORw0KGgoAAAANSUhEUgAAAH0AAABHCAIAAAClA9+5AAAALHRFWHRDcmVhdGlvbiBUaW1l"
    "AFIgMjQganV1bGkgMjAyMCAxODo1MzoxNSArMDIwMC9/QVcAAAAHdElNRQfkBxgPNhWJEWL3"
    "AAAACXBIWXMAAA7DAAAOwwHHb6hkAAAABGdBTUEAALGPC/xhBQAAFzdJREFUeNrsWwmTG8d1"
    "numeewaD+8buYi8u1yTFQxJpxhJl+ZAcV5xUUklVnPJPSFWq8s+S2CUfsiRLjkSRpkyRFA+L"
    "xx7AHriBue+8AZbYXSzEA6R4JHlSgTM9b3pmXr/++vu6e8lb1/8sSjLxEpptmQzLPe+3mMQ0"
    "tUcJgkQzYjweDwjC1BUf83Rg2QEtS/zt23dYji0WCr7vkySJMfI8v7K6wsqxdDxGUZTjuCQZ"
    "BEFYFzi4tqHZQToRezZv327WHJ/0PTeRSG5UqqLICZE4z7Frq6v5Qq7ZbHGY9FlJFlh4RYTQ"
    "6srK9MxMEBph6ertlcqRo8uIgLcnEcK+78GFq9euHTt6jCQJhmG+vTevrN4m11e+vnbtZn1z"
    "fbW6efbcD3//3vs//8U/fPz5lVPHlj///LzjmETgN+pKppD93ulTn/73BUvram4gCtJPf/bu"
    "+79+P5WMmk4ADWYZphRNLL/y6ttvvv7M4n79xs33fvnrSEIWGV7TlGS+9OrJI799/xMa01Ge"
    "aLUULIhB4LuuvXjkpESqly/fRQyhmcbf/vSv/+NXv41wVLtnyBHm9PfevvXFZ4piNnVL5gVW"
    "Ev793/71W497aWYBTrY2N9PZHEbkiFOv2yERHYmIzyaajxX3eDKj9JSIHJmsBl3tWS4Ri8nk"
    "ZPdPahB3aniSy+fHOsnRZ4QbE9ja2lqv133CSqqVfaeO49A0PeLj2A7DMjuQOs4e6uA6LgA1"
    "wLEsy5ggKOJltlar0Wls1eoNSWR5MZZJPYUUadYbFMatdtt3HI8kSNebnpvttNuSFK03ahAy"
    "VuBLhdzIXVsb1VSm2NxeV3VdjiWLudSIQ31ra6Y8e+HC54uHvlMsZB8S92AwDL14BsM4EVIa"
    "u9Xuuq6/Ve8kXBT43pPXrKq6oeudbg+RJMsx8Fvd2IZRl8QcTVNbm0055tNUc+QuRTUoqlFr"
    "K8h3EaVv10YdeqoO+ZHL5R3XDd8f8F2Uk5ZlQXxZljUMA4Z+URShO8Dly5f/vFVdGdwJrAbA"
    "3/UJmsLPO+xEoVgqlaa3as1yefbS+fNdXYfCo8dfpX21Y1IC7dEsn0gkGrVtMSIbSkd3Sc/U"
    "CzMzrql32l3LdSMSr2p2PhNvdFWt05ZjiZny9ADoV+7dnSrPYnIf7NuWcev6DcyJFMJk2MIB"
    "kEDLMqenpwcOjm3e+OoGxfIYU2icQ6O2sb25rugOdJcw3zHGEHHghRBZnuehZAhw0AaSwBu2"
    "S1HYNo2AxNGIlIhJzzvsMOpEBwe9TitTKs+JLNH/ktXbVZ9kNzQ1m8vYjmd02q1uj6dRZavF"
    "YILmeZGluj09Hhcr69V0rlDb3LAIFgDFNPSQUfbrZBk2GJ7cN991CET7ISUlPY8QBd40DQfS"
    "cOjguSSiwAH6iAeUT+Ity7Ds8V0wjPsgtccaJJWfzzzvII8xluVcx4GDwCeiMttq65h0WUE6"
    "+71z+/xmSoN/Dx3eLcsVwsLy7Nw3VQ7Uc311bXZ2Zm8hogBmSMwwkM4MTbm+T5PI2oNsCEPq"
    "IophENV38HxZ4Ch2PDY8BN/h82q13vMO8jgjadzPRz9w/3JzBWP4UorRzJmp4pPX7bmOaY7m"
    "KeS7blikE3AU5bputpCubdadPYMf5LthmKTtcQyt2m62mKk3mowwHhvCuP/hj38iHAXQmxd5"
    "1zYxQqX5w1P5cEReXV2NRkTdcgFwBswegAvgiBXkTCr+HMPuea5laHAgCJHjJ45DqCDTTK27"
    "tr7B0AgQRuRZmmXlyCTUnuUEkvZHCiHfo3IEszxALiIIy3JS6aTj7cYd8l2WIxTDUTSF+mN+"
    "vlB0PPcb474wW8QoAOyGt7QtE1Qzx/GDy0AbdE1pdHXoXP0E8z3HgR4USzMwJDzHuNtWYPUP"
    "dE2/ev1qMpX2CSoqMBsbNUFkEWbq9a3p2cWjy5PEXVO7iu6XioW9hZDvjWYTURwb5ruTK2W3"
    "qlsexlP3exjke7PRguZnaRowMDeVq9W268126mxyfNyLxV3FJIrC3svlchnY/gwxxmzbeo5x"
    "h+QYHAgid+LU6VQChlmy2WjMLy4OyhE6ge77PK5Jcpw/0F6Q7yAtMagjiiKJAOjg/NKiaZi7"
    "DpjKFXKYZoCVoL4D+CfT6bGPeAi+a5rWbDZnyzNQK3Of5IxVdA8o/1at3WrdWakGrpUulgEt"
    "P/jo44goMjSRLJRPHVuerM5Oq7nd6OSy+wgF5HtldZWkeQZTkNr56VylUjUtO53ZiSwUwmiM"
    "aGgYGlAhP1PYqFbrjfYbb5x97Lg3GvXFxUWltfXBHy4BR7JtEprTNnoAnfOzh1bW7uiGLbIw"
    "eEiYxo6D3vnxOeLZWjqXKy8sDinfiVOvPXmdqUx2YWm0zTDNzi0eAroykC8cx6VTkJf6rgNF"
    "Q2/DNESIGjhYklQoTY19xEPifujQUuD7kUT+zNnXisV9VMGx7VdOHn3GM0oHrVlrfvjB+6oZ"
    "ZOKSh/h3fvjmk9dZ39yQYgl6/7cB47j51VWSFgFnIPcTuaRrA4y7yWRix8Gxb1y7hmigM4zv"
    "2Il82jeNpmqee+PswSg9JO7VanWzun7slRO5XDgjEUrWPmjCwY5UD4HeHsxWD67CKQgxoi/H"
    "dl7IBdlFDQ7AAeAIfp8WIuUK2fzUzwYp5nne4BceDb+WaXK8gNBj58b84WXL1Glh31DHcMKJ"
    "104DV8H9CFi2PUKWGJY/+frrmIL/8NAB9P/Yxz8k7oauR2UeSFulUm80Gvl8HgRtpVKBX+hH"
    "EGioF4gNfCS0AgwGoihCQHVdR30DoXznzh34hVhD21iWBXepqipJ0tzcHPE0bGVlvVpZ06zA"
    "VluWE/zVubduXb3U7qhyMrk0NxXLTCVjjz2DfevmjWZDefOtfbhs6ur5Tz4m2QhH05DvpXLx"
    "7p27QF6OHzsycABe+9knHyNaYFkmcJziXGnlzl3HD06//urBR+zOvz/UAqCa+6csDpaMXN15"
    "xgGfB9/4iNZu1rZqzcOHd5QodKZhHxr2sMks7M39OZKRd/b9YPjW8G2ofzL8kLEOg6WuQcno"
    "/Mwj2sFIPTh2D7j65EEf2qUvbmzXq9PZ+Npmy7NNhDySjqQSiTNnTk1c54VP/9hR3Z/85Ad7"
    "C9VO41e//A0tRkWWAxWTLqYJnwRaeer4sYGD3mv913++R/ERUeAh39OlDPLJnqa//f0xXCPM"
    "93SurGo9VVERNA8K59IolvdsQxSEze16Ihk3NEOOxXqddiyR7LabvBgJPEdRAblcXooC30JP"
    "L46PboN8X15edl2Puj9FquuGIPDP/mUexUbzHWg+jSlAXugWoFRD2g/jkssjBGKMhd7D0CzH"
    "c5iMC4LAUBgUAcYcCGIYYziefy5BH9pXly9euno3EpVKmVRb6VXWNv7x5/8sC0+kpS9fPF/v"
    "2j/+0b48VbvN3//uQ8xH4bMB3+PZeK/e7ln23//d3wwcdKX9u998gDmRY4DPOPFcksHMdq32"
    "zjs/OviIx8D3F80G+b60dBgInBcENEWFwzskC/yPn2iFAMZ/QMKRLQVALkzTQvcrh1/fC2dn"
    "hm5wapjhLAu1x8EPCBhmBw4T4vuLaVeu3Fxb/ToRj359d/NffvFPzNNYk7n39c16x3rzjdN7"
    "C21Tv/jpeZKJYDLwXGdqbkZtdwJMH39lh884lnHh089IWqAQ6Tl2JBkVIPcFvjw9Rjq99HE/"
    "cnSpPJO1Xf+V4yfRU1qSzJVmitOj7UdRzKEjx4C/cywHwOr5XlyOmM6e+XeKXjpyFEYalgXs"
    "JViOtUFB2N88H0n0e9b169eBU0cjkmG7LEMTge/6wY4EsCwWelMfxweTMMDBgagJ+5XFc7GV"
    "v1xZ3VJ4lsqkYtdv3svnE56LQVHaPhmLxo4sH5qgzsZWtdlzzpw+sbfQD7y7t25iTsIECfnu"
    "U0FcitTbSn44jRM63MKsAEDn2TYr8SJHbzXUt8599xvjvr6+fvHiRUVR3jh7+ssvv4SxNBmL"
    "btYa8/ML1fW1YydOfnHpgu1jlkbwSBKDcHBnF5ZehLhPzX9HlLdhkBclKR5PWK7Lc6JtGwjT"
    "wBQmqzOeysbSBzSHH0zPLwC6cywLGQjST+l2ssXSHgdien4OhYumXKiR+yuC8fSehREfwuYR"
    "wZ64l8vld999N5PJIJr77pkzg8LB2thgGvq102eJF9Jqlbt1xfOsjVxxql3bhBFW08x4XEqm"
    "85n0hOvASrdrul4quW/eHAK6ubYqJrJqezVdKFimoXR7bCSWTOys/5AYba6tC/G03l1P5nIC"
    "S2tKD/OR4aymCUnho0IxB02wE3cAjZmZwTR70KjVTNePSCLqiy4gCRE5qnTbLMeZlkMSAD6k"
    "64dL6nAXSSI6nIkEfUhqugOSwQdRYVsBon3HIkgQAy7NQN75QARs2+FYxvP9wZyBZduQO3AM"
    "5RijkB6QKBKRHouWRlMFxPSgYoamY7G45fkRGYgvDqFyUmN5jiVH8R1yNZXLs4KYzyYBUlyf"
    "iMVjPtodIOH9U7kcywv5XIrsO0RjMZfYFb3xeJRjKYbl1F5ndFwFGLEcj8ZI0w0gqr1uGzF8"
    "QCDbBBJlw/DFM5RqmY4L30bZjgPdORGX6/VmPpdWez2S8Ls9haWx5QY06ZMUE5NFw4B29DhO"
    "0HRd6XUgcSRJdl1LVS3Xtjhe6HZ7sVjEMB14dQ5a5nGmzCDvWu1OKpPLZVMEkX70Gx9Up2Fo"
    "ppfP79uchCiq22pSuomIcDMsL/EMw7VatSG+w3d12y1KCzfC+I6LGCzxbLtnFnLZg48YjTuI"
    "oG63yzBY022R51mWbjXqCFMRnlfUntIzbY5JxiKabkFSI5qVBFZTVRBcmgn0VkcYIu8Ydtj6"
    "tCioulE3tZBaYULptXXdikSjptJTkerZ0GbhAnGr1UGk3+70MKKKpQL1mNTbMD3oOBMvLY01"
    "HhQvNUqNQCsJkkxSFB8ucAaYwiAbh9tJiP66By9KfQcuRAWagqRPpsaL59G4ByReXJyHLwHa"
    "D6wMqk4kU+HGPgJJcjSbJyBD4RIv+P25JzrcV2NZ8WQKPICqhvOxQQBIAioDrspRH5oEYxrK"
    "HNdLpshQ3EZl+KcPOzbdFx0ATJph8Rw3gfAVeSpfyGhq557Wk2MxTHi64ZiGCsMqDjwpnozJ"
    "j43ynuuZYe7sM6CJjm1SSLAsB0GQCcilQFF31z3CNLItikRh9ACJCF9k6O3t1vS4LQ4H8j00"
    "6Oi7Uo3eI9sgFWlqlMMMZwGHfuNggj64DL4rCBlGECccAz2fWF1ZzZem9W6LxJQGvcoMchm5"
    "Wt2AwBRYYYK4O+GEz2gOQL4D3rqeB2OaDXhI466iwUCy6+C5Ow4Y2Y7LMbjTU1lmvEJ66XVT"
    "EATTM3O+a6WyuUa9LghSPMGkMvmp6fLEdUImBeSYfRwsAySRozDFkiEKJWKyj3eTEvKdYUBd"
    "cSAfQq4JAoqiQEYMHVzHMXQNRiNJ4F76uINgXLl9W4zwuqFzYkJv1AUALDGeiE6uLYBb6MZo"
    "3CHfVRgzLa+/j8NlBUZVPU6MEOkdugn5rmk6aYbUyrHdAPk0wobtlad3OL7j2B999OHS8lFJ"
    "yL3c82IEokc2nrzIVtvebjabqXQ6cM2XON+9PtTq6gu5jXCcSSIviWHut5rdlzjuQKtiiYcQ"
    "9ls3vzK0b6thPvlT5aMLa8PTN18rff/0dDSWmJ1fevCNqvIyx/1RDJgZ+vYmkUhKNXZpfkBQ"
    "oiAMZ9sfcutLje/x5Iu4R/yhtu/vyv4X2+q9VUESXNdRFD0SkQLftR2P40A/sLphMkC3vYBj"
    "sWU6mA738rIcX1mvpLJZEGAsy1WqlfmFhfr2FpBxw0Y8Q1huwHOMbbvNxjZo1Igk2a4f/kVG"
    "4lH3SP+fiLtp29v3aqLAmqYXTkDZILEtCjQzy/guqXbawLhNUzGcIJVIZzJJRlNphrr21a3l"
    "ucKduysMzyvtxma9GxNIEGVeNNLt9jBymx1H5hlD3VZ1y7M0XUv9f9z32dLS4gR3LSyEd+VK"
    "O7uh86WZCSr5Jnu5437lypegE2EoAyGD+9J+sFdweLrXwr/2R8h3XRLj/2nvWnrbNoIwd5dc"
    "cvmUIlkvK4nbIEaC5Njf3F9QtJfe296DIG4NJ37Ejh0rkUSKryV3Oys2hhrIrWGrVml4ThYl"
    "y4vhcOabmW/G86aE+lh1/aJiUZWM4HGAyHfFCHl1ARiTxJHFnF6nVW+9i6L0G/6cEKmpYcRo"
    "xhwGTsCgluvY08kEIVyURSmxgaXnNyRCkqdcyKLUfJeNwwjct2ubJ2cjj9FMkMGgTYguy/x0"
    "NHGYGccRZe5mv28YK1DU2Yejn378AfJVre72bjK2tfX40iLwFw606g8vm065GLfodL+eVW+2"
    "VlPKX5RZnD7dft5qqQGmeutd+8JiVFzMBfLfVy8XlV6xNhdJjWjOYlRXVAVbNUVXSCNclHa7"
    "5djW8n5TvSRLkt29PSQVEdW0zAxAoWnEcYKw3vDdMAwxJmXJK/KhKjVjLHOALYgXounZo/EE"
    "/AySZRzHG/1hPP4Y5ZpNMWCag/39Bxv9yadzZlu9wdC6QddwqdRb79SyhoMBREI5D6fVnpyK"
    "m08w7nS7lXUnScIYw3NLrj5T0XTbnW5l+RVlHrUaqsWLFGFl+9lzQ9c77SZEiGsw6P9V6q13"
    "UNpfZI25t6l8zgVJ78LvL844LA0GFxcvyNsUk/nLVeoHHso0jSeTkFmrCNNrFJ5lR8cnYK5S"
    "Ct0wALkQHdLOVEPEcViSqPFPUZYaKFGUkIVKNF9IItVvQBoVhpGiOPGMC2XTge/lkNTmqsPX"
    "2uiMP55S102jGBMMWMi/8Qae0Wi0/27PtJytR5v11rtquNuWYTLQVsUNMUDvzFarNExwQqYQ"
    "ahogjlPI5eHGgM8oOUcYlUIDm4MQp4bedRJFM2pSjHWr5GjOXiEIBQ+aWE1vWEJqZBWuxvfc"
    "o8ODCkfWuy4mNOJ5619ScUU5/XByfn7ebm9AElFve2+1Wjf/kluTh4+2qq7v0f7uKmkn93J1"
    "qbe9a3MIuLOzMxwOfd/f3d31XScryjhJXWaB+0cQNAWmOi6yVIBf17BlGTkvA5edj0OmKjBS"
    "N+hkGlJU6nZDlRWTLAg8CABIbRAY3PyES6X29g7YPIqit2/fws+NIBiPPwOWd10PKYSislbI"
    "QqlhQBgAUKjQiyh1TW2tgsgJoB5uW55zmzFqQXBWlCzbZpxzURbkv5z5r3dcve83/Q9EioP9"
    "Q2rRjJeuY/M0TvPSNPU0E4HHwnDKS03VKZk+ncae7+Zg58rSzWmctBqNaRhCistsG54eSHIh"
    "kyrLAh4ZtS9MEzkvFB06Toihqx17eaoRXQpp24AycZ6E1HKiWWxRohorQuULUmW65OHD4dK5"
    "uzukd4QdzzEM6gCqJ1iY1NdknHDPN5VLsW2p0iVBCDYoOBgzTTPwSADhbdelgN5NE7ySTpTz"
    "gVui1u7yvBCarRauCZ8QeNc0qE7V2gLIseS8pKarDT+YMxMu2TbkDaBvWUD6RlTRAg4Cfgwv"
    "S3rvkN4VrPx6a6N9eY65wAE1tb/XEqrldkvkkuvX6JDUPq7WVO71vh65C37m+1ez7/rGdov+"
    "+tsvSKBmq9loBOMwQWUO8XH/8HjY25CI8CJXyN1hEBKfPnmy3jPXXu8Q3X5+92nTCUDvBJPZ"
    "LHr/6vjFi+e/v35NH/SpTCBXmow/j5OCallSkGjMz0bJ2vV+j9/XIHcNv795sxOFs0JI5jCf"
    "mZDrf5pEvmNmnAfN9sHeHwa1v/1m8/jD6XSaAHLs99qnZ6ftTjeJYwCFL19ecw/cNeQO6R0h"
    "13PU/tqicDwvi2cIy83hpizSgJDRJN5+9ixLM0M3ur3BRkeWnDNGu71e0GhGOiYEMqzCMm9J"
    "IXdI7xoaDh9d9l7/HwtcjeC2/7OMHsfR+8O9W/6rK5E8S+Hw6z7FdQSO/Sd1YjwCVetGHAAA"
    "AABJRU5ErkJggg=="
)


"""Help image on default search page for SQL window page."""
HelpSQL = PyEmbeddedImage(
    "iVBORw0KGgoAAAANSUhEUgAAAH0AAABHCAIAAAClA9+5AAAAKnRFWHRDcmVhdGlvbiBUaW1l"
    "AFIgMjMgYXVnIDIwMTMgMTY6MTM6MDEgKzAyMDCprw7NAAAAB3RJTUUH3QkDEhkaBBFPsgAA"
    "AAlwSFlzAAAOdAAADnQBaySz1gAAAARnQU1BAACxjwv8YQUAABuzSURBVHja7Fzrb1zXcZ97"
    "77nvx765fEoiRUkU9aolO4rsyHaaBCmMpI5jNEGDfuinAv3Q/6H/QYF874d+aAonaCMYLgo0"
    "dl3DkWHLesuibIkSaZEUH8vdvffufT87dymtKL4lMSJca0Atzp6dM2fOnDkz8zt7V9SNLy6k"
    "SQzP6dkSuTvx9Ve3b3OsdGh0uFDI7bQ+3xYifQO9la7iXK2hacpOK/MtIhKnVM/Avq4eCGIQ"
    "eUhSoCkIAuA4MAzIPTgAtt1CZlkWV4xvmWCaEEYgSoDhqlhw/CBZvYVRGFA0YRja8zxBEJY6"
    "LcuSJUU3sAEUBfkCKHQIUQJeBAUxe1W4lfpip0AgjIGhM0WX3i69Qgp+Ajzz4O1aA5GSBJo+"
    "SAREdqeMTtM0IYS9fqWXkYBNM9MzDJw4Cc1F6O6BmWmYnwPLg/5+YOHq2PUrha4ejmXi0K7N"
    "Lmrlcs/AkMTstVoQp0ARoAFy2tzn5y5nUoBK4tC0PVVBkg+Pjl44f4EVWNt0h0dH6jOTC01j"
    "956RoaHeRh3SGPwQpN3QnYvg/AywEphoFA5u2eBE8Gd9cGMWjBAKAggMRNhTgU/uwZ4ihD7M"
    "+BCmELnww0H44DZwBPwUEg9e3AVX7oJHg0RBmEBIAbjZhqkCmBH8xe419uZZ0dgXl6jr1y6O"
    "Hn7hWc5qWy2WFzl2x5a944R234HFy4q60wvfecrsfv4sBAzkZfBiICkMj8D01C1e4DFu1Bbu"
    "VboHbNMyLaO3/2ifmFI3aqDx0K9BXnQsSKYgi+UYhyUABwBDd4IuDWBAFndG0cwADQcMP4u/"
    "KQWml0UhAaMznc3Xpxgg5vI7bYYdsHsKXf1ZgE4T0DCoUsDzUMijJdI4SfsHBsMg5AWuS66q"
    "CgGVwGgl49ZEXYeMawBAb0ui26aHTAJUAApZU7ez7YSiBIaXRV40dEkE3QeRA4bKImxOZL2d"
    "tsGzpxTtTsGu3Sv7K12Vdcfk75c0+SUnVdp/6/F2WoPFh70Dj/BIInzriMq89DntAD23+84Q"
    "iQGuTEKUZuc9DMHzoG8AksiSZNnQKUWGybsgCRBj9M8BYSyGtEugNE0zCJIwNMNynO85giRP"
    "TSL6ARSImAZTJc85hONdx0G8hLgIwQKV8jOzUCoALwJnAlXJIh002imh2M4TcTsx0O122M4T"
    "bjtF59sZu9bm7wII2p1qu3NpVKn9Ua1dKKAoq53bq+0l1jMGPwdxCIv1bK4oBE6Avl6YvguE"
    "h3IR4RYVBUFKoYZJtsA0CaMEYRkukhcFvU4sOxtSn505eqLv6Y0eL+VV1CamAfMkEUDmgXBw"
    "4fLVkcMnU5rB/UAw6Qbgu8DLcPPmFy0nLuTkyPfsIPQsO5fPD48emb49tmf/MaPFe3a7tkG5"
    "EkxN3c6VBwKnYRjN5qKeq1QPjRzWmyCpELtAEOhyoGmZXUIWYhkEPzOiSYOGpkd07LUZqGxj"
    "zAC0XW0TJ2DyoHHZKMsAeS9QaGsGTNIWNQch1xZlZO2sE/djPrO1w7WBqpmVUbgiScmA4dwi"
    "VCowX1s0W74is5YdmMaC4yW4QJEjX8/XA7N54tTpOCwhpyRBvdnSEZ0/EUmSdN9lM6+FHcBN"
    "31waGxt7+ee/zqkCnnbC0Hg8mk3LCza6zd0zUPrNP71dry9ygnb69On7cnYEN31zSRRFQdZO"
    "fmdv5PpOELtRUm9OUEy6wRDCSs2mPjM9MzisPdKP/y6eAyJCGmR3LHgk9x2AL69+LshSy/JK"
    "pVJBk27evMnwueMnDl+9QJk2MBEkIgz2TYx/NV6sVKIEMBaKDBWGESeIee3g5cvA0llcCiJ4"
    "7fvJx+//d75cZRnKD2NMBlZzUdZKB48cun7xvKxIph2Uu6qqyNy8eVtUiy8cOzj+FYVqTI5D"
    "oR9eHAnhwiz0aBlSm8OQh7GZyV69IFP+aFeGA54h/foff5Gkywz9q1c35ldlXpKMarV7RX8W"
    "Z3p6Xwij7EZw6S9fAKNZpxg6DmPbtmmG4Xk2jpNiqeJ7BCdNY0gQ9PC257oR5h+GoajUNKx8"
    "AbeU1tQ8ZiHMz4SF0INKd9KoN2k6zfIeRbmIcSmW4zlVLbl2A7NtFIaW43IsiycXl1SuVBt1"
    "mmQXa0DRUMRYj7uHLdzJRTvTD1EboUFmM2AsPtPzOjExUS3l/vDB2VKlmKYJYShDdwulQhSF"
    "r7xyar1Rt74aC6OQIfyBAyNLPTtzL/bNJbT7nj171vyIotY9dou12SSOzZY7vG/fUs/z+P7Y"
    "lET+5xeuFvJK4lOMzM5OTL/02vck7rHN+Nzuj0dhGPd0VxmWZlSCeW333iGOZZ5AznO7Px5x"
    "PI/JzPPCcjmXz2lPLOf5PcHjUeA6U1PTeqvlBcHTyHnu749HvKx85+TJKIqw7XkezwvUE9Wx"
    "z+3+eOS1jPc//BhBv+fYFMu+dOrVSuFJnsMgNJXeuXUdge+KSmh1z5ofddpb5N86w2rJ68nZ"
    "ePg2kuUEg4ODP33zL59g7Ny9r2m4H5oEniMts2WY0zTNxlGYpEmSAsMwAks7Xox4CLVHbGzb"
    "HkWnDE1jNse1JEmSARn8SBKjwI+BRjQxPbeoybxuepLIIluxmPdc2w9TSeBajidwLMKtME4J"
    "IaLA+Z4XJWkcxX4QSSKH/JKM3aztesiEkA1rBNuNCjm5abRQB0UWjZYniiyhAAcSwlFpKAiI"
    "dV1FZPWWK/IcneE5VC5GXCXwrGVn32P19XZlt6HbRHFEhb595dpNnhCgacLRUZAePHwQnXfT"
    "sb7vZpjxAVHXr55DVZfeoEFpepNMuxWejQduUQKyIZp9eo/dRq8PIurQoaNN3YC28/E8Hydp"
    "uVTceIol3HTt6qXualenE72BIcy6Ud4PghVLZ57UfToDtyjhiSf6kxIhjGnoAi9W+/s48hga"
    "EsKy7P3HsNDz0e6kuVjz44RnWdw2PwhFgTd13Q3Cnp7e2dnZXQPbcNP//4YC37McNwgiwTAq"
    "peLWB9q2c2d8XFJzpWLu3uw8aXdZUzNzthPIcgYKsFjS67O8KEvK88dUVxIniH29PdkXKVZr"
    "2nG6e/vIZheigeehha/dGD+wp+fWxMzrr2c3aMSybDeIy5VKeRlrqZQhMccyXfdb+JTFRoS4"
    "6fr1sWpX2WlZCSGSVijm5I2HzMxM37lzm2NSXpKH98rTUzMs1geXzn+Spuve3KcZwabpLYrj"
    "rZQN28sWxwnD0NsiaotsumFpW7gbiKKYLAv9t27e9H2/t6e7XC6Jooi2nJ9fIFgzsOsrH2Op"
    "Qz2yuiSOzFZL0Qrk0VEcy6B0TPFrysHCkWs/Bty5RTJMU1PkIMSqYI3ncpENJ8KTqCrZw1Bp"
    "mvh+JAgPHw9eKs/ZZUogz0KtWe0qrRDlOZakaJ1oUK8v5gslZpUn4YyoUk7Tlj+xjFI9LxCE"
    "+4vK5xSOzQbiSj3fy2k5ZPb9jGH5wgOgkG1JGr49cujAsi0JL126XC6XHxuvRq75z//yr3/3"
    "9/+grnpG+j/fe/el7/3g7Ifvs6IU2H7KUWIamkESJTSJozf/6m2Ju2/izz47N3ZrXOEYw6EE"
    "ykqJwvJk+MChF488VNE1679790OGiilOzOeExqzOi0ySRkK+7+03Xl8x9e9/f8aPvEYjKqgJ"
    "r/W/9ZM/79h1fHxiYvKOFwLDUm/9+PV/e+e3pZ6++sxsvlIJcS8lokjqj3/0g1Zj7j/+8JmU"
    "WEEiMiT1nVZE0X/7N7/83W9+GxGCde8bP/lp7sFj6Gf/+L/jk3O5UtnV9ThNCUuxnPT2z9/k"
    "l/nBmTNneI6nOYUhNBO4EUNs03z19dd6e/s8z6UuX/yUPI6/r0lBGC85cqNR53hRkaWN2bYo"
    "bTXhIYhTdHMG/R1bLKG3LgpB4cJiA0Mztvww5jl24xlNE9ObXyzmcCKx7fJPrz/L8mHo352a"
    "IUmcBPG68R3RQa5Q7hy0dWcKQq69jFyxeytsHcr2NU0ohk2T+H7BniaeH246I/KFYYQl8f03"
    "aYKBZ3UeWpoRZ1kSni/3duZdjg9WK7bmWtZk28oyOxT6DtodsvsZhl7uNBfOXzz24vFO9EGz"
    "TE9OYtFPpdHE14v5Yv5nb76xWpzrunfuTBw6NLqxQgiU3z1zJl+uJDHNC3y9Nm970XC/emPK"
    "EehQknjCqQNdsiJr56+N56uF0Gzcm63tP3zMmJnQHef0j97s61IfGDr95KMPTI9RVX5+Ziqh"
    "YGj/CyeO7V+t2L+/8065uyunlc2WjuCVZbhavRYm9K9++Rb9AGe6ln75+u1TJ09sor/rYmLc"
    "1O4bsN24fnW+1sRPqYuff9J+1Oo+mYYhygr7IB2jv/cODCmKulTYYMQhZI2UgOkF3afjfesR"
    "siFPFEWYEh0HlRNomvZdq9HyquVSEgcJkDSN0WtphnAsmyC+jrNLhaWKi82Q3cP7OMdxsCDD"
    "lu36siQybVo9IwUUYTEuta+VsDh2nKyowAkw1T6QlumPgJKQTfVflnKfhM2xzSgMTKOx0t+p"
    "2GtfUt1PmujvRqPRsiyIo4bucjw5/sKx1eLQCq1WS1U3+UEBst36cqxQ6c5+8+J6tmXqpqPy"
    "SSuWHGtCU5U4ZTSB8qIU52I4SKPQ0I3de/fber1Rr48cO1HQxI6o2ZkZ03Y0RUoogpWDtNaD"
    "xcg2PTkeM2oS2IhRDMsKfZ+ChqLlBvof4vA0iWbn6kNDuzfVfyt234DN9+wozBor89L8Qn3F"
    "JU+SAk8ILwiiwG0waxxv4UewacxwfH1hfm6+hpXlQq2OHo2HffLrCazL5mZn9aaht2z0YqwQ"
    "ypWunKrkC8XA91mOLZaL3KPnaebePYSCOMrQTXt9fIfZgmPpdq6javMLNLoZwzZ1fYWp+M0z"
    "ynbSyjgTxxEewY7l23m1KitSu1ym/cDvrlbXWJvnYTTgOG7jybJTT1FLpS5GGwxZGArTyKd5"
    "NY2DpZiYxGHLckNMmlEQZQ9CCZqmtQw9TtJiudK5ikKfCoKgI4oCrFYZnlsjzhiGoWkqlg8U"
    "QyRR6My7PARjYee6waY/3/0TxplrVz5T+kcHu/MPtgGatQVdz+67b08sHD1+ZE2JaIWJycnR"
    "gwc3VgiP83+99x4ryknCiJKwMH8vTslQj3xxvF6QsUhOGS430K1Wy5XJ6Ubvnv7INr+4crV3"
    "cDj1WniaBDGnVQudGc+d/Uh3KE0TZ6cx87MjoyeOH92/WrFrFy/yilwqdTfrC64fcCw3tzDP"
    "cNJf/+JnnbyKez/VaPb0VDfRf/vizEp/X0Ho77uHRhRlk6+ynsARHrQxhiMu9dAl2z/XxxSa"
    "oLNvKq3j71jRY329Xt22WrE1VX16R94i27r+voLQ3+/dvUvzHETB7LwpKeIrL59c0wqLi/X+"
    "/k1ujNGyH37wfv/uQSqlMIj4rq23vL4SO9sidORoqkw4uSvPxQlTq7eAo6jIr9eaQwcOzt+d"
    "YDnoGTq2q+ehv9+59WXCqBwTL9YWKDotVodGhvtXK/bHjz6SVLVYKIdRgMEQi2vbwQoo/uH3"
    "T3cyGR7EycmpkZF9m272dvn7ysrp04//Z+DQd/uKDwGnrCqiJCEmkdQCNtabbAtIB08X/d1T"
    "p3TdQMypMHKsKb19hE4CPWj27x6KIz+lOAzVWk5OaFLpqniWWenq5jCn7x3U8nmef2T2XKHo"
    "+xEvqkmaIEuhsPaN1fD+/YoqpyltW60k+zmVpOVUTNztU94xPCaP0mbabyNRK+8JwsBH9Ege"
    "3AxglTK478imBeLTA4rHZUOf8n1/U+979optzGbodd9zTaO56p6AIgi5g+ThN664vE0BEfJs"
    "5WvMbWRbiu/PcsZtYetU2yvj+1djY32Dw8oy3DQ3PY0VIsThfK2Vy6vHj6+NmxqNZm9vz2bG"
    "Ss59erardxeVgB8GoedgfK/mmZrLUVl8VxhWLGskiujbDYvC+B4HjVpz8MCI1Vy4N7dw8uXX"
    "CjmpM+Pk7TsL9bqqyISX9+zqw8y8pmI3rl1M2Lxv6XsGd8/MLWChijYRFfXQyMO7T4zvd+/O"
    "7N+/dzP9ty++o3dHy/7fn1xO/b9urvu5jeMK3+F6Qz0QhQSLKCmUZMoyVYYzmfyiKPbYymQm"
    "/2iKHTsxHYVylIw8jmU1S+JIIiERBAtA4lCu17wFSAASARwnpspkfyE4WOy+be/7XtlFbimq"
    "q2d8XqR5UOvAuUiWF4WB9hGK/cMshZlOYPZPz5zUNNUNAKopgAyYLQb3ykp1Ipf2XTvAMc3y"
    "YxIvur6clkG/C2KMIPBYMg3WJjDNbhcwtkazmU7LAM8wjzaQmiGCidEEIJMpsgJKFaFBZ0J9"
    "x3ulPnAiMSqGy992XITO+4hq3RATwlWw37pfSPEkxfCRrucX99A9PAL3vYAXBJahhw2v4/YL"
    "EShAV1XAEIUmQUsQBKHrhmdr8/NZEvNEEQXMwFBQFBVMMEWpAeWiQBqONXXNdjGSeGVp586e"
    "AXLS+RVBkMMEy2Qztkcm4lHYGSdOzHRIMwyqv36AtnzwVucdR9ejevr9wd0fps8s5FIHbj8s"
    "0NVWO5vDK65tp/KZxbGxw6oLuqlWd1OpEErgufYP33+HEbBCeDshoubj1HRGuP2oPC4Df3cI"
    "Op5P84Xx8XK5livkI5bxbGUlPz1LYc76yxfRRDrZp2dufL0Em8J3TFqQL188X5jIY4MEW176"
    "Jpqe2FpfX7g4//2dB5IoRnCMYJhPrl3tVXMsVVXH89kQ+T0v1CYfXc04SBx6Z3ZTd/o6YsDH"
    "bjLeUYhKv5+g285hNOv0GJqF+NbtJuV1XH36+Ce5MJuU9mkQHJeXq6twwiOBu75Ry+Szi1cW"
    "Bs7Czk5lamoyZLJ8969f/mWiMOW4yC9raFqtqZ7IcMUaRnqGFBUoJpqNExQllrdqEY4MTE2p"
    "NWbmzrX2Nner1YVfXhsfi3V7XPnpnuFxPItXt7d83M8Wznx4duawYP9YWmIEXk7lTFMNQG96"
    "vm7oLc38/e8+69lNnv302dr5+ZD4wfHhaoD2O9CM7heNRiMW67mHYL9H42mh7X8H6GJYJhEf"
    "8GiJ2S7xeMh7JlAHsLXebEUIAgWIApemWdfSN3eb+YwMuOphBEkQLE1opiOnEkB1Vc0Em8h3"
    "LR8j0nKq3/8OKwF/IyQFKoLnOBASkOBwj0qtFo1FYbpN0+okd6IUO5ZLxGM9/7uhm7YXj0mh"
    "8h+nn4DqCxcorul4ksTvn18QF4eDD0zZ9zTDATga5hcDpXYU5fCyuJpMZ4gIoWoay3Ctlk5F"
    "nHgiBQgJRNB2fJ4GuV3bcrd3Kp7rmIY1XpiEI6nrquXicYntNgU8h2GjvmezDEsSQFHwwwIg"
    "2lOvtxUuy/IcEcE1TWdYWtfNXDbb7ydothpHkf84/QT9+TOlF2vjp6Nd/h6gaKfNwRCxQK03"
    "8OH5pGCkhQoE59kwreLqKugZjmOV2h5O0tk49ePTlbwcA9RlhWQySqcSCdMw0tkxR2uoDVWp"
    "N3kGV1stVrTbLxLsl71KpaFtxuLidrkUoeiZ2TlMHuDIBY5oOxZFs2vPn8O5pklaaSgUw82i"
    "KEfPT+BjQbj8x1fCcTU7PtPmakhEMFwHpvLCyQIED83y7cT5OtG4Tlaw3T5JERo0idPhALD1"
    "dAM5sICMQR2SJGmacWzLR5uI60auO7gKimI0wUCCUaTrY6OfM+sPDIyu9qb8kd/dupE5dbHf"
    "/7668gRDT1S4a8XK3PzZxUsXDjeHAnjPnp8/Pz9aIJjTL/70R06K+T4hiPz21obt4ifHpfvF"
    "hkT7DEMSVHQqJyWi8SerW9nJnNPcKxY3pk+fLD0v8hK/+KtfZ9M9XL21fHOzWmUogmJjVy4v"
    "TBbyAwX7+os/CPJ0tbx+6fKHt/9zPyoKoF4ojr3+yce9aq75cKV4ZdDQXmvtTfnfAXz6PYtv"
    "jkcCGLabDSxDb+qWnEz4nhvgKE0MOj2Kqt3Z2clkMqBGUBR8SIrPWyOIR6w2bL8D7q03dO/S"
    "hXOd/2G/72yWq8g/41b3VEkSP/powKaGWVCUei4XYneg6M+9O4mxPPLP2HZ5o1RvmbKEKza3"
    "/uIFNE6QbFIkACGLNS1C42DP1HZrU7OzrXqr2aieu7CYjPfsJsswf7x7TxJ5kuYnJ3IDNwc6"
    "iE8e+mTUbCmFqcnqXg3WFflnBPEXp072qvluqbR56tSJUPnfFK4CWSQO8iY6haSQfwZRLpxm"
    "BX5YEit61ScIg6bAT8gZW1eBL9Ik6RH0mMxxpL9erRTyad+xXc9TrSAuSYLkp9KypTZ4XgQ8"
    "SCYlAFyWo/u7UBQlHouiiz6uZzvesN5RQrkUszgaWFqluhuPJ2Ao0NEr9YNAjErh8r86Vz+n"
    "2ut6xnHQcnQdv8ivJKU4gfN99OAeTkT6L4v0ltGy4Ieh6giq+Z7XCZ504suaprmmirExEvME"
    "AXlagMUrShOtgAdN2sBDEL+E02HpSTnLMt0EMYSr0EjnVyN6JPDAciMCPwp+YRs2VSsth9wj"
    "GJF4e8RqQ/XMt/+8jePktav7L9SAntFbLaCSEdzdqTQphp0eZJTCLFSru7IsYyMLHOelvy8h"
    "9uITBBmpK7tBhJ7NSbcflTMJHg/cCB2fzIiF8YlSeS9XyOOe/vTRo+xkwWhoAeFLsbF4rMff"
    "v/zz55bvB65FC6nFKxeH4eo3X30eG5sqvyiOwlXPUdXaQA/Pa60dk57B35l/5uB2GcpsBMLY"
    "ftVrX4wj+mdQWAeOzhDPzP8s2But1mzsAY8olzde3+8PHj4yDfvKgRMG9ntprYjTJO67NcXU"
    "bfP6p78ZOAuVSnVysoCNLGi//+2riclpaNbzPVPXlKY+Ncau13HCQ3EPkhazCTIS4bYqdZwh"
    "MFuv7dUBVxt7jVpl/fLV69mk2O3x6eOHNsaDhVfZ2cbwYGz89AdzU4cFu3njBisIqdSYZRmw"
    "PK4DhjcKbP/204/7/DPO89UXH5ybC13sn7nfK9vGtzeXQTHgjx/ege6bzVbnlYNSqWS72OxM"
    "4aAJzHE9gNYAbUMHec9TicPNARq3Ws1EYv8rpT7ghaH2KrqWadQbTQyFUWDLexRF+46xUWnk"
    "s+m2E4YiCTwq8vWmJssp2BqqYbIMC/MCYqQz2X6+uLdbBb1P0gwyZTmAgZhwKP8bUGJ7awsQ"
    "wvPR+UDGX/t4MQwrp+XuGfEcq6mZiXhI3hLITxDhNwYGVvNcgCvn7t078AHsUPzZyv1bt/5V"
    "mJzKZeTQFo9YShubCxcvH1dr/x9F11rLy8vZbLZzP5JsNpvwj65r6yXruPqAhVVbjXc90ver"
    "bG1twTxL4j77Alz9N5x9iiJVzRQELoL5hoWuRbWTocF69JCeIdqMvq0OCSJiWTZKicYCsBOR"
    "udh+kzPwUZ5XgOMcyxiGiRKdCZwgqVqtzvMsTdPc2038fM/L/sV1TTfRpWGYURd5o4BkdLIk"
    "UHqo61q2g15ZwwnbsjTNQDFkH7EI0J5AMRGXa78LohsWwLTXaaBd4DPHsbA2KOTov1WH33te"
    "/gtqRDNRb9yo9wAAAABJRU5ErkJggg=="
)


"""Help image on default search page for search page."""
HelpSearch = PyEmbeddedImage(
    "iVBORw0KGgoAAAANSUhEUgAAAH0AAABHCAIAAAClA9+5AAAAKnRFWHRDcmVhdGlvbiBUaW1l"
    "AFIgMjMgYXVnIDIwMTMgMTY6MTU6MzEgKzAyMDAqPnlpAAAAB3RJTUUH3QkDEhEPoRUhUQAA"
    "AAlwSFlzAAAOdAAADnQBaySz1gAAAARnQU1BAACxjwv8YQUAABl1SURBVHja7FwJbxxXcq6+"
    "75mei8fwFklJlqx4fUB24nh3rSycIFhgkQBBEORHJkiAYJHFIotdr+NVJOimLlMk5yBnOFd3"
    "T/f09bo79WZoSlxvbGNX1lAxP0iNx9evm9316lV9VfWazMP7N7M0gTN8C3ijgGVZbDAMo8hS"
    "lqVfPz5NMz8IJ5dwHCcK3PEpHoWept9w/Rkm0HTDsoeIy5feGNp91/UyyDRVxVODgc1ybD5n"
    "ZDgbGYsHnmP8IC4Uy5qmo4g5lul1DuqNfV3XCmaenfa7vGb4/HfX/+Vf/53EMbZv3bl/+87W"
    "pD+MIm6s16jEGSsJkn58CSdIoqhAlvl+sFNrPXj4FDv5ab/Ia4Z//qd/dJyhJMv+aIhqiyYH"
    "FRzNjqapPE+Fie2U+BHJBP5Ipz3XwaMsCbIslQt6oWDSYVt3r5/ZmW8JnhcFURg3mcD3UOJf"
    "Px5VX1YUjjtSbn/kPr/V85aoFMtzOF3PL0tSYIC6hSz1/AhSIohiEIY5w8CzzfpuQkLPGymK"
    "Mhk/eQ68QxRFSZLgnRiGkyRxcjaOI0EQCSGoFzgSG4IweQc46kwTkmZxFKlji4lICNF1ddrS"
    "fg5CIvz37cezLBOFwaQdBCHq++T4XO4o9I3zlzvN7XrH/cXP/03SC5osjtw4iCxWUH76s3/w"
    "Oru72zutISkUix9/eNVxHLNQZLKk23kQBeGTZ00uC6M0YUCsLi0VVVDKS9v3bjGy9hdX36FT"
    "Atlw6Ea+d//BE44jAq839tsXzs13nOjyxdVPP/3dbDlnzi4LXNat77z10SdFlT5Yr9+btqhf"
    "GvoDqzo/a1n2zEwZVZnZuneD5YSV1Q2WO2I5jmPncvkTF6WJ7Y4YSLHftu18np5tt1qExOPT"
    "WRQR8WgBTuY2kGU5CHzUfmxMxoRhKEny1zxZmsQkQ+NIvrwEPG/IwDes5dcM2fh/ljDN+rPq"
    "4tq0H+f7gvZBvV7b7fV6dDmHvtfpO7IkyiLX6uByKO/uHqyuLna77VKxnGaoc2RgWZqWEwQu"
    "DoMgyZxer7q4QF05WnWGy8aqKvIsiYmi6aoi/8lP+P8TBwet69dvLC0tULnHUbj7bBuDMUni"
    "GBB0TThsHxqmgYS022nfufdElVhZ03wvnF9eUdmovHze6vZu/c8NozInMaRWb4kcE5AkHNla"
    "rnT+4hvnVhen/YKnFHNzs9c+/uHuXv3MzrxStPb3ep1Wrd48i1engyMeiaaG4YSGw3Is5CXw"
    "CBgCuBHIeAwhLwNJIUoAQzCBg5CAKkDfR3IPhgQtlw5A4oe+OiDgx2DI1GljOyfRH8MERI42"
    "Csr4qMIoQmoP+LsiAqWXQdCjMPSDUFGkMAwEQR6NPF6QWCbDsAB7OE7gee6YJp0GHMk9y1KM"
    "kho26ycwr0PdwVgLFAGGIYQpvFEGN0byQ9soKRyzUYCuB3YE7y6A5dMGyr3tQJDSuRnFYEpg"
    "h8AysGrSkcOYThhJQOZhtQBf9CAdz9lbsy/nNdIsJXEcMDTUSpIgjmOM4VDWeMT+JMnSjD+N"
    "chclGnNeKUAUQaEAqxokCbAcqDK4Hug6TgxYPWAlyBsYhmHwCRdLyNNBkmCuivEsDPqwMgcY"
    "izEsdA6pLnN58H1gUzB5EHUomRDEdIlgeJuPoVSm98Hfgv/cIegGTKJunN04BQwGCIEwxNga"
    "yhVkXEAAdA26hyCPo+PJIzkOihUKRRypFIqKbQMGHgyTpqnmeZ6EPIHjdF1/IQY/LTiRF/vV"
    "f0GrCUEI5zbhoAWDLhRnwe5BpQKeCzkTDjtQyMPmKnx2AzQdFpfgP/8DBAUUlQo0DqhJWV2B"
    "1TUMpUBTod3FXhBV1EcIRxAn1PgUdKr4dh9WN2HnCZ2SoQOVEqonHLQhpwEjQORAzNAZTdEi"
    "8ZBToN6E+WXwbDoTWh6cAQxtWNkEiaGnUgJLy1DbRwWCa3/5+P7WA9QkHsPfyPvok5+amjRt"
    "Of8+TvCZ7e1tq99XDV2UtCRwLcfTdF2V2Z4Vzc+Xh/ag07NKlZn5itlsdd+8dHHaD//64Q/z"
    "GYzUZVXN4kSSpTCKNE1TVU3PFWSJT+MQ/epCdQ7GyctJcucMfzRO2JnN889VeHH+ucurVGbw"
    "uPTCyEKxPO0nf71xxt+ng+f8PQW26dIiiYkcBqk3ksgIFJ4esQc5BnpFdJscgKlCGEPbhTmD"
    "+kkkixwDGQNMSi+UOeA5yhd18dW9BvJ313NlWSUk4nkx8Ee8iPwdfTWPpxiOQyKZyxnTlvZX"
    "5E4IYXmpNYRRAnMaNIZo60ERwQkgmvB3QpkDRlKDADZLlOCrHCX1TkgZPZIZjocKsg4bVJGy"
    "/h9UX6ncU1o0IVEUYxwiivg6ScbEk4In9mMn1YvThBN8Jh6XaydloyQOepZfKZssy7XbrYWF"
    "xVPIgl87HPOZE371N7/5NQTdX918srS8oXN+3w7jNL7y9lXrsPn3f7cAcCb4l4YTcr927a/o"
    "8W+n/VDfA5zxmenguV9lWNaNWCQwHAtBApoASTpOxRDag41RRHNe/LidjtOTEneUKZu40DSj"
    "lohhKb3BTpGnbAfHvBLHkEVhxHJckiTIYdBRCaKIHvX4NMMwx9sXTgOOeWRAUvZhXx0ROGdC"
    "3aWkEClAEFMe+c48zTjKLPRGNP37VhVqFoQRrBSh6VDhMhksmNDzwIspn5FYsMbZ4zUdWBkq"
    "330eENlMp9sTJTEKfFUzLGvA8aIsUUGTKESylabZ4kJ12tIG2/EG9qhYLJ7gMx2P8nTU1mSS"
    "GsyoqqIGiTyHPUyGBzZJU1T5jOHgqLjKTkbyNJlO97dyY6XjxrsTkEEj95d/b1NaluJI8TRp"
    "3yuDbfXCwHfswQmRdHYfdjr77a79wQfvP3qwtbAwt7K28dmnv8wy+dzFcw9u35Y0c6ZSsntd"
    "XlEMMTm0kgsXzz+6c2NhZe3Ro6ezi9VR7zBmxeFgUK6Uqqvrt6//Os0SnpN3tuvGbFGXJZET"
    "fvTjHzabBx+8f3XaQpgmTuh7GIYp3VeZKbKMJpKQWJIUEscZpBxHjaYoUkOO6gxjUkmtf8oy"
    "KeEFPgxxsEijFwxZxrWkvu1lSZTPm0cLh5p+jBsTSRQsxy2XitN+9yngD+u7JEkvtic/8vzR"
    "fqaJ0BEvOqhxSxx3ipNzx7eYl//PCt73U+gv4oxHTgdH+j5yHZLx20M1SmE1D60R5AVaFMVp"
    "6YzgUoW2Ue0HASWIG2U4cMDxYTZH2U42rqniUImBnk+rsuh/l02ovMIdpWi+2u2Wni8NrV4u"
    "X7QGPUFSVAXXXjp0PEmWwyicn5ubtrS/InfkXiRNJZ+aDDemdbjDmErQJ5CTwYmoKHFKRG5c"
    "1QyolPNjsfIMEJaexRvJAggRrV9nCXzTFuWXD7NQovvQdQO9jpHLczzHMiy6lVwOWS57qpKR"
    "qCdf2neG4TlOGe3GwShXMPf3aobMW14AMUYjYqSpG8vVru1f3jz39fdbNqfzHuixZZn6oYlP"
    "+nJn+ASnaBvBMU7Yd6QuhpFLEtLvHg69wMzpas7MkLaPP6D6fjLu7wgn63ybm5PGz6rLXx16"
    "Vtl7iTjjM9PB8ac3tDA2CDn0k1YAukQ32mHsQ1JaY0Inaci0tqeKdF8YOtggpj4WmX2c0MLe"
    "YPwxiSFBP6C5Gnk8pqjQwhMOQ6/LjVNjaUbHI2jiJHs5O/QmiMKQblRSlGA00gzDc11BlAQa"
    "eWRhEAFLvZemadOW9lfkjn6fEPK4wyFNTFhKGXMi7A9potEK6TbHEQqapcNmdCpHf/yVD4o1"
    "Y2AlRxM7LoH3qnBgQy+gRAjla8rgh3THGfIfvBzncpK59CKaxfzx6st8DYyy4xjly0VRREPn"
    "8T49yKhDiqKA4YQ0SU+T2L+Uu6xQ3bugtEulEs2ZMkyn03nnfBkbjjMUBF6WFdcdapqOLC0I"
    "ouFwWC6XWJZJU/oVIf1WluYCmKrBhWE4/kiMbln0o0xVxPGAbJyLBc8bcRyrKAreNhF07B/n"
    "0dJJrjgldPMriSO6zU+QBI4NAt8dRaVivt/r5UyTlkwZZlI4fRGyosgTEkO/bYTJl28TGMap"
    "YpAn5T5Bo77z6afXeTbefPPtg51HtkskIeu60WxOrswv3H/wMK+perG0srSw9/RBz+PeWJ9/"
    "8uSLjTd/sLt10wkSVTOv/ejqL37+y7X11dv3Hv/NJz/qHjq1douPHI8IXJawTLJy8YrdqiHX"
    "brZaI3+kydrlS+u3tp4JrCCyMRqKSmX22V4tGFqMpL175cJurWEPwyuX1+/e2ZIVURRlRTf/"
    "/P23py23PxVn3x28UnyZF+uf8ZmpgDlhZ5rN/YNmXVK0KIrXVhY73f7s3Fyt3lBkWVOVL548"
    "rC5vcjykeJoaYm5xtlRrHKCFyKli4+Dw3PpGfXdbzRWYOCzPL3b29zhJLRfNXt+WZXk4dFiW"
    "0zXZC8nIHmi6Xl1etbuHgiQ+efKsUDDQbVRmZhKSyDzbtWyzVOk29xheJHEi0kwLev6sOlOU"
    "NM3uDwKSlAomeoXa7u784uLebo1l4MKlN1uNvbyZC6OUpFkSBpLEt3tWIZ8/f35j2rI+gRP6"
    "LghCZXZekuScoSKDhCxJ0MWJGKhSX2fkTU2VJFHmBX40CgyFi0EgMSER/VMfpUrFddxiqey7"
    "Ls4L8oql1XWRzURZy5IYb4ERvMALrhskNI+PTcnq972h22630SWiz5VlusNLEER7OEwIURV5"
    "YXEBf1R1jc3SMAxESeR4jhAkL0RVtSgMWGSjDNtptSVZwpug58cJdtyRIon0o4OUFCqzlYLJ"
    "8afuzzCceKCtu3fyZmmntlcoFW3LanesZqMRZPL6nEZYbafRHg79nM7X97vACkwaf/bZXS2v"
    "5lRlf3cHFOPCWvVZvafwpN3utrr9lCTFQr4yU9h6vJ3Gj9+9+vbTh/e0XOVgvxPFwXtX3926"
    "fXNucWVgD5GM3Lp5b3V9Y+/Znp5Xu4f9t9997/HWfUkrDFo1QVXiMHPsrpozXdf1rHbGafPz"
    "5Z2nz1SzILAsasBura1ofGOvCVzKScaFlXS73vvJtQ/xpfKG/kfK5rvECb/qDp1arTm3UI19"
    "jxUkfMdyudhqtatzMwf7LbNcViQJFwGai8NO19A1hmUdyzIKJWFSXM1SASmkIAT+CFngoNfJ"
    "5QuKzO+3rZKp4yJAIpgmNNuz39xHC4bajaobxsTQdcsamKYZ+H6E3DuKi6Ui/opyqYQqjKsQ"
    "79qoN5ZWVnDZjUa+mc8hX+/1cXkVkMtiJxLQKBPzmuSNfFynuq67ttWxhudWl/H3GqdG9Mf1"
    "phNy/+/ffhYFw54daIp+9cP3nUH/ycO7mVBYm9UO+qP+oLO4vOEcNghN/wFJ2MZ+569/8uGt"
    "G3cuX7mwdf++mK/OFhUSBrXd2szS2kq18Plvb+qm5vqZKoR9N/v444++eHRXN2bTJMT1ouq5"
    "R0+/IBm3sbaAMy2p2uef31y/cHEmr+6322GSEW904c/ebOw2NtYXbI+gh+i19tTigimxvUGf"
    "FhQ5cWNj7f7W46LGr2xcatR2Wq2uaWobm+e3Hjwtlgxcl8V87tLlN6Yt8K+V+xm+axzL/YxH"
    "Tgcn/OqDe/cIUgW9aPUOc7o6irPNjfXD9oHrBTmVc7xU16R8ztirN2D855tKBT1J2DjyfD8G"
    "JhN42R32kSBmnFzQ+FZnWCkbzogIWRQjq4sDQStD7DEZOK5r5AtZjOyGkSW+Ol+pN1t4oSZy"
    "thuoijhEN2rHl88vZKzY63azjElSghYjzdJWuzs3U2x1rFKxmNPEncZh0ZAbB+2Zmbkowmu5"
    "3iA0NLFU/t92rvQpjuuIz32fe8JySyABupBRpSLFVqIP9mf/v66KykpkiUgWFjJYHALEtbPn"
    "3PflngVT3hQfUnESkCv9ZWdq5r15815P9+/X268rUZI5Zi/yg5n5u7JwpTYG5UPzzgkigeWG"
    "7dcqpTDJOAwMrAe+r1qthJ49OV4+0U74TARQKIhcmlE8zxqmB5ivbzmz0w0EpQSBgZfHSIak"
    "cBy1dMtR5NLB/sloo9Hz/BFFAszZ0To8zwMgjXOGZVKG4YrgTo4wDBt4DgDBJM14gSeYYvdp"
    "HAZ9w5JFkeP5PM/BaQNUZVlaVcGpQ6t8cnIyT4Jpkk5ylKHIOIsEDuE4DqAty7IYkoV0QKBX"
    "rqDUkH3/8d06UJWOHTx8uPz06YtaVQVIM7+48O7teg00189ZKq83Jo739lhZ6WkHSU6KAssL"
    "5SdPHl32i3wach4nGJr37e0dSRRECVBaVqTnkWScpI6tO0E2NlK1TFNV1SCMEgBuUcyCdlFM"
    "msENoNQiEJg0zUCBC0SXp4bpqmXVtW0UxcB+DOLMAEBR2y52wxB4EYsHdJikaeT7nChmwFPT"
    "DPTU94PQd+IcJzAwQVRUkCyaIDDLsmiGPyvBmCMkRdqmiVN0kQWl67D4JI5iRU7k/3CXyW+Y"
    "9yE7Mz4+tru5bvv1Dz+tR0n0py8eb6yvtzv98UbFtdzQ0zstvtXtuZZH0LQs0hNTM8CPUs+w"
    "3JQict0OHj18sPJipT5SEQV168MHT+9P3rxlvn+vSNLR0YFUHvH7xyNz93fWVkq10RBMktnL"
    "UPHW0uLR3rbW6d2/e6/Z1ednp4E0YQyrcGS73UcoNnV0kmeznPKDYGqs2mpq6ugEGnpB5CdJ"
    "YvopnmXw5am1xp3Fucue239JhvT98PCQYxhekoHGn6o8EBm8oEIU4HXbA+5O4zhoLQomGH6Q"
    "4g+HFDrxfQ9FYS1IoPtF8SwUBdJEcTLHkC2tVavXoDdQTfCQsiyDshtWIPBFScUigp/ntmWD"
    "UzX1nqCUqSIXJwfdh6fChwW9FY9AMRgJdAJWHlrBJc9xSIYejAXttNtg9OFm+AxzDC8p8m+a"
    "kv+mXKzviqqahvH9N99MLiwa2nG725GkyvTMxOaHjxWB0O0oiGNwcKrCHX88ZtTSaEnc2tln"
    "eBlLHbk+ZWhHfb07M7+E+IbteeWRad/qxoG9svIaUNDd5Qehb794/vre0o2dnYMoTfI0nxiv"
    "d7S2HSZx4IHPrNRHBaJYfoSVro9Vtg86PJH0dUsqVSkisewQjAnNsNevzWxu7RJkTuIkK1cS"
    "z3jz6tXswq21H97OzF4vLX8C0fkhfW+3WmmW12rV82qG56UJi8qDcQT8EB8gftAz3bCAr5/e"
    "BG4gCgOG5+GibVmSomD/34V2kVys7ztbmx3dxHOMZkjAvxlB72+scuoIkkWOqecIu3BnUTve"
    "+3jU+urJo5dvNpc/u72/91FkyU7f9j2PYSnL6PFy+fPHf6koVyUkckUF9D3/RZqapvd7oPLn"
    "EoAj84P09CRL/CA6PYxj4DzOr27MB38lXyxwSWtqp8dFqzQCInZ+WtSJyzI4+KdWAGzOx2D/"
    "cjUMPMBTpw3Pezi9pxhMlja19lAvadztm78e+eWKoXdbzcPt92+H9B2Ao2naf3/67bU79/ST"
    "g5N2C2DJ7OzMxvY+mRaUdO76bLPTj+xOjMvdk93Hf/5ie+cgDtxyrW72+xmKLd5Z/P75S6A3"
    "aBbdWbr//G/fjYyP97utqanJ1Xc/6lqz1hiDJev2kq+//lI7Oni9+hOSBDjHldUqlnsnx8b0"
    "dHlj65gTJCLxPv/yqzcvnuEkj5Co3Xfq9dLstZkXr1aJPAsSpFTiOrqnMNjM3I31tQ1e5R8s"
    "//Hd2pqmSLsHH4v4JIkvP1h6ubLG8dj8wtLc9cl/Vzn/44IO2fdX/1gBcF2uVZEMPTrYYzlu"
    "fGqm19YALzueSxbgmEKRDPByqVoHbD45NXbS7CkiDYtRkmXA8q4fJGHA8UK1Vvc9FwAOYH+r"
    "1yE5fqxebra6tXr9hzerd5fuAs4BHwB6evP27Y23q6Ik5jiN5zFBMuArvMCneZklsk7XkEQx"
    "iiOMYhgs8RIMTaMojCRV9SwzQ3ERABKauQDm3VgQhchzUoRQBNoNkpIqtzpNGMv8jenLnugz"
    "uTguVquPMjQJbwWWoT7aIAki9F1nkHkBdAkaFJgSRzCShi8XIKXjRcXu9CJxgwbiAxYj8gPA"
    "GwDptHaXJEkDVL3TIynKt504zdE8zZIIcCq46JZ2ggDPoSmgY7BIaJ6RJBVHoeV4DEPJigxr"
    "DLgQOgkHRAywY7la9Rw7zdCRehUIWo6iFIVTFBOHRW5SUSgHQABGsCxTHR0Ft64qsDrl9Kyo"
    "69WSIX3/7tlfDTu+duPm/Nz0ZQ/s9ykX77P57A8PMRRLst9XSd4rKUPzzgxqpl3pAMcnLmBg"
    "we21Wq2heT85PqqNNIoS1HnS6dk0RYALq1Qqhm7gJMnRZJIXyaUkReODRFMARp4LrjSqlIt4"
    "GcvS59s8gGrZtsPz3CDpD2hX6rghzzFonhhOrEhnKaln+XtI7npekf0qCJrW5ASRY5lB3fnU"
    "AxCbJdDPIGCQnfZ82hQOPdvyU0ThadMNS4qkaa16vRYFAQZeIYxFgUOvGH1zXffZs29hSlHA"
    "kgx7lrFpmzqQ8narLauSotZ4jtrb2nTDfHq6oVtOHgcAY8ARW05Q7JCPAHdj1WqpeXKMkozC"
    "seEguxFJ/BwhREnywSc7DoUh1dFxx/Ni39VNh8QRgqT9MJmaqPc6OhDfImGGwRMEFhOhOTaN"
    "Y9d2qo3G0f4uAKpKpba3u8sLgiwrpmXFEeB0rKJKpmkAYIfH0RQmitLRYZMiEIrli+r+OAba"
    "o3fbpdoIQJrLnuohOTo80HVdksSfAZdV50AWNd1bAAAAAElFTkSuQmCC"
)


"""Help image on default search page for tables page."""
HelpTables = PyEmbeddedImage(
    "iVBORw0KGgoAAAANSUhEUgAAAH0AAABHCAIAAAClA9+5AAAAKnRFWHRDcmVhdGlvbiBUaW1l"
    "AFIgMjMgYXVnIDIwMTMgMTY6MDU6NDkgKzAyMDDSmuHXAAAAB3RJTUUH3QkDEhEazMjFugAA"
    "AAlwSFlzAAAOdAAADnQBaySz1gAAAARnQU1BAACxjwv8YQUAAClwSURBVHja5FlXd1tXdr69"
    "F3QQAAGCFKsoUsXqGosez3K3s7ImD/PgH5Bflfe8ZMX2eGyNPWNnbNmSIsmKZY0KRbEXgES5"
    "uL3fbAAURFESKSlW8pDzQGIB+56y93e+/e190Tu3rkdh4Hs+RhAYivw/HBTNRFG0hwH8ahim"
    "IPD7TqVrOk2TTzyOoE84llhfXr7zYEFVFIblRVE+c+rIKzpes6nwPGOYfiwmrK2tJeIJjmN7"
    "vxq6StAcTRKvaPU9RuAHs7Ozsig4vh8hWKO6TvMxSeJdx6ZpynGDXF9GUVSSwMD4/v25mCT7"
    "YYBjiONGJE1qShOnmHKpH8PQjUqlVCz8cgsZG0VIIowaTVSWPQSlSPzS5k+n00cV1fuXf53/"
    "548PEFIifkzgOY7r7OEVAj4IwqtXLisGkozHSv3py5euOF5IYKFh6AgllftzpWKOTsT+9/0O"
    "o1KpNur1IIj6+vslWVZUA8VRU1EQHE/39e20VDVdVVSW53ieJwmy0WylYtLi8nqxWMAeek83"
    "4LBIG0KGiYgCghGaZ3y9/v2YPBQT5aOTcVEg0RtXLypK61UfLBaXSeLpWAaKwwkcRf/POK66"
    "WXMcZw8D4BlZllRV23cqDMP6C7knH3/ydESluhWXJcvzI8+hOFHkmJfc/VY9m07uWCyoN1Tf"
    "c1PpVKVawzUTWAW29bRH0dAPbcfBcYIk8H0X8vxgXzM/CGA2FImeZ6p4PP48ZhzHP4+Z6wV7"
    "2ACvRFG4vr5BQChoipi9f19RdZygZ35z4uX8DhHF8UdRjUJkfWXB8rCwffsgtUTgdKC5Z27a"
    "hYuJdw08z9us1RMSb7kRzzEwM2wSxTAC334czBzTaFmexLM4jgW+C2lDFNnONjCyfcND+Isi"
    "Ydfedd0w8BZXN4cGCjDPzptXr23GE0msHSJgYWJpaSmXyyPtgLUxCv8wFIWNAbmvrm9kUinI"
    "nLzAYx0FQpJYva7Dug8XRbr7N01DabWSiZSmao7rSrJIU3R7PyjqOPaNGz9nMmkCxVDbR8tD"
    "I919NICAX9Lx+K5nBw6Mdz9Yti3w+4uB3oCdrW6sRC6AlvFtFac4gsAPHpqaGC73bBxD/ebb"
    "yxH4lxE40rfMAEUCyzJixbEPZnZD56sLXxqOi2LsLzeuCKmB99480/up2WheunwNxcBf/vT4"
    "8HdXb8ZEemW1nu/PBW5AUSHLJ96cOdeorv309wdu4xtGytmmChm41VJ+/9F733z9vYdCdmU+"
    "/PADltoO58Uffmg0WgwvhF4Al8D3LYqX/+mjd9F2SOxisWhZJvrXr744evw0xBky8rXrNxmO"
    "z6Tk2Xv3T557PZP81bLc8sJsvV7bA+8g1EiK3sOgN+Ai72vmeh5J0j28/0+m+nXNQEr4fkiR"
    "aDtEkiTl83lBlCYOjjUaDUGKnzp1gmXpl3fz04bnAds7Dz87Fy9eSvYVpie275nj+tlc/4Uv"
    "v6JYSDA4xwpr68sEzQ/mY3cXq/mEqHuYxFFAFMA89xe3RA5fXlxLZfs81/JdS9etmbffEzmq"
    "O1sQBFcvXazUGrbrHZ0+eufuPQzFeQ5zvaimaDOvnwW11/aU4/z0n5er9YbpeIcmDm9WV7wI"
    "8y2DovGWGZw7czKfy4KZZWir61sjI0P7+N1xATn7eCEKgILVVqON9zffek/XdUi7V69enZ6e"
    "vvzjd6XBMbVRp3jR0lvZXGl8bJ8lnxxLS8tAvPPz66lM+uDEKOB9c3MTuPiZm3a9sYOHaXo7"
    "2JoGvCl0zqxTnNBNHFHgr25UM+lUz+yxsUM0+L4PM8Ri8rOW69ratv30qZ5mtq/iAjOG2UeV"
    "mEZba4DftykJx3GYemRkJBaT3vjt26raKhRyYRjRJB6h+1+xJ0ccaJKFukBiBfHhEo/yqufa"
    "n336x/6RyVNHDna/CcOQxNELX3xRGhgIQrgQgQ08qlsZGavoaFZiNDsA3ivk+2xduXevybLR"
    "7O2F/sFBho5CL6xWq6fP/y4usT2/37196++3LNswQGTEacILI033Pvr9+zsPA09++u9/7Msk"
    "ai0rX8ydPXn8qWcJPHt+YXny4NjeRwbg7ut3xzZ8r/2B6G0Ukv6DBw+AXv706ediLBZPxJOZ"
    "/PTkPos9Y4RXLl+PSRw4DoD8xttvIZ26ye2dJEB+M/MmQVI91eX7gReE52dmVE3DMBzCAEoU"
    "KnjXMtIomZQFw/awyN+oVKF6TCREgsRPnklCPuR5rtVq5YtFyGqAuN5xBspDGdsBZ5A0ZZsG"
    "jpM4SXm27e30ghu88+5bpqkPeKEg8r3Hdw3X81OpxLN+fTSb4+x7J4AAux+2/U4QBOB9YmIi"
    "Fkv84eOP4XHPc1EUjx6WsFDdgLoOgxDFn6eLg8389jyOYSEIjjCgOhX2Trz7SLC0NA8X4vCh"
    "ie1AhZBtiCvXr+VLZST0HMezLcOwfYnxVZ+xNaVlOFDKl/oLge+YpkszyOLsUr5c1jTFaKqK"
    "rh0/OxN/WHyA31eXFlXDhJKg2N+/VWsKgqjUF9fWRNuxx8fHMqlEF6GLD+Z0y0JxMvC8a9d+"
    "KhT6q2tr2XxGN93x8dFEh6nCwK3Va9lMeu8zvwzeIQ6GYdy+fXt6avLPf/oSpTmgVJqiMDzy"
    "I8rQlFIhU6mbJOJBwI6cOjFcLu29wOzsLMdSt27e6x8aOnZ4chfefddPJFKJVHYn3iEvlcpD"
    "hq4hGCyO0SwDxI6HkIMjSZIJNmQJZH5hqZDPoliIRnjpQBkUvSTHActyOkVi4U68O+0lEqZp"
    "Qj5PJJKgqfsK+TBEbYclQDp3LNsIxfF4ItFue0ny4anJhqoPDJagfiZpHrDQNbMtm2GZV4L3"
    "Lr9PTU3Jsdib77wDNQ5OEPAZC30vxGjqBdpVvu+pqpFOp7PZ7NCB0d73O/GOIcRWdcPygqnx"
    "4R7eaYbR1Va6L4e2Gxs25GBNtzEklOREFIHKMMR0cnR02HUshmIJKqzOr2cKWUVR4QK2Go18"
    "f5lhqJ7fk+lk+9b4URiFHEOYZoRjuGnYkA8ClO4CExAKp27f6QhqM9CyRgSJBXxBEJD9gGm7"
    "XgS8q4a6L5Zfkt+hSgS8Hzo4ujy/cOPWXWBRy7JYltE0O51Ly3zs9JnXnsfvylbl8vU7B6fG"
    "Ll/8vqWZAJa3P/oQaZfR7UW6NiAogYLgBpjWNohc1wdiAfgvzj+IAPAYqRsqSdMCGa0ubw0W"
    "+qDe3dqsrKy4A/05RW2BK3lJUBVVhL+aBlEFmWrbYe84q8vLLCciOLZV2YCa2QNJDxEzLZql"
    "xIT3EO/2wsJyti8N1SzU7q5tIu21cU9xKEYAm67f4QjAlq+K3ymKAj0jSIn+wWho+ICUSFLP"
    "0S15cqRyxZMnCASny2fPdb/p7gZYi3kobwOfSaVSsWRGErfVju24DMvH43IynYE6HlQg1OIQ"
    "hsgz0yVRZIharZnOlkBfmYaRzQB2I0t3WQ7QGgHPMBwjCVwv9YDfh0fHMAyp1ZRMecBzoGR2"
    "QTLYjk/hIUU/wvv04UNRGBiWl4jHNVWBdA7fMxxrWW1R2MM7F6CvBO8QB0D3wsICQ+Oba+uA"
    "98GhwTfOn30JvyOdJLw0t7SI+opq2rbz1gfvIx0m2YF3W1GaboRlU7Gep+D3Wq1erVTcIKII"
    "RjdVAF+cQ1ebTikd9wmmUd+Cb4bK+epmQ+SItdUNXhQhB9W2FByN4slsr26Ccf/eHSC2kKSb"
    "tS2KYZpKS+BZVdE4gR6b7PXvoutXr2fzOdcwtupN39QcKHQp2nVMkpGKxf5tozCCPPFyrnjW"
    "eIR3kiSLxSLHSyzPf/jh26auzy0sJiTRME2e44m2DAPW2aceA1qcX1gAujwwPsaROFxwwCPd"
    "0TM78yqCkv39RZxiH9ORfjQ2PsayXDcMsCUgXMfUDkwmBJaCz3ynyaO2lEw6jmFReXAQI3BA"
    "cTyWpBgKuGInz0xMTu1CX0tp0BMS7IUgennVPfraMSjX21BwrKZmSoKgqWoykwaMOA+JBSgK"
    "0sCvyjPott+9zqhUKpLAqi1dNfQWUKfAzc3Ow0ajwBHlVGmwzPbto6WAHDzbwWjO1NVNSHm6"
    "7ljumTfOI4/nVdvUvvnbd2MHp/rS2z3YTt0UXbjwF5qF2gePQlRp1XGKy8XJuYo+kJI0DxMZ"
    "HCqxcim3uloTeGJ5YQ00UYiEvuNRNDZy6IQsPtKR3379Zx0048M+AWhinkVdH6m3tJnXzw10"
    "+gTADLd/vrHZbJq2NzkxXa2s+AjumzqkbdUIzp09Vej0CQLP2awpULLtffYX4pntPgHcI9Aw"
    "c3Nz5YHS4vyinEq6tpNIpeKyhLzICHzv1i83EUAhQ8ZlMYwA72g6k15bur+rTwBpEMQi8TCF"
    "dPsEUCIQONHFAdw/QBDoKYoV2i/VHJeiCEi/UE/B1QFgBX4AkwOnQ8yCMJJluYe2DmuFkLG6"
    "EItAP4I2fKLwAAhDtUiDXCMpHHtmD8O2rShCWXYfn75In6D5SCC2++NAlli7mFTqdQOqCYx8"
    "cb/7oIVZFjeREDhX0w3btOOpNp/uwvsXX/4lUyjPnD7a/aaL988++USUoVTBKZKpbq5HGNUX"
    "w++v6yOFVMMMkjI/WMoTWHR7bkMS8IW51UwmidNMYBu1Rv3df/xDUnqE9+/++pUZUJJAzz+Y"
    "Jwn06OnXD44M7tptFLpffP5tKi0cPv5GNvlMl0Ghdn9p/WinCtljvAzeNa39Egt05Njo8OZm"
    "HUGxIGy/PQHVTNAgFmgUIyzTPDAyTDy7t9Ubq0tLqm1LLAPADBCsNFBcX5p7nr5Yb99dNgcc"
    "O5bVxTsEBvhuvbKVSib2PR74HekkrcBz3RBhSKLz6uQpeIepYGYM2+tQzwPk5zTbjXeyMwqF"
    "AstxUbjpIxiFhvWGBkSjWg6JIRuVddADcJ2fR1uGUSSLUuR7luO6lhUWi8gTeP+3zy70lwZn"
    "zm63ojp4Rz779JN8vgD0EYWYpisg73JxYqXhFxKC2u6LycVCzmzVbtyo8hw6e3shm8vgFEGh"
    "aICgBw8fSyfEnt+vXf7Bw3iWjJaXV4GKJo6cHBsq7ton4P2zTz5PpISpo69nk898M+O71t17"
    "D478qnh/VDfBWFpa4lnKDwBarhn44CZd0/rLB9IJeXgUec6hNrdahkvaNgW6AaBEMl0w7dQz"
    "GMn9wwfv+2H0eF8Meefdd0E4A/oA/jiOkiTd1jMkK3EMZEjIoNXNWl82PTrKQmVVLh+AAHff"
    "ozquBz7e2ScYGh0H/QdTJTNZnqUZlntSkDhu+JvzZzmOJUl0D7kCeaRUKryqugnwPjw8LEgx"
    "ttkKMZpEPcjyHCSTMEBeZHheKIlsLCY7UOHYHu5anVpkN97/44crxXzuyPQ2iLp94G+//dvA"
    "0BASoZBFbdvUTTfBR3WbTIuUZnrxmFTIZUC+VKstqGnm7y1kQG/gWOi4GI6KsaTE0z2/L9yf"
    "xVgZj9z1jSqG+OWx6XJB3LXVKPQu/3hLktnxQ8cT/DOhGvruytrm2Njw3gd/GbyDfoDMfufO"
    "nalD42rL8BGdoUldBT3J4fWNm78gAoNJ8cTE+Mi+fgec/nT9vwbLJZZuAxCkW2k71I/h/dj0"
    "IYKkd/WBj584obQUpP2amOR5JttHhq5FBXgmLhlQamLh8spaPpdhGAJCODo53u7q0BRIrwBO"
    "HYJ+j3p+F2TZsl2omOKJOEgRnsaehne/PDggSiyO7tUGgJ8ESfhV8R491gdu98Vgu6Yd4ZBL"
    "SaidIxQPQj8Wd1le2Nfj234nqWNHD7PwPI7b4EvPwbbjsaMP7DnLqyuiHM/u0O80Rc3N3kvn"
    "CpAfLKjoXa+lWSzuuLikQQmvWbIkDA2VfdduC3w0Wnmwki1kLXC266EEJYhCL/W0STMIQFBt"
    "1RqyJAoss7SwFI+LjboGiMwUx7MJvovQwHcMA6ms342ns66pGabd1ps4BnB57dh0r0+gqE0m"
    "92r6BCAhbt68OTUxeOnHn1mJCv6bmit/jqPaztP7PjM9+6JdtiSvWAZsAhgMjxd4IS8JqSRV"
    "SVXen5Uf8kP+gDzKryAQCIE8woOAAwZjY2QsWftoRrNP73vn3OnRSMhYsl3ISa5dU3K7u9V9"
    "7nfP+c53zh3HSaUzUiI5dAUPOKR4st1RIN0P+9qD58fSqDMC9bQAJnfs7rEsD7QZ/HJ0xHGR"
    "LgYZ7PZWBWg9HsPdwCMJZAO114ln0yzPA6n54c7iWLlgWmYsJDKFjAtuXRI8igKGrqk6M5xX"
    "oLOaxjCAcx6Ifr3ZwnBM102cQGsJqPJQF1M1U6ZRIm5bpqYZwOJDDA+By1H0Xl0MnugIdeCZ"
    "mZlkOnvpRRbAz5K4YTtRFvOwI5mQREniaNL2gNTYdJ8+Qko0xHtIk5jnCJLE7haCMZYTWJoc"
    "GTlG4ISm6RRFGIYd842pnMzhQbOtpLK5UrlsmYachKkJW7W2nJFdzyNx0rB1wNpeu+dyOfBs"
    "kP2yDNPpdICVthp1MSH36wrEUBcbHS0FQUinOLjGcZ2MnGo1mxCKARn9XImJ8G7YwVHpwODf"
    "FxcXadz+7lbFsfUg5uUy2Vq1pmh2RuZ1yxN5GgjAhWefGyb39xuJZOL3H/1BEhkVIqPjvfDK"
    "L6KptndCtGMhCYrptO3kINZF3QaKorZabeCRFEH31C64LJmNrTVXJkt5D6fu3rkDIXpirATe"
    "Q+RJy7bqtTp4XrCR41qGYeF7+glWl1cgSvR6ytzcyVqtaZqbiTjtaWa7p57nOZeJUllvu1p1"
    "gqDbVWZnTgauu1apYp7tVW3F9BHPIZFs5zpgHBtC4KFYPvScMBhEIOzdf7lCUDwskKA/cByD"
    "ZdWAOc9kXNuG7BHJQ+h0DFCTTCQ4QTggpYZ1g/cTd7BjgPJ5cAD+L155pdPYaraaDLXbo7xZ"
    "2RAkWY4PwgYk7LMnzmqaJsUTOOqrsuFWwCldSyV5WeRopafAdMLNVaVnGA4GTMX0KIbEMNw1"
    "LZLnSsXC3n4CsBRNMyjzsl3w4jQPi2l/hzQsnUazw/NMPC5T9299MXQVMolsvzR4wHiQvElT"
    "uo5joX4CgPm3126IogjPOj8/f+36rTNzk5lsFgsDSFRdCPmO9f3tOwNjbW4ecNNCoZTKpClw"
    "yQQGC4VkeBYcB0n4NvKMfaMM/DvA/eqX1yamZ548M7eDBIiU/vWvv8FJIggxLCQUrYuTTE4i"
    "VpvmaCZuhhSHo67H49NjW7WWyBMbq5WkLFMc7egGTjH5QpHdY7uvPv9McwmJp5ZX1gSBOTP/"
    "9PHJ/bVJeM7vb96S0+LMyacy9+8XAigBIIqF3ME27depDnHL2I5GhL3/r2+VR6cAmgB5QDRE"
    "f0U1UqkkzB5FMzzHAJUG8FIP2pkeKt2eabscz8WlAZYhLahX1/fpBEqvF2B4Mj7wM5FOEGlE"
    "sR0dGPAObJ3mJYrA4edImTIM3TRtWHIuABk1TeKAbQhIyaS8t+4R65O06CqzX9XiWBoejAVP"
    "6mIsQ+4iNET0aXga3ALicVRT3YmrEOn8REI6+M0frn+GIqnTp0+rqgphAew+Wkp/db23tFoJ"
    "rZ4bEKFrirnRbmXtr3/z9/QDNBLAiv70vz6DMARzr/mdqM43PXsidk/e9NkXV6ePzQxbASNd"
    "7N133uXRbBEUydQbVYxk8wl8saodK6a7VihL3Ggpz7Pk0npTFIj15a0s0sVord1VdfXVX78h"
    "7Kmvfvhv70OeoDqhLLIjpfyN724Dnez1NI4lnrr0WjIRxdXgym/fzBbylm5kRiZdpbndaFMM"
    "7Tkmzibe+LPXBr0Ujllpd/L5n7OfYKCLAeEDoDUajXRK3tyoABemWE7kuUMXzv7fHfi12raP"
    "Gr7Dcqk0PP6A/WLD547ghgqytk1zEFGQKWHetxstGWz2wLoYuioW1hrtXDYNrNTzA/AtfhCL"
    "1L0h3oHjOjbK8aI1Cv7C9zz4xB4YyA942v5+sajOd/fuXYaeubO4BOta01SMln79+isPZXcY"
    "i7cXMJIfmxjZV9feh/d/+Md/mjzxxBuvXo6ORHi/8uZvU5lMCPkswTSa226AlVLkUs2cLqba"
    "upeVpcmxcq+59fGttbhILC2sZgtZWGJCIr6xsvrnf/ubzB4d+D8+/PdYGOsa6KpCLvXOF1dT"
    "stRs9uISdebCL8eLSN8GvL915XeZfE7t9kpTs2a7Vmu0IBrDRIQE95d/8ScDvNv6tzcWLl6Y"
    "PwRzD4F3bIB35M0pqlqtAt6rtXo6nQbAbtfq2VwOpl16gC1Vw9FtNRXTBYIO2IEICc/DC8Lm"
    "6v66R9jfy4XvJBoR3mHNIb13oAMjlmXqOsUKFIkH/eSyUt3O57IA5N0Mpf8TcPD+wV28A5Lg"
    "jdBVntvs9HLZTLTvIkRSGjFsfIxuBUPXVNcPIbzBbKE/GDZst+8bhyYOE8AfRQeO6nxbW1uS"
    "JFmmeePbr/rlGvzO0lq5mD03/8SD2x1Y162bixPT4/VqVVE1WL3Pv3T5Xrz/8+/emTo29/zF"
    "vXUP7IP33x+bmADLu45v2kDfrKyE1XUiF2dU08+mEuVS3jZ6i5Uux8UWv1/Jl3IYQZpqB6OE"
    "F1++tFcnuPnNtZCOU5hb2arhoRfg89Nj9+yACdyPPvxESrCnzj6TzeXv90a+a6+tb548cYgk"
    "+yh5E9EfYHSSwCDHKxZGeEHUdSVbGBFYolKtUcjDBqlMlr1nn+C+URqbLI1NrK6s59JyIUD9"
    "QBSxv66NU/zrv3oNJ/f3Rz5/6VJPVYCIhqhBUqYZxjX1FOqPlHTLIWP+VhX1RyaTAtDt8xfO"
    "QX6AmjLocbgPzBK9J1/N5AuO69G0hJMUz7EJkf1JXWzuxGw8LjBkeIAMAGsxlZKPRCfYHRhh"
    "ar1Ws0dDmsFwSrdGI8HAdSxNkJLnxPihdo/m3rbQNajOZ1qJVCq2rx/Y1K5+8d/licknTg5A"
    "1O+PpG5ev14YHQt8D1aJBSTD8iTaUwPONVRFt8FxjY2NoLYBC5J4b3VxHfBu2o5hKBAVn/qj"
    "l+N76trA0HzPr+mtuCSAW1lYuJ1OxZuNHqR9hfFTxYwYIbTXbduurSwtZwplR+8pmgHuBSMw"
    "N8CfuXB+qIu1qq3Cz8pnduMqDHhW17VjBC3LSUESSIZ76smH3s6q9tqrq1Wah6wJYRFIekSr"
    "f9QPHBJT09O8GN+Ld9u2cqWyrvRQf2QIMKVlliNDMLMvCCLOCByF3V1eGSkVwpgfC4mRiRGY"
    "rbQkzaaP+54DYXlv3QM+YckiXZWItbs9cNyQcyflOEni9M6Z8BsJEnVT0bkM+Bzb8yVJRFkf"
    "5HcYuVcXg5OOBO9Rna9UKnGcAFlfR9NCLRZoVtTv8FDDgqSGxDOplKGpGmT0plkql/fjHVnZ"
    "YfndjSlgQZblbNPIF0vgmwzDBAOpmgmuOZPNE7DWVUOOZ+dm0o5t8ixHUGG9upXKZWFWN+4u"
    "645z7umLLL3rZ+JxybIdSeRFnveChiiI7Vad4uKxwAO3N9TF0qmE7bosL+BIpenKcqpZr+eK"
    "eVivQDolgY/wrh5dfySM9fV1gec03eR43nVcnAxv3LzR7RjPv/DM4cXsnZEtFOHv4p1F4MgU"
    "joWcEMk5SPlyB4j3gDoELkRd3TCjI5EODHnj8uIiLBESp3pql2bYOBOu392aGi15Mbyyse54"
    "/sRosd3tCizJCrxnQybpABgxG5JKAw+o4eusraxRHNdbWTt+fEZVjdp2KyHRdq/b1YxkMmn1"
    "vSUgtL69Db+us7w2MzPHMTTwSDwMWo1tw4klEokoMgHevcA7EryLogiHpqamRCmeScuagUxP"
    "U2RPUeSkFIYPvZNbFAV4BsMkaMfsM8MYw9Acu1OHc6xMrshxTDIx2Apjov5IMZtJp7M5kiB1"
    "TcMG/ZF6YTKO+iNb3Wx2EtaHrmvFPIkTIWd4DEeD1QDlQDp5ABu7a/dz589f//oa8NTlpcWn"
    "n33uJ/flAkJnZ2eufvUNeMKVlZXLly/9pN0A72KA/6x4D3fjKvCZQn9P+MjY+PDgaOwRR3FP"
    "sjp4eiRSDvDu2tbq8iIfT6flgd1hLcD/16q1SqXieiFFMlF/ZErANtvOSCbpkUyjVgUGPj1R"
    "rm63IPpsrlWScpKVEkRg266fzpW52G7Mv71wW84V8f7WYfG+mlewcPuH0dHR/v5a5n7YCoNQ"
    "07R8LvOoxviJ8fi+h2FvXA1i+MjoBCfwu3HVdtyFOydwjGNRjgZpD8mndaA1tjmTTfE0CcRI"
    "6KPJfPvdwto6BL451AaG+WGMxjHIalr0e/QwbyLJ6csvsZoS/dO+dg0+FU2lWYHEwmFCZIfh"
    "uO3EFfQ1AYCJysZdkWUhJqWSiQAeYOc0x3c5w7bazYNf0P6p/fD7jZBOxvrq3uOz+964arvG"
    "8spqKpXIZ3bqqw5OefZ7n3zKIl9EAPw6WpcgmYJELDXNiZSouFicIWSRn1GV1bV18EWaqSV5"
    "wfaCRL8p1ZRzk0M/Q5Iff/2lapiW680fn1tYXcUwgmdiro+1VP3F+SfG+6IueIZbtxcaqmLY"
    "3qnJ49VGNcApyBgYllSs4Lmzp8r9Tjc/CLY73VL8ED0S+ZnD7G6jPUZoDHSCozb6fl0sDC3H"
    "pUiUrEUHHNudPTZH9esm6J+eR5Ok47q+59Is2vSDtgKTJIRRwjJC24WEP/ADkqJ838PB2Qch"
    "xTK7+WoQeKLIUhRcRfc/Y2gTO9zQp0gc1li05coCJtMvxew9DSwHt40aNAc80rHRvh/6kMRl"
    "eLcDhuEBTvxdXewxjL14N7XOBx98KqXSr14etNgjnYCn337rXSkZ9Udy2/VKgNFF+d7+yOC7"
    "uxXIrFfubGTysud7NMPVt6p/+jd/t1cXi3TgnuXBVeVC9vqNhWRC6LRVXiDOP/ursX5nWWga"
    "V968ki3kDFXLjx2zu/VqXxfzfTtGiX/1xusDXazX+mF568n5Mwe/YGiaLMcdfI7dbQFvi/2v"
    "4f2esU8HhjgGFCsMA8swov5IpKMFXqXayGYeoj8SXeR7jVYnn8tisd3v5xjqYv1bIYnO1DXb"
    "Dwd1GPSVELvO+gh14McwfuTf9d477308Oj19Yf50dCTqj3zn7bfLoyM+6mmP6aaq6nYhSVS6"
    "QUnmweHm0snRcsFU2zdvNgU+7DTUZqcjZ2Uk0hvqxRdeL2V3+yOvfvG5a7uag3Yby4n4++99"
    "UCykt7Za+Qw/MntxqAP//sOPEulUp96YOHFab1a/bLQhx8YIyKjJ1/74pcjwvmPeWVw+e+bk"
    "wS/4KHWPozb6PrwDCHvoq7jYIaPv4/0sABLoBLj4CLBol4WhhQSbkDgIkVg46I80UYMJ0W8t"
    "JAcb3cOowx0f2l1RejzPW7Yb892uoqbTaVQ7JAjLcSApHdY9INuiaQonqF634/pBQpKCMEDM"
    "ESOSyURkd9PQ/RATBf7gd/x/gHfXNK9+/vnYsbknTkxHR/p4x//zkz+MT06B9W3LRXvcTVcW"
    "go5Fp0VahZ8TUqmYDzwb3DS8oNJWm81OPBXvdjosTT97+eW9edPa8tKabsBkTIxNtNtdxwm6"
    "7RrJoH3Dp06x+Swi44DQzbUVSBJDnEwnkj8sLZXLo9uVjXy5oOn2qZMn0v3v3YK8abOC+r8P"
    "fsFH0Qkew9ini50+c5bh+B/rwP65c/O9XjfEcUhlGY7KZJEsRvB4To6Ljgd8ZW19o1zM0zTC"
    "diqXK46NADSPTU9omuGjfZTDu3kA2EKxCCk+sPxSuWzo+sTkFMAYeBRDkcN9wywnCImkaVhy"
    "On1RTrR76uyJOYLA4nEMlsRw3zAvCkeyv+kxjH26WKvd5QWrlB9srev3RzLLi0uZYinqjww9"
    "R1FNBrdiZMI0jZ5iyMn4salJ17GAOIILVjtqZb3Lx4XQcVmeA4bOsrv9wDzPbm1WpaTcqG93"
    "e+r8k+clcb+jAIS6jl6t20Bp2o06UCMfZ+Zm9vf9ov5ItXskuthjGB7qq9/Box9jaSIpZyx7"
    "sAaifcMxgqpubKBtwxhhuzYiJGTYbGyz+QzFsmDxhR8Wx0YKumHwPgnZTU4o+q5N8OD9neDH"
    "/cDdDqRduN+XHxiW0Q0t+iLCH1kB4rHpADF1bA/YvtrSOYm+F9eoPxLHjrjucWQDxcCd/fYe"
    "joqdtm3x3ADvOO7Ckuc5JjM+BtFP03SSJMAoMd9I5JM8FTZbvXyhOD5OQCRMyzJOhpbuqpoi"
    "JSTPdniGAd49rMmA3UfHRrfr7aQsB67dVY1EPH4vGOEhstmUooeZTBKmPZfPejHy3tMA76Zz"
    "OJb/j+Id0O44O7qY6zUaVTuMjRazwyMQ6HtdpdVseUEM5khROzj5P91dW1PbRhTW3ZYs+QKy"
    "8YUAhoRe0qSTtCTTZNLLTF771r+ZaR946EuHlhbah0xnOr0EnF6GUgMGy5IlS6u7enZlHHNJ"
    "YDItNN0HMPZKslZnz/ed3fMdhKJIbXd/n6uVQ1awNjdiim7O1A60nixibR+QGgBVgWUAGxvh"
    "sPAHRczqaavlemFPN6nED/1oClDhRDAJ86/d3h0MXAvVSjm2e6CJ+WI0fVwvGZE9mZGpPq9h"
    "WeFZfUaFWS9u3GEGAl0bXpWLm/PXJFkZvcMwuDLA/MK8rCgwW+EJsSzrgMEja+71kiIKpjXI"
    "5/FHlmlUyhMkXyxEnjuh1jM84zge+KbRbcMQ3Lj5ttbrlysqzA+YPQVFPjkocZw0m00v4sqT"
    "RauvlytTfnjK2MXEkF/Zcadphj70v5H/9Glrcqo+0smDY2RwtaDvgJTH8DKiTdtg+Wwlz/2x"
    "71xR807MSlzCc9zi1dmdXU3JscgOwgAYfWcCeEhXh7PlxGe4+s3ql47jRnQmw4G1xnfv32uc"
    "ED3DMD355WdNMyW10ZiQ2n+1lclK7d6dY90AQeyBkdYae0GDs6VJhi9o6DDCuBweSXHi7du3"
    "2OM6G+qDjz7k+Wf5kQBlcRS8I8ppxZjUewK3ac6J8Agd2wEczklZoEml0iTR2VCjcV+6+94x"
    "b9vrHnAZCQ4cJcEBEt68tZTK74GGTgN6MGxnr5MvFiLyBYbjHkb5gvKq4uo4j7SN/Uefff7m"
    "jZsP7gz3zdN8seXl5Ryu0DHUDVNsJs2PvFZX0/zI2elqhqd/3dJkmY182uwbfhI5lnlt8bVy"
    "tT5ef2ZtdQXI+LhOPsOHYczp1mBcJ//42zXNNB03eGPx+tbWb4IkO3pPLkrjOvnQQ+1u7x+t"
    "t5T8R9fFEN5oFKMo9N1hfiTOWKbi3Y4GMeR51sUQchXliCYrDIJjavlTI3uAFl4Qxu32/7Mu"
    "ZhsHy1+sVxszR3Xy1KePHqmVMkZYmtf0Az+kaiXw7+7cVFF3Qoha52YaZm9v7cm2IjN9zTZM"
    "S5CEgiIZmv7w40/UwrN14B++f6ybph/Eb12/sbmxyfFCFFgUmzPM/vsP7s9M421IsNB1gAHf"
    "B/a/MNvcaG3kS6rZ7ZSrqm56YO91sj0SevaPP20uvXtG0tx57B1wwnNRt9u9NHsPwPro43Uh"
    "ADaBT+K0SAdlxSzDMK4zYDM5CLIg6gIfvLO3j1d0IYzBBYPhF5NWHsb5kTw3rvfQdaNYLMDj"
    "JKvBWFIDBCkhWZkcXkAbroul5yHdeFzNDmcdpwvGDN6CGXZDLMD9WanR57H3vZ2tr1e/UlX1"
    "4uyd1MOmbduBqyZJ3Onsw73kpCEDgRDfQwPL99Ni/DQMVID6toMsPRHy07UKIhULphtVZ2D1"
    "LRt4J/BIN/Dziuwjj+aYSqU20srA+WESUEkETiXwEUStDJ9J2RRN+Pgh3ww6BzihDEK2OMKf"
    "4mEecq44Cqm0Wxy6htGfPLM2fQIu5LnYG+FCYkGr1YLbl+XcxY07RKFr6+sLVxevSNjtNufz"
    "YHtdAM/D1t1vw0/TOHIUToFHGioADwGnP6CIVKVYII57tN9J0pWhX/h8VVfkOad+mJ7K984o"
    "pyRlufTqL90c21pZWalWq2mJ3Isbd62nwVVpOgF7Td9BCP253X7xUfBs6vX66JBXt+3u7sLt"
    "jzLaL9LeuWKpxFIJfAPwKgFZM1DL5TgMeIGHCIhIDBNi0LieDw0BPikwBUBk4H/8EqbA5RPB"
    "FctyGYFFLrBsJsE545xuDERRBCp55gb0pbRiQSmOKaS4en0KQO/fvmrge+DNQ9cLSI2MMEpo"
    "BqMcgFiQ0FmaCSkAt4ghgJnN8uYAJUTUybAcia1pCLsgpIJngw+PcR9Sjx/+4igaenKyLPsE"
    "q9mX0jpfcPsb0i0aSxTJwvQAAAAASUVORK5CYII="
)


"""Icon between database info on merger page"""
MergeToRight = PyEmbeddedImage(
    "iVBORw0KGgoAAAANSUhEUgAAABgAAAAYCAYAAADgdz34AAADv0lEQVRIx+2UTUgrVxiG35OZ"
    "ycw1arj+3VSiqUhwISW0AcWaUBA3uhFxYxddVnR1sZsgIZtmERCkF4RCQnd2UaSg4A9E7OKi"
    "dHEx4KYoRdtICA2dyV/zP2fOnC6qIVWvd1Po5r7wcpgz883DOR/fC7zX/y0CAOvr61EAXgA5"
    "AEkAbzjnPwUCgd//E0AkEjmbnp7+uFar0XK5XNE0rZjJZPKMsbhpmt8Eg0H1seJIJBIFkFhb"
    "W4u9DWABAMMwwBizGIYhK4rS5XK5hsbHxz/q7+//3DTNH8Lh8GePFRuG4TUMYykcDi89CaCU"
    "QhAEWK1WCIIASikajYY0MDDwocfj+YQQ8ioUCn0VDAaV1mJKKWZmZryU0qVQKPQoRACAyclJ"
    "78XFBW5ubv5UVTXHGGvYbDYRgARAcTqdz0ul0nClUpn2+/1Wn89X9Pl8f5mm+eXIyEi/2+3u"
    "v7i46Pf7/Tg9PU086AEABAIBi2maLwAMcc6nAUw5nU6n2+0epJRKsiyjVCoV0um0pqpqRdd1"
    "AwDm5+e9hUIBdrsdu7u7Cc55bGNjI/YAcF+rq6t2xthLRVEWxsbGhq1Wq03XdYiiCJvNBqvV"
    "CkIIOOdQVRWiKKKzs7MJ2dzcjD0JuNPKysoU5/yLvr6+T10ul6Otra3zbd9KkoT29vYmJBqN"
    "xsR3AWq1GiwWC+r1OrLZLFRVBaUUjLF/migIkCQJkiTBZrNBkiToug5CyNNXtLi4aBdF8aWi"
    "KAujo6PDhmHYqtUqZFmGLMvNH9TrdTQaDQCAw+HAyclJghAS29raigFA8wQLCwsWQsgLAEOE"
    "kGnG2JTD4XAODg4OlstlSVEUCIJQSKfTWi6XazZ5YmLCq+s6enp6cHx8nCCExLa3t5tNFgFg"
    "bm4uyhjzyrIsdHR0WLu7uzt7e3u7OOdttVoNsiw3Li8vk9ls9ooQ8iOA14SQG9M033DO0dXV"
    "haOjowQhJLazs/OvqRZvB8a7vLzsLZVK0DQN1WoVjUYDgiBA1/XC2dlZUtf1LYvF8u3e3l79"
    "rnh2dhaSJOHw8DBBCIkdHBw8iAzxLioqlQpSqRQYYxBFEYIg0Kurq3QymfyNEPJ1PB5//UhU"
    "YH9/P0EIicXj8UfzSATwjFKKYrFoAqDlcrmSyWSKqVQqXygUfr6+vv4un8+rAD4AYLZa07Rf"
    "TNNMnJ+ffw9AaXnH71YC4LnH43llt9tHOed5wzD+0DTt11wud5bNZltT1ATAABj3TG/dusdu"
    "bRIAz24tv2Pw+P0TtJjde+Yt63s9rb8BX+/h8JD+o8gAAAAASUVORK5CYII="
)


"""Icon for the Chats page in a database tab."""
PageChats = PyEmbeddedImage(
    "iVBORw0KGgoAAAANSUhEUgAAACAAAAAgCAYAAABzenr0AAAAK3RFWHRDcmVhdGlvbiBUaW1l"
    "AE4gMjYgamFhbiAyMDEyIDIwOjA4OjAyICswMjAwNrNp7AAAAAd0SU1FB9wBGhQHFZJfkT8A"
    "AAAJcEhZcwAACxIAAAsSAdLdfvwAAAAEZ0FNQQAAsY8L/GEFAAAHIklEQVR42q1XW48cRxX+"
    "TnX33HZ34qydrAO2sTcsDiECJSgoSiLBA1EuWJGCUCLxEIlHeIUHHnjiAYU8RAr8AEBCAglL"
    "8YuRkEAKAqMgBwUS2U7WFpeNN/HYa3Z3dmd2pruriu9UT89tdy2ZpKSZ7qo6fS7fudQpwdg4"
    "fWnNn7t0HSurbWTdDmJxyKMIHpPDc8GHVQlzGTz1IePEMnqpVCtYumcWjz+wgFMnF2QXyfdP"
    "X/Bvtht4/HMVPHT0AGrcqUYeGUmU57QSbvCxeAkvQSEZYzhQtBxbqcHyP1t448I67jt6B14+"
    "tShDBb575l9++SbwzCMLmK310OkY9CSGxA7VzJG1TEqnUPFExmRwJqcglRSFNUzTBuUFNokw"
    "y+22NTj7p5t49KjFD58+JvKH5Zv+B7+7gQdPHsPhRo6tRh1R5JDYHH0kiMSNcwrsHXHOjSD2"
    "OSKntkfIJaFeBomzuxRQv1hiWXUxsr7F9a7F2++t4pVTR2D+SJ9X5w/DNirozNQgxkDINOdH"
    "LlKoDSyZF4xypJEJAo1PyDemMsK1ODhKAjhETFKugd+BikbBPYZ73dggrdcwR2RnZhfwOmWb"
    "d284NBu0NFHLyNh6pFTCUwGFVJwqYAsLXS3Ewq3ovGSkrSPODYWDgrthTelqeU4jiFylgtlZ"
    "wcp1i3gzjXGnI5S+EphKMNujTyYV64Zz4/Z+n6bba14OS3X8IKKFxuxkYKZ5CZBSB/RpkVL4"
    "TC0T9EO+FXM7CGuhWTF5N6vcUwQIvDMe7ZR+Jp2b+k75DDPHO9WCSBrVADmnsXcaIMIJFcn0"
    "O1smGNGSMI/5PN40uHfOY4nPhbqgWRnFmKURG1RgtQNc3vS4sgV82LGDqBgpEFGSC3ZoXDCD"
    "KDu2jFpNI8uIcQ5D4eWH9zQMnjhi8PDdwrowTIaJZNMQVaUOE+0vHhJs0ZDfXwXOXVNkZMIF"
    "oVI5dYUElGL9o8uQ5wO23gwLymOfEDy3aDBfmyxEuzN9cm2WGj13wuALB4FfLztc3ijLh9YK"
    "W6RycAVzzAXrCUiuSgif/GWCT80Inv+0BOH7Cd1vlLSLTeCbnzFomIJnRjRSyskyylSDabhR"
    "+HNGg/50Iyd8hhtfOwHMVW5D6j7jOJX4yidpHHm7LKOBPvxUnsJqIuKfsjxmWUTtmNtE4/55"
    "4MEF2VX//9/xxHHBwRp5B3QzdHOGI9+ZNlrmVBvCQp+U2j1wFxNTbg/2W407qsCxOSClkV1b"
    "hdhthl7KtEwQa27a4IYiFjT1nPvoQqeH8lTjkqwNwxqgMcADn+62dhiEGYtMPwXOX5WQGR+X"
    "CzZ2gIstFjrK6tHdfTuHKNNs6GlV9UPtctaCnP7564rgjav+Y3PBmUseK+s0SmsCS3/KVOyY"
    "BBX63uhJ5QcuyNIiE9pdj5+/6YPmH3Usr3mcfscRWRra59lAOX2eEynPHl+kof4x4glNziDJ"
    "cp7cTJG3WMlePefR2i4Y3Y47StoLLY8fv+5xbbOoAznPhg3boMtpve+zMlotxVoQCgW0ULhI"
    "I9CEivjaPwR//yDDay8m6LE+1JORANlDaLm23gV++ZbFmYsea9vRkCbyHUg2C0mIOo9udX2s"
    "Qajl2HGW0f8aE4Ed1xSZd1sOKxuFTf9ZLxidmBccmhkJ1JrS2vZ477rH+fcFf2MMXf5vXrQh"
    "Y40h2xdkIQMknAXhMNJSLNpiWfW/0XOisMYX/tF5Kfxbv0p5AhscSGIcarJdZQsmREpL+LVu"
    "iu2+fqzdEib4lMOiGto557SPLghiX/TYhQK5CpShCwyjROcq/MVfjPZu9BgbHaA8vEq66e/K"
    "+RABNVQVcUVT74t+wAUotRhl1o+KkCKAYv7Cz1xh1WAvILMH3X7zYZyINjYFAkF3ahBLaDvV"
    "XxXttjlLgn9iTc+xuWjQ7PE+TbfXvByOLYmaLbQmM4XrTbNOv/dSVKmKjXa42EOFh7V24+Pz"
    "/d6n6faalz8FhZmOGu8SWhOa1R2YhxerWFtbxYG5iLlJHFgkYtmh63oMjBkkbMWNsagPjumM"
    "QXgrukQ6iJhN2kFL0kXEy4uuKZ1jgNbYIc83LDZba/jS4p0wLzy2iH77Q2zzLnjk7iqZOPQY"
    "QMIPY15NchaOjNBpd+ulEg6S3M0gZXfTM8WaXl6cFhilMyO6zDUKuqjOFr2CerSNxbsirLW3"
    "4Lvv46lH7i1S+UdnL/pXTl/Bic8/irkDTfS22blos6om84pWRNDkDVHGnuWvuDOYXVVT44wJ"
    "iDleflrtG/j3hfN46RtL+PaTJ0c9809++7b/KZXo1w6iOX8ILkmogAlXr+kh47qITN4dZfdZ"
    "HgI962J97SZdt4nvPX8/vvPVz44up+X4zZ8v+bN/WcWV1ibhI6Auxqgv0ugvM4vXL+3hdVdK"
    "ChOu6SZ0u2PlWYq9iNeyxSMJnn1oCV//8tJQ7v8AarJQ9wfXBWsAAAAASUVORK5CYII="
)


"""Icon for the Contacts page in a database tab."""
PageContacts = PyEmbeddedImage(
    "iVBORw0KGgoAAAANSUhEUgAAACAAAAAgCAYAAABzenr0AAAHMklEQVRYw5WXXYxeVRWGn7X2"
    "+X7mlxaQAWkLFCqgyL9CkEg0JSAhmBADxgsTLzFemIiJiVwYEo3xggu8M8ZLb6xGITUxRiMR"
    "iYlEQ00tNI1QcMCWTmqnM9OZs/derxfnm5lvOhVhJSdn73PWXnudvd/3XWcbY3bgyCn96chJ"
    "3pxfJK8s01hQUkJsNQmEAAPARncMbNzZNhv9QZ99V0xz701zPHz9nG1z+daBw3p5cZJ7P9bn"
    "9t07GBoMksgYgm1JxGiwycBGCdlYwFGi63a2dY7+8wR/PnyaG3ZfxA8e3msbCXzjl6/r6AI8"
    "dPcc08NVlpedVWuwJhjkQFvCAjJMCXkmvCAJSJgSnO8LCKP2EtMJFqtz8I8L3LO78vTn9pj9"
    "7uiCnvrNu9x2/R4unyycnZwgpaBXC2v0SBbjkTAgTBQ3GhVSCJEo1kPm9KJuSwATlcwgGvJa"
    "5eRK5dBr8zzz8C78hSMnGVx8OXWyz/LUEHPHQhQTkSBwqvVGgQptckTC1cPUEGa0qcFG6yQL"
    "ZC1tgmpQPCGEAyuN004MmWmCqek5/nDkJP7qu8HsZI/Ug7CEV9G6IxOmhIVTrXZfGEOa4hQH"
    "Z2XjmdgcK8sUm9jiJ8vIxLAUMKPp95meNt48WWnOtA07o5DUx6uwSBBizSbo1+BcdRQNLpFl"
    "DBq4eaph32yDG7RhvLJgvL4MazheJ0HQmtG4sWYTGztR8Q6YAosh5zI0JkMkosCaO0goOzJj"
    "TaJtO7ybGdfNBo/sSVwzY/gY1u66xDh0Wjx3PFhoDamOwNjF2WCOAiooHCwoAY1CVIwShjJj"
    "g7tJS+naH9kBX9nXsGOwHWP9BHdeauzsJ358JFhYtVGM2MKKRCUAKSEyEcJrVCRRq5EzlGIb"
    "V86Qs9EIPn+VX3Dycbt2Fj5zhVFaJ2fbEqsUoy1OqUatjmQg0SBRA0oZKZt8C5VzNu64FPZe"
    "xPuyuy43fn8c/rW0/Z0sYard2lRQBE1I1Cpy6SR1XL3MIGe4cScke38JXNSHPdPw+mm2iZJG"
    "UukStQgCGkmUEpQSIAPZSHbVJVDGtP59Wgjy+oqOibhTqA4uRvNBk2rQVifnNCowozGjqtIW"
    "sZL9ghJ7IROw0oq2BOBbqpPJCGupTFCLQc00VFEK5MpI0zfvZlAKvPCG2H81DJv/n8D8onjl"
    "313MjgXjipxo04AhS0gtoR5NKKgSpXRYsDHeSiLnxCtvBy+9JT57zXuvggS/ek28/R8wfFsC"
    "SPTyIm5BLWKZhiZq3QBhR4+xweaU4hSDH70sLps0bpr73/t+8Kh4/lUoJY1t2GYS8kqREzZF"
    "yqcxVmkiREQHmghH4WwUaoO2FZg4viCe+q3x+MeN+/fBTL/bIglOLMEvDovnjgTnipCMXs8o"
    "ZSulKUFSQ9uvLHuPnWuFRgitb0GJkUB0IDQTeaSEbs5bpyvPvmgcetu5+cPisinj+Gnj5fnK"
    "X+ch184vqEDaAmaAJsSaC5pEqz7qaAguQ9UpeTRYRs2JSG2HZDkDM27ZJb50a+Keq4zJ3uan"
    "PXZL4s9vip/+Df4+b2SCXAElPLo4PW8gnOVmkplq9HWWSqWpIYgugdwakTr61AIRIpm4/Urx"
    "5TuMT1/bo5+gnvd/NtWH/dcZ914NLxyDn7xsHHpHIOEyIgSNkbSM5WmsJ2SVCDoQIhER5JI6"
    "Z0TNIhzuv9H57kPOzFgdOF8V17uDBh64AW6Ya3ji55WjJzrVC2ek+0G2oBZDo8Q8JGSi1CBn"
    "kTO0uQPlTXPOt/enLZO/l9mIilftNJ5+ILFj6OTS4ShnWMoDcu5AbzgIXBISXQIj51KcuRnx"
    "nQcb5mY+kAqzLiN37ja+fh803lE8F9+kewgFKMAVHU+rRK7rzvC1+5xbr/xgNeB8UfribfDo"
    "rUbQ20iilG4FJJCCxgicgugjg6CHZDx5cIlvPp9oSh/hlP4yFl0/989dsH2+X9dfwSxhGhIk"
    "UGAusnc099kJJ1ZbBo1R0znMVulHpWmnOuVqWux8SR2z8/0u1E9liEWniTnB0AuxJmYH5/BP"
    "7B1w6tQ8O2YSfYl+JBo7h3wVyhQ9K7hXJjJ4QHZ/T7+eLZNKQjHEeiskz/RsGfkqocTQMhdP"
    "Vs6cOMUn9+7EH//UXtYW32FpZZldlw1wD1bdMM80rFHqJJnEmk0g6+MWlJiitcSqd8+SBVEn"
    "qSTWfNMvx2TnlyYo3mciLbH3Q4lTi2fRyls8ePe1HYW/d/AfeubAMa65+R5mdsyyumS0IaoH"
    "WDN20NM27tvY1Z0PfNs50ggGBDOTfU4svssbh//C97+wjyceuH6z9j7760P64YFjrA0vYfbi"
    "S4lej+pOCl3opLWZi9nWs6PFBfQh8LzC6VML9OMMTz72Ub66/0bb9tP2sxeP6OBL8xw7cYYc"
    "lRQNtjnTBsdFIGXAkK17OIbh68Vs/cfKunepcfbu6vHI7ft49L59G/P+FyYDSiMHBeEOAAAA"
    "AElFTkSuQmCC"
)


"""Icon for the Info page in a database tab."""
PageInfo = PyEmbeddedImage(
    "iVBORw0KGgoAAAANSUhEUgAAACAAAAAgCAYAAABzenr0AAAAK3RFWHRDcmVhdGlvbiBUaW1l"
    "AE4gMjYgamFhbiAyMDEyIDIwOjA4OjAyICswMjAwNrNp7AAAAAd0SU1FB90DBRIcBgK8oMUA"
    "AAAJcEhZcwAACxIAAAsSAdLdfvwAAAAEZ0FNQQAAsY8L/GEFAAAGdUlEQVR42o1XS4tcRRT+"
    "TtW93T09D/NQEyURHAnxhWJACTHgRtBIEBTRjWtBt7pQfCxciGSRhf4Fd4bgJooLweADQXER"
    "iNEQfESiJJkQMpOeme66VeV36t7uvt19oxbM9Dl1z6k69Z1HnRLUxrEzK/GbM5dw/sIq3HoP"
    "mQQU1iJickROxDQriZfqV3+kLixjotVuYc9tCzh4/w4c3rtDZkReP3Y6/rDaxcH7Wti3ews6"
    "/NK2EY4iuua0EaFSliiJSAZJbcHK0OFYGxic/fUivjt9FXfvvglHDi/LyIBXP/ktnr0CPLV/"
    "BxY6m+j1DDYlg2QBbRe4tEzuzk0lEhnjEEzBjXQnm+YwLZuMF/jcYoGfV73Bia+u4MBuj3cP"
    "3SHyxdkr8a3PL+OhvXdgZ7fAWncO1gbkvkAfOayE+kpp+UCcCyPIYgEb9OwWheS0yyAPfsYA"
    "9Ysnlu2QwfU9Lq17nPrlAo4e3gVzkj5vb9sJ322hN9+BGAPhogWVglWoDTwXLxcqMLAmbWhi"
    "znUzGiOcy5KjJIFDxGTAOVAPNNQm9xh+W88MBnMdLBLZ+YUd+JJ7Zz9fDljazpPmejIL6yMG"
    "FMwJq0KajMk8l6CMzwh7SHJHHtQl29Uf8MaPPskZntSji6xg/HCjPK6rx9LoFAU2aGzWamFh"
    "oY/zlzyya4MMWwOhjC0Ybi7p2BF9mUPLhxFvwiSNdKYaysE06ik/HGperCJaQgcbDsy0KAlS"
    "2oA+4VeJ6ChIaPsp30reV2E9oqfGRmjWU36UOTGoFYhqrKY42SwGDRAhQ0Oc6vlhgkGoPORF"
    "zAQ9PfquWa+eFZY7hXQOjQtmEPfOPKNW08gzYhKyI6WhYjP90sniBt9uxJcuSJUq6GEkoZTp"
    "P7oMRVFVtmimqkmNvxH9f/iUIVorfJnKyRUBWUinJyBFWVLr1UtkXM2G9EeHZguNjhc/i416"
    "EwZUpdLonnrgFANkCkaD/qV8iVKV3ZgWGvKi0MXmzXUUDo169SJuUICFkAag2o8GWOI/4Kxz"
    "trpgKp36rVLjnz0eE338GTthwMDHf9VLyNCowCLlMUcEaKV3jAGvCAAaxLHCbfg7zCDlm+j6"
    "cIS0Sa8+tLANbBsdXOe3AdMy1xgItCGmINRYkNrq5WbSSM8Y4NCoNxkErKduFYY1QGOAFz4N"
    "8H4UhN6XlUpSlaOPpMZLnKCnR39wAz2ML7NoWK6ZHUHmYd1Vft+kASwGmv8KYdD85N/oohaM"
    "ed4BdXomCAvbrFcHgoFneYENWh49k2Nrv2AWoPRdcgEFygJRBo+kU5e8mDBBT98FzsVGvTpa"
    "md4NJoU+Brx7YpmGmhZMGcJfsHaHVKzLYxgZ84ZFpE7PBmGz3gQERKWXdbHIqtuKa5TwWoq1"
    "IJQGuAHTxFano69MGPPGT9IzBvhmvVQRq2FjD+IWIDkREp9cn4JQIyaQc/SjxkTCjnOKzJBX"
    "1Ov0bBY069VLItsXuJQBklyULqMQS58VPIFTF5ix67RkDnltver0dKF3rlmvnjCezYu2cyFI"
    "mSGxKsVKJAM0E4yMoWSUDPmULTV6xoCiWa/ugkwPqoaEsuaWQaidjk7SEOdjdSWX6Gn3N+TT"
    "qUj/9e5sAOr4451W+r397Um9ej+vTatHiUBKVVqQSWo72VqjlYKWXVzyT6bpWeNFgwY5/mvI"
    "lF5Ws4BVIB1bmIrOlK7PluYM1jYHaLfn4e1G6uVy30p9bNEa866id785prNiKNcb8TKlF2v1"
    "QttExjk6fEv0+xFL7Q2Yh5fbWFm5gC2LlrlJHHQh2aDrNik9j5ytuGEJnXNlAXTsG/9NLpce"
    "LHeJbDolX4fl40XnVC7wMuqIw7aux7WLK3hkeSvMC48uo7/6N67zLbjr1jYXCdhkAInRq7LP"
    "4Oyye7Opu43SShdJEeYxYDHaNOWcPl4C5bzKmbGcC91Szs7xfdDCnL2O5VssVlbXENf/xJP7"
    "7ypD+b0TP8Wjx87hzgcOYHHLEjav87GhzaoemU+0MoImX4hNnZ9+DXoRzcRF0ATEIh8/F1cv"
    "4/fT3+P95/bg5Sf2ju/MDz49FT+kEf3Odixtuxkhz2mAqXJ+asG6LSKTb0eZrVIp0N06rq5c"
    "oeuu4bXn78Urj98zc1fh46/PxBPfXsC5i9cIHwENGWS807jRgF5Mrox5GUqY1FOa4SVU2Vjq"
    "8CB8bS3vyvH0vj149rE9o33/AZd4Hw2lBI2bAAAAAElFTkSuQmCC"
)


"""Icon for the Merge All page in a merger tab."""
PageMergeAll = PyEmbeddedImage(
    "iVBORw0KGgoAAAANSUhEUgAAACAAAAAgCAYAAABzenr0AAAAK3RFWHRDcmVhdGlvbiBUaW1l"
    "AE4gMjYgamFhbiAyMDEyIDIwOjA4OjAyICswMjAwNrNp7AAAAAd0SU1FB9wBHhQSAqlbZbsA"
    "AAAJcEhZcwAACxIAAAsSAdLdfvwAAAAEZ0FNQQAAsY8L/GEFAAAIvklEQVR42n1XW2xcRxn+"
    "/jlnr77Ecew4F9ttXFynCVRJoLRKQtNKFWkhQmqpgPLIGxXlpQX6wFMjRZBKRYIH1Eg880BU"
    "IdREIlLUVqGQQkFJFMfN1SGpkzi249vuenfPOTN8/xyv13FMj3R2z8z8889/+f7LCJY9R0cm"
    "3ccjd3FjbA5RpYxQLOIggMP9j+OE87Pix7L4r3+ynFiaH9lcFoMbW7H3yz04MNQjD5C8eXTY"
    "fTpXxN7tWezq60CeK7nAISKJ8lwphF3cLE78hxdIljFcFLTxzNcNLl0bx+nhaWztW4PDBwZk"
    "SYDX/zzqLk0B33qqB635Ksplg6qEkNAiF1mylvtP56HiaBkTwZqYB+lJgZ/DSlovvCDJBGjl"
    "8lxicOzUFHb3JXjrhX6Rk5em3C//OoGdQ/3YUIwxXywgCCwySYwaMgjELufk2VvaOTaC0MUI"
    "rOoeIJYM5TLI2OQBAdQvCW2ZsyGiWoK7lQTnLo7hnQO9MB/R57nODUiKWZRb8hBjIGQac5MN"
    "1NQGCZmnjGLUA+MPNC5DviGFEc6F3lHijUOLSZ1z4D5Q0MC7x3CtEhrUC3m00bItrT34kGeb"
    "zyYs2ovUNKOakXHiUKcQjgKoScWqAEmqoc17LHwRnZOItAWEseHh4MEVP6d0+TimErRcNovW"
    "VsGNuwnC2XqItZamdFnPVLzaDjUyySZ2aWzs6t8r6VYbN56E4rhFRAuVWYjASHPiTUoZUKNG"
    "SuEi1UxQ8/GWjpNFWK/8Xkm32ngpcpxVKWhJoxIg5jB0VgEiHFCQSPcljQCjtWRpLGJW/V5J"
    "t9q48QQ8yXrZFReMIJ4dJkSthlFCxFiLZZsaG5lEiPjOPNBTMGjNCP8FbdkAtSSlyQUa5wHG"
    "F4BSJPx3uFclOO39AqgLfKayqoB4K4X6Q5chjhczmzNLewha7FgX4Nk+YGOLqEsxUwNulR2u"
    "Tgs+L6eZppeA2tIm2LtB0JEj8GiB22XBB58DZyadN3WaPjRXJGkoe1cwxqzXngaJVQjhP19q"
    "sT4n+OGgwStDgtmqWgE4fs3h0CcO5yaA/Q8Jbs2l7/P9grOc0zWlUVrd88qjfMlDeSnPqE6r"
    "8Jwo4pmqMAUzav6YIuqrCzFxsJHAfW2HoKvgcOSMw8iU84i9Pgt0ZoFta2nqOtAe6utofoft"
    "neLXrs86VHnI1RmHd7m3O+/w2k4hT+aVKKKCzr96no+G594+61z3ANa0F33CKISCV7nh8fWC"
    "mapDmZJvagXocizEqSlzPFgFmqik6bG7KB4HcxSqwLUW5hRmcNycUzc6bKZ7/jPu8Pt/Jygn"
    "dWKhgLl7JawvjRIDiUrDDeoTWmP/w/RnB/CPMYcz4xZTC4KffFVw6qbjXFqgfvqEwXsXHT6+"
    "mTp3T5/gxUcNDp+2mmewe7PgabrlD2etj/udLH7Pku83egO8dy2HPEqcrxNTGYQam4l3g2YD"
    "hyc3Ct6/5HDimsV8zaF/jfGg+nDU4gb9vaEVPq1eniTyq6lFLk9wL7FSJkDvlJgh6ZJ9/SFm"
    "KmoFh/PUvsxq+OQm8rk6j2o98RhgwacASbIEQs37ivSY4fXdIYMr93wyo3UELQyJzS1AXxvU"
    "aJirMIQ0Yrhrvqp5xGFDQQsUXUA3RiTazMgh/vBQB9eTlNdsjRO2DUE0zWioQp5+65+u1jWE"
    "fKHIPGDw0laDl7fDAysTiA/Rhwm6GcY465APTfXxtWmgvlj4FB9KM02Nw+B+GnXtmrwvATh6"
    "3uL9YTJimMyUFtC78F8V2MEtuiAhMv9yQfAVArCF8Xz4FEtyFODtFwSfjlmcuJzG+S+eAf54"
    "FrgymZbawS7gR7sMfv2RY55w+PZW+n2jwevHGJIZizf3GZTonuPnEyYv56Wss/a4NAz1h6mT"
    "jULMw2YXEhz5xHpk/2xvSARbXKAPH+s2uDqZ4OxtiwrjWYvyCEE6cifdX2EI69pV5oMvdRr6"
    "3XKvw8/3Goaz4MhpR7dR86RIl2eQdTVGA3Njoo6xqQCaKCLafIQl+g1Kf2sGOPhNgx76/ZFO"
    "xv96eN9eJza2dmuoOY+PoS7B6LTza9uIeKXtIVgP7jcYI3CV18hdTfUVCMNaSOdYujX1exBq"
    "rFiOojjwBUJj+7M7DgdPCPYNxvjBjtD78jcHAozeS328nVp9bVNaFfcwxKbp2ndfDLCFCakl"
    "m2Lg0MkEH1wRv9endgI2YhVMYvG1wBcjTcWiLVaimdBonUj7XQcfnseGLU5eipnvQ/R3xVjL"
    "gjTQGWBdq8UzA8b3h6eva1JyGGXGnKaZb7C/HCtFdItZ7BMbxSjn2zlrtY9ODwpd2mOnAhCI"
    "1mipML4oGaJExxFbm4ssPCMTafHRhsSaxBfYJl1jLEv7GnwaT6iKqiA2bepd2g9YX51UW/Wh"
    "bfSgCk40x8at/r2SbrVxs5nWZia1gC+8lIApQ9MPW2tkVXiOMt4/oYbnsrEoaFb5Xkm32rh5"
    "lwi82sL6EJnU9aadPrXVOgsMk06wwMkqsizW2o0vH/+/75V0q40brxqFkY487xKW+aI9twDz"
    "xEAOk5Nj6GgLGJu0A5vJUBboOib6uAUZtuKG/i1E6nsyYN/4RXQZKSNgNGkHLZkKs2fk55TO"
    "EpB5dsidxQSz45P4+sBamO/vGUBt7jZKvAv2rs+RiUWVABJuDHk1iZk4IppOu1sn7Jx9M9mC"
    "Orubqknn9PJiNcEonWnSRbaY0gUFtuhZFIISBroDTM7Nw1Vu4vmnHkmbr0PHLrh3jl7Blsd3"
    "o62jHdWS9nNMzaoyr2jNi17Tn7Lsv/GmdwbzwD1SccYARBsvP+NzE7g+/C/86uVB/Hj/ULNn"
    "/u3xc+53FKKWX4f2zi7YTIYCGH/1WuWm1ZRF5P674/Kr3DIBTFTB9OQUXTeLN763Da8+91jz"
    "ctp4/vS3EXfs72O4Mj5L89GgNly8G2Ox3W5EljYakZ9z0qAw/ppufLfbjMB0DxVh+hzozeA7"
    "uwbx0r7BpXP/B3BdFieyVMNyAAAAAElFTkSuQmCC"
)


"""Icon for the Merge Chats page in a merger tab."""
PageMergeChats = PyEmbeddedImage(
    "iVBORw0KGgoAAAANSUhEUgAAACAAAAAgCAYAAABzenr0AAAAK3RFWHRDcmVhdGlvbiBUaW1l"
    "AE4gMjYgamFhbiAyMDEyIDIwOjA4OjAyICswMjAwNrNp7AAAAAd0SU1FB9wBGxcrI94utjQA"
    "AAAJcEhZcwAACxIAAAsSAdLdfvwAAAAEZ0FNQQAAsY8L/GEFAAAHcElEQVR42pVXW2xdRxVd"
    "e8459+VHnq4bsNPGbZrSAhKpCiGJQCKVaCurSBUCCQnxDarEB3wgxFc+UMVHEI8fPvkBIVIg"
    "iCAeSilpU5UCoqpIXJsocZJa1Ildy49r+55zZoa159yXr2+MMtbxnTmzz+y9136OoGucnVrw"
    "l6Zu4+bcCrL1OmJxyKMIHluH5wsf3kpYS/NXf6SbWDqTUrmEwwcGcfLDo5g8MirbSL519rL/"
    "x0oNJx8v4ej4blS4U448MpLomb1CuObH4iVMgkDSdWBT0NZYTQ1mrs3jjctLeHR8F743OSFt"
    "Ab7xm+t+ZhF49tgoBiubqNcNNiWGxA7lzPFo2cqdTMUTGZPBmZyMlFMU3qGXNggvsEmEQW6v"
    "WIPzry7i+LjF6WcOilyYWfTf+eMdfOzIQdxfy7FaqyKKHBKbo4EEkbjuk8LxjjjnRhD7HJFT"
    "3SPkklAug8TZbQKoXSyxLLsYWcPi9rrF29NzODM5BvNX2ry8937YWgn1gQrEGAgPzfmRixRq"
    "A8vDi4NypJEJDI1PeG5MYYTv4mAoCeAQMUn5DvwOFDQK5jHcW48N0moFQ0R2YHAUr5C3eeeO"
    "w3CNmiaqGQ+2HimF8BRAIRWnAthCQ1cJvrATnZeMtFXEuSFzkPF6eKd0lTynEkSuVMLgoODm"
    "bYt4OY2xxxFKXwqHSlDbo8FDSta118b1n7foDNf7qcT4QA2HqnRgCrlJTGbXa7ix7rHYICIU"
    "xzc9WqjMRgZGmpcAKWVAgxophc9UM0EjxFuxtk237p0rnWr3xAhw6kCE4VK3Gxoc5/+VFPjz"
    "ex5vEm1Lpp5oQUOc7hV7pw4iXPAg3fS2FWBES9prEdN/zr9TDxo89QGBke3hqmMXhXp+XLCL"
    "fM/dsARO/YIRRN6xpddqGFl6jHNoM+/osfN8jLY8cZ8K1ZNYehKN7h8fjfDGvMe7q6qABBRj"
    "/UcTIs+bmc2bnmzSte4zPzYiGEjwf4d+pnSfGDG4vkT3sWoKh9gF7QlIXgDayl76wUgNODgE"
    "PL5PUI4L52EY48r7HrPLwMIG8MpNanagOFx2EECPrdPEf7lFXvy1qnDwAXLM6Q36IMAi2FMB"
    "npkAPkW7qVOZnpNPHZTgWBdvAX+45nDhBjD5kDBpoatCdBiH5MXJhVmHa0supO+CHwWIiH/K"
    "9JhlRcJ4ZA/wwhMGY0PbD2v7Nl/uKgPPPQwcHTX4yVsOd+p0tEcofHU7/ftE6lczDi9TgNRl"
    "dPoqEeAhDIkYVhEAMkK7u+zxlY8UzIGdIW3tKe2XHhO8+LrD3+aAz1GIyYdN2PvdVYd3Fj2m"
    "WWfeW9OQjpghy6hgjaZOiUqiPsDYDGbw+OSDgkf37cS2/9BvjjEMz007/PhNHwR4+mcW24KS"
    "fJJshQi64AMs+BTA2rYTHhw2uHf2BRrjQ6wJqWru8Jmf2uDMgmLd5m+Y0hk9TgYQZUvc39Ss"
    "6kP8Z5TopSs+OMu9Dv3mpX+rYzH/W310HnWti8emFJWpP2USq5sEJdreqOP5pgmm5x3OTd27"
    "AL+dcpi+zeKUFk+WOjp1Z916XIO1g3warBspa48vwpBerfWAEiqEZy7mjP8IJ+kPqpm5i01a"
    "e6/Nenz/IuuGerEvsqNhqnborDsfGdTjGoaIUMmvksJqKtaEUAiQEaIGw/KFc8CJByJ8/YTg"
    "0F4gibYyV17Xlzx+cMnh0nUTCr+L1NYmZEjjtq5bI/J1SDYISYg6S7eaPjiheozjKqPdnCvq"
    "5cszHq/+h3E9mOLoB9lOUYovP8k8sV9w+k/Ar6+kTOEmaKkItr7Ts3rXrcH2BVmIAAm1IBQj"
    "TcWiLZZVuxmEM1F0txqec7Tlu8xeETd+/q8UV79dxi/+6bfQGb/zujUsyqGdc06KCPHNVKyT"
    "IECuH0oHSnpJax2ihfMHTtsC4rvQ9Vu3EVBFVRBXNPWFE2p3g0LbzPpmSS7Q0+6vtQ5a9Zn3"
    "0vVbt/OAaDNTIBAKLyWIJbSdbK1RCk7LfjjYJ9bw7FqLOk2feS9dv3U7CNh5qdrC4M9MYXoz"
    "XCW8mynLLXv3aIMvN1FisdZuvHt9t3kvXb9161FQWPNQ4V1Cc8JweQPmyYkyFhbmsHsoYmwS"
    "ByaJWDZouk06xgAStuKGKbTKGm40Y7Jv3IkukToiRpN20JKsI+LlRd8pnbZiFXbIe2sWy/ML"
    "+PjEHpgvnphAY+W/WONdcOy+Mg9x2KQDidFS2aBz1ti9RaH79VIKhSR3A0i16zXFO728ONJZ"
    "pTMduszVCrqoyha9hGq0homRCAsrq/Drt/D0sYeKNPXd81f8mbNXceijxzG0exibayws2qyq"
    "yhI3PWjrDbG3S5TmrtOGtSdrqp8xADHEy8/8yh3MXv47Xvz8YXz1s0eknSd/+Pu3/Y8oRKOy"
    "D8N798MlCQUw4erVO6RbFpGtd8fuq1yXACZbx9LCIk23jG9+4TF87akPdS6nrfHL16b8+dfn"
    "cHV+mfARUBc378YFaUtcBhIBycK7cC8ogjP0lMZ3enNfyBf2Il7LJsYSPHf0MJ7/9OE23/8B"
    "F8pelXv5qYcAAAAASUVORK5CYII="
)


"""Icon for the Merge Contacts page in a merger tab."""
PageMergeContacts = PyEmbeddedImage(
    "iVBORw0KGgoAAAANSUhEUgAAACAAAAAgCAYAAABzenr0AAAAK3RFWHRDcmVhdGlvbiBUaW1l"
    "AE4gMjYgamFhbiAyMDEyIDIwOjA4OjAyICswMjAwNrNp7AAAAAd0SU1FB9wBGxc4JCGlYgUA"
    "AAAJcEhZcwAACxIAAAsSAdLdfvwAAAAEZ0FNQQAAsY8L/GEFAAAH6klEQVR42pVXXWxcRxX+"
    "zsy9u+v1T+ykjWPiJI1TN05apWkoaUhTAlWqlCoqKEIF8YDEWws8VFAkJPoAlagQD0UqLwgh"
    "HuGBgIDKSChCJSqNWrBACQpxrQgnad3GiY0bx7v27r13hu/M3fWu7RDMSFf3ztwz5+c7P3NG"
    "0DZOXZzxb168jqtT80iqFUTikFoLj5XDc8GHVQlzabz1Je3E0vooFAsYHujCkQf6cWJ3v6wh"
    "+dapC35svowj9xdwYFsvSvxTtB4JSZTnaiVcY7N4CR9BIWlj2FC0OW7VDSb+NY23LsxhZNsG"
    "/ODEkCwr8I3fTPqJWeCpQ/3oKi2hUjFYkggSORQTR9ayUjqFiicyJoEzKQWpJBvWsJo2KC/I"
    "Yosu/p7PDEbfmMXhbRle+vR2kT9OzPoX/3ADD+3eji3lFLfKHbDWIc5S1BDDimvnFNg74pwa"
    "QeRTWKe2W6QSUy+D2GVrFFC/ZMSy6CIktQzXqxnOvzOFV04Mwpyhz4sbtyArF1DpLEGMgZBp"
    "yk3OKtQGGZnnjFLUrQkCjY/JN6IywrUoOEoCOERM6lwD94GK2uAew3/VyKDeUUI3ke3s6sef"
    "KNuM33DoKdPSWC0j48yjTiU8FVBIxakCWW6hK4VYuBOdl4S0HYhSQ+Gg4GpYU7pSmtIIIlco"
    "oKtLcPV6huhmPUKfI5S+EJhKMNujRiaFzC3Pjbv992q6282bI6M6vhHRQmMWEzDTvARIqQNq"
    "tEgpfKKWCWoh3zx9Z7B3g2C4hxbR+jrD4tysxySDNUOLbvW+5nw5c7xTLYikUQ2Qchp55wOT"
    "1FGRRPdlzQQjWoJ7exye3m6xs1sovBVXj2wSnJ/z+N0Vh9m6rNnXPm8OS0kupKfGBTOIsqOM"
    "UatplDFinEPbJsF9vcCXhyP0FtcGdoEIP3yXoI8fP71IJZZkhcDBLoMnBg0GyvT1gsfpdz2u"
    "L5q8Ujl1hQSUglPoMqQpdSICCQtGkmiKAZ/ZYW4rvH3sols+NUAEG/uURz/3PLvH4hAL3j3d"
    "wGNbBM/ebxj9dB/RSuhuF1zBHHPBeh8W01R/SmC0t1cwtAHrGo9QwOaSNBQQPDZgcHdHC3wN"
    "g4Ey8PHNTFnKSRLKTH0op5HCnzIa9EGAJS+9e/roM1mfAhsKwPYuYHIur1Z9RYQ4WFGLON1Y"
    "dDSQsHs05DGoLfGvZwof4eHPekDDY52y2yIcYV/C/TzTglvbh8obn1HrE1RThiORRpZomVME"
    "+CNrMFAlSF1N/LqFK2W1nu+rc9/pSYexa2pMfiCx+uLN9zzOXBZUsyIkW+B6nUrHiDQ3s+CG"
    "PBaa0J257HHsHqAU/W8FpuY9zl3LDdFxnfMfjzmcHGHtYLqOE5Ffjzt8yCyI/TzT2YUY4IFP"
    "BbJsOQizLK9UzHice9/hLFPn8Z13dobS//Ydj/c/zPdZ43Bwq8VnKXwfs6BIA4YY0Dt6hP2G"
    "w1/eM4y9TthkjvRLVIDO0/xX6J3mJx8VqS76yZjHZuYxe4j/6vfRCY/XxjWobNj3+LDg64cF"
    "5bhFpzVjP1P1vk0WL79exNvXMlRMjL5aqgHp4RsuSFhjNUXq9fy5Muvw4mmPX5wDZqr0JVFS"
    "v+r7Ki1+9azHD99wuFnJ923v9vjqwZXCl7OADw9cPP9oETWeE3WePVqZ5ch33/bpphGYqJNC"
    "FZ4sT0cFlPGg8wJr8CeHDPZ9hIh0Cq7MCcamMvxtSoO3Rbd6X3PeHDEhq0SCbtaM+uK/sWVx"
    "UkuxFgTmvqYiq5Szmj96KBkUyejBQY8v7rc4vEMtazF75kGLt656/PzvwD+mRCv78j7jVvJp"
    "DusrkKQLEhN1Ht3q+hCEGknOaZGw4YCwrNcHtnp86aOCT+yKgw+zVVnZSTiP3Ss4wkw5cwn4"
    "2RgPpw/yU9B4CXxCgrY1hmxfkIQMkHAWhMNIS7Foi5WpH42eE3hij8H3nmLtbjsHVlfF5lSj"
    "/PgIMNIf4blfZZiYpt1qkMnrQ3uXnKEY2jnnJGRMqIQagKpkUICB+EC/wbeP2RXC7zSkkYo7"
    "+gQvHbfoLZlGQeMBlep361lOd+0jtRI7VSA/g0Mx6mcUf+fJiO/1CV9WogHHw9sEzx8l1CYX"
    "tPYxIdtUZN6zOO0xtO1MEfEO8LWjBvu3/r+nQGso0y88BJzcr1xjGmUbzWr+OLYkSiRUMLW5"
    "66OeDoNbS3WYYideGK3gm69ZNpSF0MemhUro7XSeFBZv+72aLp9XydyytS80+uF8aJvIOEeJ"
    "d4lazaOnuAjzsaEiZmam0NttUaB2BWUki8yeJVJ3ImYrbkyGDjYaRism+8Y70cVSgaUU7aAl"
    "rrI0J2FN6RwRKbFD3ljOcHN6BgeH+mA+/+gQavMfYIF3wcHNRTJxWKJjhBsjXk3SrMwct6G7"
    "9VIIB0nqWLRo4ZLJ1/Ty4kiXKZ1p0SWunNPZDrboBXTYBQzdbTEzfwu++i6ePLQrz6aXR//p"
    "Xzl1CTv3HUZ3bw+WFliptFlVkyVqObjthiht7+aT3xnMmnukRgQTEN2sxdPzN3D5wl/x/c8N"
    "47nju1tty6u/P+9/RCVqpU3o2XgXXMwgItzWre0LpF0XkZV3R3Fr6TXQkyrmZmbpupt44Zm9"
    "+MqxPa3LaXP88s8X/ejZKVyavkn4CKiLGnfjnLSprsaz1x5e/0qTwoRrugltXZOumaI0hNey"
    "ocEYTx8Yxsmjw8ty/wOBV2HGcjvWTAAAAABJRU5ErkJggg=="
)


"""Icon for the Online page in a database tab."""
PageOnline = PyEmbeddedImage(
    "iVBORw0KGgoAAAANSUhEUgAAACAAAAAgCAYAAABzenr0AAAHyUlEQVRYw42X248dRxHGf9U9"
    "c/a+vmdtsHNZy94kQCQSJUQhSgQCQayIB4Tgb4BXkOCBJx4Q4iEP8EeAhJEQKEgoIBIcEi4h"
    "JLESE2d9wdesd9d78e76nOnu+niYs2d3bYIYaTT9dX1VUzPdVV1lbLtOnlnQn8/c4NLVVdLG"
    "OpU5OUbEzksCIcAAsP4TA9tOtq1BZ6jDsUPjPP3JKZ6fmbK7KN87+a7eWB3l6U90ePTIboYN"
    "hqJIGIK7nPC+ssnA+g7ZNoN9RzevW03g7Pk5/vLuEg8e2cWPn5+2gQPf/tUFnV2EE09OMT7c"
    "ZX090LUKq5yh5GiHWUCGKaKQ8JCRBERMEe7kAsIodWQ8wmoJvHhqkaeOFH7w3L1mfzi7qO//"
    "bp5Pz9zLwdHMrdERYnTqkulRE823W8IAN5GDUSkTXYhIthpZoPZylwOYKCSGvCL1Cjc2Cu+8"
    "f5UXnj9MeOXMDYb2HqSMdlgfG8ZCwFxkEx7BCRSr+4YyTQyISFCNqcLNaGKF9f+TzJE1NBGK"
    "QQ4RIQKwUQWakWEmKmdsfIqXz9wg/GvemRytiTW4RUIRTQjIhCliHihW2i/0YSr1/j9eDuQA"
    "gQ1kCZkYzhnMqDodxseNSzcK1UpTscczUR1CEeYRXPRshE7xAQ7ejrtx5/xH8dqd2so3r0Jo"
    "N6bAfJjbCSqTISKeoRcCSCgFZEZPGuDS39aewo75j+IBA/kgcuRQQB7AnOxQyUXByG4ogVQ2"
    "AwwzY1ftBIOVFChegICZ3cXbxGYBo7C7Y7hgubflQKTggBQRCXdRFS9IohTDnYFRMCZq+MyB"
    "wJU1WNgAl20LM9t2s2MczDg4aRwZN05dh9VmawkwgQckA4kKieKQcz+zKYBBNJjZZ4wEmF0S"
    "TQPqy9r/G+7IOjtl527CsUljZhL++qEoAlnEVNpQLiB3gkuUIlKGnI2UjZSMXZXx4B7j1BWY"
    "X2vno4w9taGyxUvJyNnw0soqtbL5dePUZZjZZeyu+9zGaDKkJEoWOARJ5Ozk7KQkcoKU4P4J"
    "WOmKc4stTkk8MQWfPwxRW7yUREqiEnzusPHEFOTU3uduwlJX3Dfe8jwlUhYpt+9EEGJxmhJI"
    "KdJk0ZSWMLMH3poT3b7CeC0em4KXLjhLt0V2cWBYHBgRuYilrvj9eefRe2Ci09rpJfH2XGsr"
    "FdFkI6XERo6UbFASgSJyhlQYeNdk59A4zN70AX5kv3H2Jpy/2S7ZM4fhxFE4MW08c9goRZxf"
    "cs7eFJ/az0Bv9mZrq0miSZGNMoSVNaQGV01wOUUiZ9E0IiXIGcZrmF/dwvdNwOm5dq/sG4Kj"
    "u4yXzomXzomju2D/EKQMpz907p+0gd7iGoxV7ThlUXdXCb2GksU6FZWXMtiEpbSZyvoZK+VA"
    "9hYXN1JqoyFnozikZIBwt/YLm0AuUAr0mlYvBkeijaJQyAq4jRHTEkaXyl24t965B+QBA1a7"
    "MNEx5tda/MGieHh/4G+X4dIyvDdnfHG6rUDem4dLSxEED+8X7y8YOUcM2D0Gt3pGLgGyE1XR"
    "dArroWZPL1MJof4SlOz9BAEXl+DIuLi2JBC8dqHw3WcrPjYmLi6LX79nvDkJmHN1VRSPPLAb"
    "ju+DX55ulw7BkYNwcald3spFLwiqSKMOasMQggyVQE6RlAspO29chscORUpp8bXlyB9nnRPH"
    "AyMh0kuFcwvOuXmjaSIjsXBiBl6ehWsrhZQLpTiPHTL+caVdrpwCy2WUUmo66lEoVMUF3jqQ"
    "GsOjA4G3rsHjH4fpveLMDQjF+M2ZxL6RmtV1I1nLQ4Hgxoqcn71tLN+KpDan89A9kclh459X"
    "RSpG1DqWxrFayArutJsQCXcn5Yh7e17+e1G8ftF47njg+rKzeAt6G2JlXQQZHvrnqvrYxYWe"
    "EzyiIA6MG88dN16/2NrKDhVOMqdkQ32dyiXMRC5OSgEPbQGaBH/6QExNiJkDgVeXRSrtO4M0"
    "4NkdOLqwCh7cbyxtiFc+gNu9zcNoCLc2aoxWoVJbY7cOZOHBBr/2+orz8zdFDNYmqf5hFeQ7"
    "eNuxuzAZp6/BW1fgw9UwOK8qExko3hb1ausBx4AikYr6R3L/SxGXl9riIki4bc3fydvEQe34"
    "4qIG8q1iOlD6eQMDyakMJ5ARHWTg1EhGhXZgs4JTE++Y/yheWxi18q1eIoIcCyKFdunD5EjA"
    "uw1DlVHibcy6dLxgzg68OQ7u/5NnJUBc3yHfvB1IEYZDxnticug24fHpIRYWrrJ7ItKR6Hik"
    "stsodCGPUVsmhMJIguCQQvifvNrWiTkiH8bqDWJI1LaOQhdXZNgSe0cLK3MLPDG9h/CNz07T"
    "W73O2sY6h+8ZIgSnGwwLiYoeuYySiPRsBFmHYE72MRqLdEM7F83xMkoh0gtbvOSjLS+OkEOH"
    "kbjG9IHIwuottHGZLz95tC2ifvjie3rh5CwPPPIUE7sn6a4ZjYsSHKza1ujprr5ze2UowC3c"
    "1UcazhDOxGiHudV5Lr77d370tWN880szWzXzT377jn56cpbe8D4m9+7H65oSAtH13zqtLV/M"
    "dvaO21u5bQ6EtMHSwiIdX+E7X3+Yb33hIePOTvIXr57Ri69dZXZuheSF6FW/N+434bYZWY6U"
    "AEO2yQgYRugfZpsR2OoEYhWYPlzzlUeP8dVnjw3e+x8KF3bjV2WxswAAAABJRU5ErkJggg=="
)


"""Icon for the SQL Window page in a database tab."""
PageSQL = PyEmbeddedImage(
    "iVBORw0KGgoAAAANSUhEUgAAACAAAAAgCAYAAABzenr0AAAAK3RFWHRDcmVhdGlvbiBUaW1l"
    "AE4gMjYgamFhbiAyMDEyIDIwOjA4OjAyICswMjAwNrNp7AAAAAd0SU1FB9wBGhIZOulC7wsA"
    "AAAJcEhZcwAACxIAAAsSAdLdfvwAAAAEZ0FNQQAAsY8L/GEFAAAGuElEQVR42o1XS48dxRX+"
    "TlV33zt3HrENxESykTLEMY8IEUSQeUjZRMpDJosowBK2zo7HAgErTACxsBRYwE9A4AVScKQs"
    "QER5yBJZJJYcJ5aVRASDbI9lecZ3Zm53V1W+U9V9b9+ZO9a0Zm7XeXTVqfP46pSg85w8txL+"
    "fO4yvri4imp9iEw8amsRMP0EMkLkSqSleetLusoyGRS9Aoe+tYDHvrcfRw/vl20qL548G/66"
    "OsBj9xZ44OAe9Cnp2YCKKjrnViN887EEiYNokHQmbAxtn7XS4Py/L+H02Wu46+A38NbRZRkb"
    "8PxH/wnnrwI/O7IfC/1NDIcGm5JBMo9e5Tm1TK/ORSXQM6aCNzUX0pVs5GGrbjRe4HKLBYpX"
    "ncGpP17FIwcdXv3pHSKfnL8aXvn9FXz/8B24fVBjbTAHaz1yV2OEHFZ8d6Y4vaefayPIQg3r"
    "de8WteS0yyD3bpsBGhdHX/Z8hmrkcHnd4cy/LuLE0QMwf2DMe/tuhxsUGM73IcZAOGnNj7xV"
    "Vxs4Tp4mqlFaExc0Iee8GY0R8rIYKInOocekJA/8DjTUxvAYytYzg3Kuj0V6dn5hPz7j2uaf"
    "VzyWBtxprjvjxC6gpBGBBqhLxasBLu3Q92Mu3EwvSEXdOWS14eLgwuuRp3r9uuYm6LmiwMKC"
    "4IvLDtn1MsNeT1eGIk4qcdsBb9y/0PGhvck43xX93N8dw2BSYmoouZmNCqy0INGltAEj7kg1"
    "QmXiR89+7qNyaLN7xjhwRybV5Y70bx5kEnJOHzgfUyTQW9ASJ5kFrwkiJGhIpeu7JpMZrw4t"
    "YmaOEy03pdUT1cjz18XyDVpBTErPtTPHrNUycswY79H5CKiqaXr2eHd0XUsMQUQqrxuQ6O1M"
    "f5xXhQbZghnPEQ3o0DuOd0HrXEEUK1wq5RgKj8zH3dMhdYLULnqp1S0tgpnj3dDJgKZQ+ac5"
    "4nTDMQdI1MwG/W+yZgy7VRXGtMjsccS5BAA70rqqzsXChNPSDGjWowGW/i/JrSrbHDDNN/zo"
    "/cdNF852Md6ZrrTEaZQnSDnM0QPku4o54NQDqoAG09u3weMf1nECpaU5On77hJ3ity5vZUc/"
    "qMd0K//4yYwVlQCrtD30cYOykmWZaw542hBiEmouiEx2UJYTOhkh2/hbZbqZLj3Jp6iIvFqF"
    "IQZoDvDApwHOjZPQuYRUguT6qu7QjHubWFN8zSQxY1lZYkyP5Q0/GEI6q8PLPGx1jfJNGkAw"
    "0Pqvan2biFKt7Z8+bTHrmeabadkz2RbtJK81+5h4lgdYWTgMTY69o5pVoKnXhoAKCSBSDB9+"
    "r46oFbHbuDg+fWyar5Aq0TtJduRdN6Zb+eljNoaN8Sbcx9RHybMnpDLUsmDC0MJa8TqCdYLP"
    "mpXR0kaaMePW5UdHixnLtN7HdOiiqkQEHGYDLBJ1i7AGPZ4IxQoIyYCqZJlYP3ZblzauHU/z"
    "FfGM78ioN6GTvOXbMIRUC5CcHuLRraGPSagZ40lVtY0HRNsB/u15/S068Sx24E/oM8/KFN0+"
    "CkRsX1DFCpAY6ngY+VgyzAECUqUhMJMG9Luv0TBTxn7Gsp3S8YWXelN8rW0NYSv7zq/9mG7l"
    "F1428Sxw6MV2zntJFRIaKNZBNEArwcgkBB06VouRbfwYAmbTRNalOyEgP9ONcux8wtyUhHS9"
    "qioYKVz6Tg/apU2YjKf0NInRkdXTNMKEr02rQ/JAPHhpQSax7WRZMWaatOyHUyny+fK4xax2"
    "bDY/0V8dn6bbR48mbUl028JSrEwKfbY0Z7C2WaLXm4ezG7EnzF2BA4xbXQwjndUFqmJj5jie"
    "cR29WTSaYtR2k3mOPu8So1HAUm8D5gfLPaysXMSeRcvapB/0Q9lg6DapPY+crbghCM0xiYwi"
    "JvvGm+nlMoTlKtpBS74Oy8uL8lTPMyH77JD3DRyuX1rBQ8t7YZ56dBmj1a9xg3fBA9/scRKP"
    "TSaQGD0qR0zOAbs3ixFb7SBFPEhqP4+SwLRpEk8vL556TvXMRK/yg6Rn59iiF5izN7B8m8XK"
    "6hrC+v/wkyN3Jph6/dQ/womTF/Dt+x7B4p4lbN7gZUObVd2yNNgeJvjQurR9t//pzmC23SM1"
    "z1iAWOTl59LqFfz37Od485eHcOzHhydn5tu/OxPeoRGj/i1Y2ncrfJ7TABOvXlsf6doiMn13"
    "7F7lOgaYah3XVq4ydNfxwpP34Fc/untyOW2fD/90Lpz6y0VcuHSd7nMRfCYNmqA1V/M5aA+v"
    "Umk1TOwpzfgwa84iSTLLa9nygRw/f+AQfvHDQ+N1/w/jDD9W5IqYSwAAAABJRU5ErkJggg=="
)


"""Icon for the Search page in a database tab."""
PageSearch = PyEmbeddedImage(
    "iVBORw0KGgoAAAANSUhEUgAAACAAAAAgCAYAAABzenr0AAAAB3RJTUUH3AEaEgYCDBpZCwAA"
    "AAlwSFlzAAALEgAACxIB0t1+/AAAAARnQU1BAACxjwv8YQUAAAf0SURBVHjafVdLbFxXGf7O"
    "uXeeHjt2HMcuiV3i1k3SlFSNUkjToCoSUmmJWLRReQkJEBKPLUiwQKKwAMSiC7pCILGoukBk"
    "gRBBdEEp0FaljSIUSJO6CWkdJonjsR2PZ8Yzc+85h+8/d96e9kp35jz+85//+f3/Veh5zlwq"
    "udcu3cZSsYyoVkWoLOIggEP/47jg/Kryc9X6lz/VS6y6g3QmjYW7CjjxwDRO7Z9W20i+f+ai"
    "O1fO48ShNI7MjiPLnUzgEJFEeA4KYVuHlVN+4AVSPQxbgrafzabG4n+X8cbFdRyY3YGfn5pX"
    "HQG+8/trbnEVePLYNArZOqpVjboKoUKLTGTJWvXfzkuVo2V0BKtjXiQ3BX4Ng7ReeAWTClDg"
    "dtlonP3HKo7PGvz4iTml/rK46n7w0goe2j+HmXyMzXwOQWCRMjEaSCFQtpeTZ29p51grhC5G"
    "YEX3ALFKUS6NlDXbBBC/GNoyY0NEDYPbNYML7xTx3Km90H+jzzM7Z2DyaVRHslBaQ5FpzEM2"
    "EFNrGDJPGMVoBtpfqF2KfEMKo7gWekcpbxxaTDW5Bp4DBQ28ezT3aqFGM5fFKC07UpjGK7xb"
    "X16xGMtT05RoRsbGoUkhHAUQkyorAphEQ5v1sfBhdE5FpM0hjDUvBy+u+TWhy8YxlaDl0mkU"
    "CgpLtw3CjWaICUtTurRnqrzaDg0ySRvbmWs7fDxIN2zefgzFca2IVlRmKwIzzSlvUsqABjUS"
    "CheJZgoNn2+O8aCxJw/sKwCT2QDFGnC17LDcoNbo0g2ea887meOsSEFLapEAMaehs84ziS0F"
    "ieScaScYAgba4QmHT85ofHRUIRt046rcVFjccHj5psP7lf5zipf2zttPwJusT0+JC2YQ7w4N"
    "o1bSyDBirEXnkCaTR3crPD2viQfAegN4/ZZFsQocmFA4xPfolMLd9OULiw6X76iBC9U2AcQF"
    "HqmsuEJ5K4XyQ5chjlvI5rT/O+ovJ4Jx+sr/HP685LBS9RCAv3M+V3A4fa/CwZ0KX1xQeP5f"
    "GjdqvcmvsR0+BCtMksreFcwx67WnQWIRQvGfJqQ7HtuTmPzVIvDiJeBGmekm+5FCneZ/Z1Xh"
    "V/9mLNwB8QM4RjfJnrxtPu15520KD3DMO0VhKq7F/DGjQV7ZiBkHs2R4zw5grQ784V2HzS10"
    "9qKoOy5uAH+86nwwPTQFjOhkb5C2/VouRLHzr9wn2RAGtH/TiPRBq8AAC/RvLgReKzpcu+OS"
    "1GlXmYHx+VsONysaMyPKW2Kl1lMAemlbdcMSpAxytAAdYSLGgBFpKKn4pFU9pnJJEL23TrCJ"
    "nV9vZ9PgeMMmlpodA3ZkqEzUv9+PyAERMoMsKtxrMi1TEgOWMjgfhM2m82Z7dzU5cGgXmRh4"
    "Adt7g+NRWmqamguovL++fb/3FdOn6mXoRtPHAAs+QmtMJwiNSZDqPANv7QHgwWmNe8ctLtxK"
    "Cr3zxUj3jR9ZoABMxf8sO1wtKW8BFpQuLbrFzGlCOrPDqhEE0Tr364Kqzue/DwwjERzg2prG"
    "+RsOLBH4yoMau3O6sxfH3fHh3RpPHdSe+cfYYzx7kutmkLb7GmYBCP1NmrWqU0jTLMHcya8/"
    "G+cm6beUj1zjDwPLVYeje4D7djHXGeGVusXtiqQgsCtv8Zn7FL75MANvFDhHXCgRA47cpfDV"
    "I4rCMDveFl58BWlNMlZU0rCEG1a+GvmMN9egTvzony6ePAAdjtB3NI8H6wTBPjGr8L2TwN3j"
    "ygfpEqFXUm8fwWfvjsSsb153+OlfgesbyblfntY4+pEkCs/Rit840w3EFIWphgqjbLeaW2uY"
    "2boG9cgP33Bu8n6ooIDaFtMkoGjiO0asJiDtm4pw6mCA43MasxMJuMW8a3HV4uUrwEuLCmub"
    "28/9+guuT5Cv/RbIugo7rQJG8w71qITpylIShBIxloEQ0W8SEz6Buaap0eVly5fmIiZPjTVZ"
    "I+jPOESxEpFJ60LJ74FzX34xEeiFL4VeCAEiti+IWAUFA1zrTGh9XksAChJqqRMd/NAiWGu+"
    "2pBa4DxYSRv2QXSD88//pusCg4xv56xVSYYIErqkx04EiOWgaplSk5HtzH22DBkP0g2bt59Q"
    "FEUSmN5eST9gvV8FjCLjWiU5saZ0f+2512rIeJBu2LxbDaWBSSzgCy8lYExK28nWGmkf/OyH"
    "vX9CMXbPXCkzdDxIN2ze6YjYkojaSlNZnbhejxFkLJM7Q1FMsMXFOtIs1tKN984/aDxIN2ze"
    "fsUorHnI8lvCMqbGMlvQD89nUCoVMT4aIE3TptlMhmqLrmOFiUeQYiuuCaE5gpQWxGTf+GF0"
    "KVVFwGySDlqlamzrIr8mdJYZk2WHvDNvsLFcwsfnJ6A/9+g8GuWbqPBbcO/uDJlY1BlASkup"
    "bDA48+zeAt/dOsXO2TeTBC12N3WdrMnHiyWdETrdpYtsPqELcmzR08gFFcxPBSiVN+Fq1/Hp"
    "Y/ckTdNPzr7tnjtzBfsOH8fo+BjqhNymQKiorMJ2be2LqGGdX/LNoLd9R0qcMQEJQGksl1fw"
    "3sW38LPTC/jW4/u7PfMv/nTBPU8hGtlJjO3cBZtKUQDtc37wUb2yKNX/7dj7KdcjgI5qWC+t"
    "0nUb+O4z9+PbnzrY/ThtP7979ZI7+3oRV5Y3aD4a1Iatb+OEtNNokKGTHl52VZtC+8907bvd"
    "bgYmZ6gIP8vm96bw2SMLeOqxhc69/wd0rhV4d9yO5gAAAABJRU5ErkJggg=="
)


"""Icon for the Data tables page in a database tab."""
PageTables = PyEmbeddedImage(
    "iVBORw0KGgoAAAANSUhEUgAAACAAAAAgCAYAAABzenr0AAAAK3RFWHRDcmVhdGlvbiBUaW1l"
    "AE4gMjYgamFhbiAyMDEyIDIwOjA4OjAyICswMjAwNrNp7AAAAAd0SU1FB9wBGhQHKMo33S4A"
    "AAAJcEhZcwAACxIAAAsSAdLdfvwAAAAEZ0FNQQAAsY8L/GEFAAAH4ElEQVR42pVXW29dRxX+"
    "1uy9z82XxEmI09QJqotJgQJqEG0aKoqqSIEoKgiqln+A4AkFHhBqeUAVqgBFopV4Kg88VELC"
    "SAXJkYAgtRQKJJUS3IYQt7Spg3Nx7Bof+xyfc/aeGb41+1wdt9BRJmfPeM2ab93XCPrG9MUl"
    "/+eLi5hfqCKt1xCLQxZF8Bgcnhs+7EpYS/tXf6SfWHofhWIBU7cN44G7x3H8wLjcQvKd6Qv+"
    "lWoFD3ysgIP7tqPEvxQjj5QkynMzCNc+LF7CRwAkfQzbQDtjrWUw9+YN/PXCCu7atw0/PD4p"
    "XQDfev4tP7cMHDs0juFSA7WaQUNiSOxQTB1Zy+DtvFQ8NWNSOJPxIr0pCnvYTBvAC2wSYZh/"
    "rlqDmZeWcXifxfe/sF/kD3PL/vHf3sQ9B/ZjTyXDWqWMKHJIbIYmEkTi+jkF9o56zowg9hki"
    "p7JHyCQhLoPE2VsAqF0sdVl0MdKmxWLdYvbSAk4en4B5kTYv7tgDWymgNlSCGAMh04yHXKSq"
    "NrBknjPK0IpMuND4hHxjghHuxcFQEpRDjUmLe+A5EGgUzGP4t3ps0CqXMELNDg2P4wXebf55"
    "02G0QkkTlYyMrUeLIDwBqErFKQCbS+hKwRfei85LStoy4szwcvDiethTulKWUQhqrlDA8LBg"
    "ftEiXm3FGHNUpS8EphLE9miSScG67tq4rb8302217gxLOL7t0UJhNlIw0rwElRIDmpRIKXyq"
    "kgmaId7ytW279ebvzXRbrbuR452ioCaNIkDGZeydOohwQSCpnrOdAKO2pLsWOljRWHxw2GDv"
    "kMHtFWqizbtFY1+pOVytAdc3KLWTAT6dEfEmF7CrXzCCeHds6bUaRpZMnEPfoc5BJhHe9Mmd"
    "gocmYgKgDc1ACumyZ8Ti7TXg9ILH+SXy84MA1AQhUzk1hQQtxfofTYYsa2c2bwZ4x5T8Sx/W"
    "y6Ur8buNhEc/tA3YT5A/yyKcWRxMX140V9g8lIMpHGIXpKdCsjyl9mcvNd99e4EHbxfI/7i8"
    "fxTof49MCS6vAgvrgwlJ/xm9UwUOPsBFRm/QiaAWaaddHy6d2maCZO937KLz7+G8vNKTiIEJ"
    "q6Hp0b6PACLqv8XdNI3aBSYPk05VeXHe497bBCOF9wfg0jvAqzRBansANOIck5RFmRqgdDbV"
    "NKcaAAk5Mx9mi+haaf59/rrDz2cdVpv//+XXax7PnnNYXM/59GaEui1C7DpN3aKTJuoDjhh8"
    "cEL1BekztppH1zNzDrMEcmwqwmE647bSrTGgvnNt3eNvVz1Ov+lwpbqF05AoSat0Zhd8gAWf"
    "AKztOqG1eaaSkLlpI0bAifsNKkPAk6cdnl5yeK5MAGW06dr2Eg05YLmmZdeF9eNHDF56nSa8"
    "3CtOnnkkY5Q5GUKUrvB8gwB4UuNf1e00Pjm7hZrzd68LnjwCfPchg1+96rDe4EXrwl9mvNAU"
    "sGQT6HDJY5Rz73bBVz5usDsWnFugs9k+D6ZpIxawVsGiZhKMNTNGgbpexwQkyBNE7oTCeXZe"
    "8NO/AF+7T3DkWIRFSvkv2rhFrWn207FvyIfQu5MZcje1tVD1+N5pj+urGGiRYq0NJrg+Wqw9"
    "Pg9DDQuGHpFmzN0uJOtcfCP5enpWpWFCutvjc5MGB3fkeeF+RF3maoKFVY9TF4FTlwjynR6f"
    "HpFBLa5ghFm34NfI2Woq1oSQA0hbtGXkQsRqRjTcf+KowdiY4MQvBE/dTPHsGYOdRfYB7Ia6"
    "dLwoY8ldpGmqjSicO/nVCDPnHX4/11cLfA2SDkMSap2lW00fnFA9ynGVMn2qTwQbcE8Z/+Y1"
    "i598McGPH/X0gSjYfr3hORP8ezkNUk7sEvpAjDvGPX9d8IEx8jjzNnmmPQCEjTREgARTh2Lk"
    "fG7rzCqxUS1185CmzJcZUj96weLEZ6MtfMAEsJt94MoK8M1fZ7j6n8Eu2aIY2jnnJI80307F"
    "+hEAaCSEitNRrQvr584Cr7zl8NinPI7eFeGesdwHDn1g0AfmmXanzwme/7vDpeW8UQ3FraMB"
    "FVSBuDzn5k6o3Y1u+jxtuk4PqhpAb33hmscTpyye+SPzfEVyZw1OSKC6YpW7tmawWo/yc9Lj"
    "080Dos1MroFQeIkgltB2srVGITgt++Fgn1jDs28tdBrL1HmVGW5xLfhvly7veuMtz8V9CFzQ"
    "CAVmKKYmN70ZLRN/o4Uiodhog5sNFFistRvvX7/b92a6rdadqcpkOUCJbwnXZOIqbsB8erKI"
    "paUFbB+JGJvUA5vJWDZoOqa8bAgJW3HDFFqmwxvNmOwb34sukRoiRpN20JLUETFcdU/pHFux"
    "EsN1R8Vi9cYS7p0cg3nsM5NoVq9hnW/Bid1FMnFo0PGEB2M+TTJbYfcWhe7WSyEUkswNocXu"
    "pmHyPX28ONJZpTM9utRVcrqozBa9gHK0jkk67lJ1Db5+BZ8/dGeepn4w8w9/cvoN3PGJwxjZ"
    "PooGE0pLm1UVmU+0brnrs6f0/XZm/mYwt7wj1c8YgBjh4+dG9SYuXziLpx6ZwtePHujV3qdP"
    "zfpnCKJZ2onRHbvgkoQATHh6bR7Sj0Vk8O3Y/5TrA2DSOlaWlmm6VXz70Y/iG0c+0nucdsYv"
    "/3TRz7y8gDdurFJ9VKiLIb2bun0hA4kKScOelw6FCT2l6RSzNsb8DAVhKz05keDhg1P48oNT"
    "3Xv/CzAtpFE0X7e2AAAAAElFTkSuQmCC"
)


"""Toolbar icon for commit button in database table grids."""
ToolbarCommit = PyEmbeddedImage(
    "iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAYAAAAf8/9hAAAAB3RJTUUH3AEaFDUPgk08NAAA"
    "AAlwSFlzAAALEgAACxIB0t1+/AAAAARnQU1BAACxjwv8YQUAAABHSURBVHjaY2CgKajn+w/G"
    "eAATpXaMGoDNAFwhj0OcEatCfKDxEyN+A/AZgqYZtwHYDMGimTAgIiVSDBDOItUmqJcoTgcU"
    "AwAXqRhzWeRKpQAAAABJRU5ErkJggg=="
)


"""Toolbar icon for contacts button on search page."""
ToolbarContact = PyEmbeddedImage(
    "iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAYAAAAf8/9hAAAALHRFWHRDcmVhdGlvbiBUaW1l"
    "AE4gMjEgbeRydHMgMjAxMyAyMjo0NjoyMSArMDIwMGnY+V8AAAAHdElNRQfdAxUVAARfk92u"
    "AAAACXBIWXMAAAsSAAALEgHS3X78AAAABGdBTUEAALGPC/xhBQAAATFJREFUeNqlkrGKg0AQ"
    "hjeXE1QIFlaW2oiVjYUWGsFK8Bks7H0GzRNY2ecNAja2e21II9gJipJXSKGiOdci5LzsGbi/"
    "2eXf2W9nZgeAf2qDO0jTdF9VlYn2PM8D27YPbwGyLNsnSRI2TWMOwzB72+0WSJIEDMMwFUX5"
    "eo7/XAJOp9N8+dlDoDzPQdu2cPnoxyLt4Hq9mgCjoijA8XgMsICpZjCO459NO5/PAAsgCGK1"
    "67vdDg9gGGYVwLIsHgAhXAWUZYkHqKq6ChBFEQ9wXfcwlYFNg6ZpqOs6xAKQLMvCAjRNg8tB"
    "ejnKvu/fb7fbD4+iKBDH8a/4h3G5XNAIm9NXhnVdv5wHjuNQGaHjOFCW5TmTTRRFQdd1Iepu"
    "3/erTUQiSRIIgoDWcON53v2tWxh9A8ITakM7BOFPAAAAAElFTkSuQmCC"
)


"""Toolbar icon for delete button in database table grids."""
ToolbarDelete = PyEmbeddedImage(
    "iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAYAAAAf8/9hAAAAB3RJTUUH3AEbFAgjYsF/DAAA"
    "AAlwSFlzAAALEgAACxIB0t1+/AAAAARnQU1BAACxjwv8YQUAAAAkSURBVHjaY2AYBcMAMCJz"
    "TvDx/SdGk8WnT3B9TAPtg1EwKAAAoFkEBI8Fc8MAAAAASUVORK5CYII="
)


"""Toolbar icon for filter chat button in chat page."""
ToolbarFilter = PyEmbeddedImage(
    "iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAYAAAAf8/9hAAAAGXRFWHRTb2Z0d2FyZQBBZG9i"
    "ZSBJbWFnZVJlYWR5ccllPAAAAYVJREFUeNqUUsFKAlEUPa95OqOptHBTiUZtwjCCCYJA0I27"
    "6BPyD4Q+wIVf4ipctGnrxr3Q1hZCBJWrChHR0nFe9zqpM+TieeHO4717znnnvrl4FQJvlPeU"
    "FBeUN7zy/v0v19WYw1wx/wA1KmQflDoodjp2K5t9vBbiBb5YU+sooConXv3ssFa7KjSb6Ha7"
    "KOTz9n6xaPsFCq3WqlYq2c/VapjP5bdXN93hEB+DAZ7KZeyk03D6fT8/UGMs8cy5wEgpXiPu"
    "aITLRgMn7TZCponPVArxen0pcJrL4SiTwXYiAcYSLxJwMKPDXqWCSDSKKR2MaW8lk0sBfsZY"
    "LAa4Lhi7cIBjL2/VhsEc5krlXWC41IqrFHRii/4cIQ34BRwWmM30BAxjJYCFAPXmaApIb7AC"
    "DiQ7mDiOlgA8BzLYAjmYagpshUL/3kCywESzBYOwSwdj6sfiOeAWNAXChFVCmDxDsqfUXkaI"
    "uCHlfIi0HBCWroozl23sjoGvc8u6wwbxQxzm/gowAL873XjUIXE3AAAAAElFTkSuQmCC"
)


"""Toolbar icon for insert button in database table grids."""
ToolbarInsert = PyEmbeddedImage(
    "iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAYAAAAf8/9hAAAAB3RJTUUH3AEbFAgw5n8+0gAA"
    "AAlwSFlzAAALEgAACxIB0t1+/AAAAARnQU1BAACxjwv8YQUAAAAvSURBVHjaY2AY3oCP78R/"
    "EManholSSwbeAEZ0PxOj6dMnC7g+il2AF4yQWBgGAADm3wucN+5mGAAAAABJRU5ErkJggg=="
)


"""Toolbar icon for maximize chat button in chat page."""
ToolbarMaximize = PyEmbeddedImage(
    "iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAYAAAAf8/9hAAAAGXRFWHRTb2Z0d2FyZQBBZG9i"
    "ZSBJbWFnZVJlYWR5ccllPAAAAhZJREFUeNqMUr1rU1EU/7373kteW5QOrVJBEVQ0k8MtONSK"
    "LhWpiotQNUJx6ZrRP8DBUdBBcRGMi3+AU6HWRRQz2KUhwcmEQEIeeUljk/u+POf50rxnOvTA"
    "vefe8/E7n1oYhrjxrvUGgMTRqbS1Pr/BD4Mv3/Pk2sqCdN1JS8JPkUEeHzcb4z9fge+XPnz6"
    "feTwmqaVUgBUxkaYCEUZsTBPlgXiL4gXdcM4FEwkP4N+H33HgadU3vO8wqPVs5I5/1nO+kMB"
    "eraNVq0WGVAmec91C/k752W53MPD1XOS/yxnPduxfQqgGwsiZ6UKj+/lyLkL3w9QqfTw4PZF"
    "yXLWJ+1TJYwir9+/LKvVHlwaiUNpNxoNbG/v4ta10weZTPYgjvxkbVE2m/vUswE6nRba7TaE"
    "CDA7a6Fe72Dl6pkoEyRAotZSo5Z5Cq/ebh2MZ2npglT7Po7PWPjy9VfpvzEuEyumxxgEo1J4"
    "jD8ckUU3E8Ik7g6HoDEukmOct0gv0ohooTAcDKK3bU7BnjIBU4erVHSylgWh6+nNjMb4vQhV"
    "24GeuwtxIhcDTKNjUVYZwXsRyVTtJ/5sPsOxK9yCmwmAb8V/cPUdZK8/hTZ/CY6RxV6GsqWA"
    "1H2ErTKGn59jbP9+YhMZbI6MTvnkwPVOmxo0oYH/LCf9STqZiRJi4uLm6Mz4zd2K/fL1WGNX"
    "K3QvcBV09mIe0V8BBgDmbCZA3KkdNgAAAABJRU5ErkJggg=="
)


"""Toolbar icon for message toggle button on search page."""
ToolbarMessage = PyEmbeddedImage(
    "iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAYAAAAf8/9hAAAALHRFWHRDcmVhdGlvbiBUaW1l"
    "AE4gMjEgbeRydHMgMjAxMyAyMjoyNzo0OSArMDIwMJsvH8IAAAAHdElNRQfdAxUVATP+NUng"
    "AAAACXBIWXMAAAsSAAALEgHS3X78AAAABGdBTUEAALGPC/xhBQAAADlJREFUeNpjYKAQMIKI"
    "pKSk/+RonjdvHiMTpS4YNWDUABBgxCWBnjpBqY4sG0AGkZvUqW8IRQbgAgCLFhLOKKE9wQAA"
    "AABJRU5ErkJggg=="
)


"""Toolbar icon for rollback button in database table grids."""
ToolbarRollback = PyEmbeddedImage(
    "iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAYAAAAf8/9hAAAAB3RJTUUH3AEaFDUVfy/FTgAA"
    "AAlwSFlzAAALEgAACxIB0t1+/AAAAARnQU1BAACxjwv8YQUAAABHSURBVHjaY2CgEDDCWcL1"
    "/0nS+bYRrJeJUhfQGIC8RcBrjHg1Y/EzcQbgshWLIYxEa8ZhCBNRCnE4nzAgIhApTgejBlAB"
    "AACTkRU1bx46WQAAAABJRU5ErkJggg=="
)


"""Toolbar icon for stats button in chat page."""
ToolbarStats = PyEmbeddedImage(
    "iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAYAAAAf8/9hAAAAB3RJTUUH3QMZFCYg61pv1AAA"
    "AAlwSFlzAAALEgAACxIB0t1+/AAAAARnQU1BAACxjwv8YQUAAAHpSURBVHjapZO/ahtBEMa/"
    "XUuyJXAs2Q7YhDSCFEkj8L5ButRpUghjgyEuz4bkIVKJ4DIQCCr8BiZgUqdRQIXShKRQI4Nk"
    "+4Tks+7frmf3VneSkKsMzN3e3Hy/3Z2dZUop/I/l9IMd8WSkfQV1ejqP5DcQo4mIRuTqi0wA"
    "M1anBOfFiRCBO0kiMnkVKmv402hNwc25FaTiiMQfhHA7AxPwe/fmvbpbhNcbo3pcE//O2nMQ"
    "Pic+3RPXP3uIRyG8vyMM318Z12Mdc9t9PD94KXSu0aSAEE7VqYmryy7CYWBcTuJ0aXo8jbu/"
    "+th5WxVak20hBIada8R3sZnJiDwJvp8HAgVWymHij4E8A6/k4Xc9o5kDxDRL5IbprGyVQ35L"
    "vvkhgcrJYmUQQUm2ANBHEknzc6kVCbiRANQK5Uy40WSAgCru3SNeI+ytFQUzgMgKramiTP9n"
    "KyhTUB/9E5s1mgHskK8vrMryuP1o+F/HLf6MeGUkXppJLiGLk6uLuKU1plb6LrDXxAlVnbrO"
    "4acFoeth7LcFvMpY6nPUomkbdCJN9UNaAGP6DgBPqTm24bBPObGsluojiQck7lMXUpsYrQXo"
    "WmyRb9Ne32AT75aexg3OqTbfadQnH5A2mgK43Wlp4X4sM92id+QeaeUD+ILiaqdNXpsAAAAA"
    "SUVORK5CYII="
)


"""Toolbar icon for stop button on search page."""
ToolbarStop = PyEmbeddedImage(
    "iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAIAAACQkWg2AAAALHRFWHRDcmVhdGlvbiBUaW1l"
    "AE4gMjEgbeRydHMgMjAxMyAyMTo1ODowNSArMDIwML0/WYwAAAAHdElNRQfdAxUTOiUy3m87"
    "AAAACXBIWXMAAAsSAAALEgHS3X78AAAABGdBTUEAALGPC/xhBQAAAAZ0Uk5TANQA0ADICuWh"
    "ugAAANVJREFUeNpjvHLhBAMpgAWZ83vmwgfTp6OpUMjMZE2Px6IBoto/ORlNw8bp0xUYGOB6"
    "mPCrBgKgIFAKqAChAY9qTD2MQE/fNrDAoxrhtrlzVS+cgPrhz+/fEAbrQpAxv+Pj0djonv75"
    "4weUER7Os3IlRCkQfAkPR7OHCa4Bjt76+0MEgQxkcVQbvn+HmyG1axeEIbxx4zM3NwI2QFTf"
    "t7MDIohmNBtAoQQJVm0LCzxBdPXECUiUg2wAUkAOUIigaoST8OhBVs2AnJZAeoDShBIfI6nJ"
    "GwC7TZxZQGalGAAAAABJRU5ErkJggg=="
)


"""Toolbar icon for inactive stop button on search page."""
ToolbarStopped = PyEmbeddedImage(
    "iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAQAAAC1+jfqAAAALHRFWHRDcmVhdGlvbiBUaW1l"
    "AE4gMjEgbeRydHMgMjAxMyAyMTo1ODowNSArMDIwML0/WYwAAAAHdElNRQfdAxYXCxC3jKuY"
    "AAAACXBIWXMAAAsSAAALEgHS3X78AAAABGdBTUEAALGPC/xhBQAAAIZJREFUeNpjYCAAGGGM"
    "9v9rkYSDGSoZURSApGORFCyGK2HEJo2shBG7NEIJUIHJf2zSECVnGFlAjN9gbjEQ9yLREABW"
    "8BPMbGOoAkuCWAjABCJ+QGEdWKgOzsdQ0AQWasKloAvIygNCBiALoQDqTRMsfjgD8yZ2JWcQ"
    "AYVNyRnUoMYXWQQBALXDQEUeuvmAAAAAAElFTkSuQmCC"
)


"""Toolbar icon for tables button on search page."""
ToolbarTables = PyEmbeddedImage(
    "iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAYAAAAf8/9hAAAABHNCSVQICAgIfAhkiAAAAcZJ"
    "REFUOI2dk81qIkEQx38zjh8T3KsYDyLxc1T0CXLMcV9Ddm8+iA+wz5B3kRCJDoiCeNnTgLDg"
    "qNNdtYfsiMbLJgUF1d3Uv3/9L9oZj8ffM5nMPV8Ia+1vT1Urk8nk11cExuPxD09VHYDn52dU"
    "9Zwics7LdXo+Go1QVcdNksQVEQCCIACg0+lc1e12+6YWEZIkcT1rraOqAIRhSLFYZLfbISKU"
    "y2V2ux2qelOrKtZaxzPGuKlAEAREUcTj4yMAi8WCbrcLwOvrK8PhEIDpdIqqYox5J0ifEIYh"
    "pVKJ5XKJiOD7Pm9vb6gqd3d3vLy8kF4mIlhrHdcYc+NBvV6n2WwSxzFBENDtdtnv9wwGgzOF"
    "iLwTXAqkBOv1GhGhUCgQhiGqiu/7zGazKwJjjOsmSeJ8JKjVajw8PHA4HGi1WrTbbeI4ptfr"
    "0e/3L6dwbWJKsNlsEBFyuRzL5RJVJZ/PM5/PzwSpia619moKANVqlVqtxul0otFo0Gw2OR6P"
    "Zz9SAWut68VxnPnowXa7Jd1brVZcEl56EMdxxouiKJ/NZnl6evrvPwCQzWaJoijvVCqVn7lc"
    "rvqp7n9xOp22DuAD3wDvk/0G+PMX80pIbz0EU9oAAAAASUVORK5CYII="
)


"""Toolbar icon for tabs toggle button on search page."""
ToolbarTabs = PyEmbeddedImage(
    "iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAYAAAAf8/9hAAAAAXNSR0IArs4c6QAAAARnQU1B"
    "AACxjwv8YQUAAAAJcEhZcwAADsMAAA7DAcdvqGQAAAAadEVYdFNvZnR3YXJlAFBhaW50Lk5F"
    "VCB2My41LjEwMPRyoQAAASNJREFUOE+d0b1qg1AYxvF3Chkyd+gUehfF1dHF0VJwMm3sh0IK"
    "RRA0d+TuBXgBvYIgKH4hRiIxGk99pEuhkJwe+OPrCz+OIDmOc+e6rjI+Vwjzdru9v2YHS7Zt"
    "PyRJ8sV+DmbTNFfX7GDJsqynYRjY+Xyewuz7/vS8tIOlzWbz3Pc967puCrPneSwIgl/9tYMl"
    "wzDWp9OJHY/HqbZtGd4vhctgSdf1NeDhcOAKBpY0TdObpmH7/Z4rGFhSVfWlrmtWliVXMLCk"
    "KMprVVUsz3OuYGBJluU33D7+d65gYEmSpPeiKFgURVzBwJIoikaapiwMQ65gYEkQBBOfv9vt"
    "uIKBpeVy+ZFlGYvjmCsYWJrP54+LxeLzP8HSeGZjN2O3nMHMvgFTmvUJKTInOAAAAABJRU5E"
    "rkJggg=="
)


"""Toolbar icon for chat history text size on chat page."""
ToolbarText = PyEmbeddedImage(
    "iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAYAAAAf8/9hAAABPElEQVQ4y82Sz0pCURDGv5lz"
    "vAkXDC16hKA2takHCP8FYkSrINCeI4h6hPaRVpt2EYJaq1wUrYPKVwiCaFGY9zjTwktYqAkt"
    "apbzDb/D9+MAfz00KLCZ8o6Ibg+7IcKDHRSK6Kyokmf5WoE315F5VUxGDDdACFxHFkQww4MA"
    "zLhkpis/apNBvZhSxQ0AGKbVoF5MGaY9w1SlkcsmDyoActGISbRqhefPqt5yOSuC6X5yjKGL"
    "VrXQHMa1gZOKKvq6EKUKgPwwAIe97v2oXQvN3o773joA6AjNrGHKW8OPry13BwCqeHo52zjx"
    "suV3BZryE8Cdb9ZcV9JYb9CuF09Hccu//YkMAH7uKEZEh+FuzmZKu71HJl3aArAIAG0n+7GV"
    "48QXADPFAc2GuwkAyW8PLQGY6orVdDuQOP7NfABbtWX03q98gQAAAABJRU5ErkJggg=="
)


"""Toolbar icon for timeline button in chat page."""
ToolbarTimeline = PyEmbeddedImage(
    "iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAYAAAAf8/9hAAAAGXRFWHRTb2Z0d2FyZQBBZG9i"
    "ZSBJbWFnZVJlYWR5ccllPAAAAtpJREFUeNqkk29IE3EYx5/bflO33d1uc3bbbaUtJNPK3BqR"
    "yrQhRGkJBYmgvgojLPKFEBX1KqIC39dbDQQJRJLQVxKGiANDTJmRkrS1yDnb3f7c/t31u2Vj"
    "+aYX/eDD3T2/3/O95/nePYQsy/A/CxGdOoDL2t9PGkKJgE6rO2Q32m6ymwbGsKrd0H5FEbwb"
    "xQTwC9cwQi6XA0mSABWS91YZKr1abz8xXLNbLQ803gBrZ4VViYe2t0OLCwu+xbm5WSEancUh"
    "vxJX/yWgIi45axpeUAJleXTsnumg2cKsrawgzmZDDEUxtsrKOkdtbf3G+roQj8XCuJKwCnLY"
    "AwUJODNlemjQ0qwTnVJbSXNec8nnK+jTWi0YTSZ7T3//AEnTbViAVkEsB5DBAmnpitVmrY4E"
    "duCM2YWLIfJJoigWFYj9KSkBkmHsjS0trdiH4yoQJYA4FklJTSWMhkxFkkCCEbbC4Tx+v79w"
    "r8Ank3nzGtxudzabrUIgw0vIyi4MiGUpJPFZGHx3C9xWJwyfewaCIECl2VyoIouTg5EIGBiG"
    "xQJGBGl5AiTZVXX9qCsOcYDzAIY3pdB++AJcbGsDr9cLvV1dQFFUHpIkwdnUBGebmwELqBBO"
    "noafWfjy/OPjA0MOV/moFu633wVvVSu4xk9CT3c3vBobK1Sg/HbRdBoSPP8DC0QR97kCIClN"
    "YyPZ1NPdJ7evPeA8R1rzhw0mUz5ZuRa3IOK25mdmljOZzBayfCr/szdpTJsspy3OOzlJsiKV"
    "qiBSvBQDVaIYej0+/h5/hWU1y7KgzANGFHg+9sHnkz0ej4OmaWr/nKixKB+JhIYGB0cDgcAE"
    "QRBbRPEBnU4Her3eyXFcZ29fX2N7R0edhePKlUPfQ6Gdt1NTqyMjI/PBYHAyHo8vJRIJIPYN"
    "F4VhEUIWjUbjUKvVnNLF3l4Ul/wN972JzdtWNDH8foFSjF6ZqX9McRoTw6R+CTAA9jQ8CY45"
    "ChEAAAAASUVORK5CYII="
)


"""Toolbar icon for title toggle button on search page."""
ToolbarTitle = PyEmbeddedImage(
    "iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAYAAAAf8/9hAAAALHRFWHRDcmVhdGlvbiBUaW1l"
    "AE4gMjEgbeRydHMgMjAxMyAyMjowNjo0MSArMDIwMB9ug1oAAAAHdElNRQfdAxUVAhfpG/7y"
    "AAAACXBIWXMAAAsSAAALEgHS3X78AAAABGdBTUEAALGPC/xhBQAAAEJJREFUeNpjYBhowAhj"
    "JCUl/SdF47x588B6WXBJIBuKTQwGmHBpJmQzUQBkGyGvMRFr2KgBw9oArKkKV+IhKRUSCwAF"
    "qxgZvjJU7QAAAABJRU5ErkJggg=="
)


"""Transparent 1x1 GIF."""
TransparentPixel = PyEmbeddedImage(
    "R0lGODlhAQABAIAAAP///wAAACH5BAEAAAAALAAAAAABAAEAAAICRAEAOw=="
)
